package com.productiontest.web.controller.system;

import java.util.List;
import java.util.Set;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import com.productiontest.common.constant.Constants;
import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.common.core.domain.entity.SysMenu;
import com.productiontest.common.core.domain.entity.SysUser;
import com.productiontest.common.core.domain.model.LoginBody;
import com.productiontest.common.utils.SecurityUtils;
import com.productiontest.framework.web.service.SysLoginService;
import com.productiontest.framework.web.service.SysPermissionService;
import com.productiontest.system.service.ISysMenuService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 登录验证
 * 
 * @author cf
 */
@RestController
@Api(value = "登录产测管理后台", tags = "登录产测管理后台")
public class SysLoginController {
	@Autowired
	private SysLoginService loginService;

	@Autowired
	private ISysMenuService menuService;

	@Autowired
	private SysPermissionService permissionService;

	/**
	 * 登录方法
	 * 
	 * @param loginBody
	 *            登录信息
	 * @return 结果
	 */
	@PostMapping("/login")
	@ApiOperation(value = "登录产测系统接口", notes = "登录产测系统接口")
	@ApiImplicitParams({ @ApiImplicitParam(name = "username", value = "账号", required = false),
			@ApiImplicitParam(name = "password", value = "密码", required = false), })
	public AjaxResult login(@RequestBody LoginBody loginBody) {
		AjaxResult ajax = AjaxResult.success();
		// 生成令牌
		String token = loginService.login(loginBody.getUsername(), loginBody.getPassword(), loginBody.getCode(),
				loginBody.getUuid());
		ajax.put(Constants.TOKEN, token);
		ajax.put("token", token);
		return ajax;
	}


	/**
	 * 获取用户信息
	 * 
	 * @return 用户信息
	 */
	@GetMapping("getInfo")
	public AjaxResult getInfo() {
		SysUser user = SecurityUtils.getLoginUser().getUser();
		// 角色集合
		Set<String> roles = permissionService.getRolePermission(user);
		// 权限集合
		Set<String> permissions = permissionService.getMenuPermission(user);
		AjaxResult ajax = AjaxResult.success();
		ajax.put("user", user);
		ajax.put("roles", roles);
		ajax.put("permissions", permissions);
		return ajax;
	}

	/**
	 * 获取路由信息
	 * 
	 * @return 路由信息
	 */
	@GetMapping("getRouters")
	public AjaxResult getRouters() {
		Long userId = SecurityUtils.getUserId();
		List<SysMenu> menus = menuService.selectMenuTreeByUserId(userId);
		return AjaxResult.success(menuService.buildMenus(menus));
	}
}
