package com.productiontest.common.utils;

import cn.hutool.core.map.MapUtil;
import cn.hutool.core.thread.ThreadUtil;
import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONArray;
import com.alibaba.fastjson2.JSONObject;
import com.productiontest.common.config.ImsConfig;
import com.productiontest.common.core.domain.entity.SysDept;
import com.productiontest.common.core.domain.entity.SysUser;
import com.productiontest.common.vo.AuthRuleVo;
import com.productiontest.common.vo.LicenseRecycleData;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

@Component
@Slf4j
public class ImsUtil {


    @Autowired
    private ImsConfig imsConfig;

    public String productlist(Long deptId){
        return post(imsConfig.getEnterpriseClient()+"/ProdTest/productlist", MapUtil.of("deptId",deptId));
    }

    public JSONObject productInfo(String appid){

        String rsp = post(imsConfig.getEnterpriseClient()+"/ProdTest/productInfo", MapUtil.of("appid",appid));
        JSONObject obj =  JSON.parseObject(rsp);
        return obj;
    }
    public String getAuthNum(Long deptId,String appid){

       Map m =  MapUtil.builder().put("deptId",deptId).put("appid",appid).build();
        return post(imsConfig.getEnterpriseClient()+"/ProdTest/getAuthNum",m );
    }

    public List<String> genLicense(Long deptId,Long userId, String appid, int count, String remark, String corps, AuthRuleVo ar){

        boolean toUppercase=true;
        if(ar.getToCase() <= 0){
            toUppercase=false;
        }
        Map m =  MapUtil.builder()
                .put("depId",deptId)
                .put("userId",userId)
                .put("appid",appid)
                .put("count",count)
                .put("figures",ar.getLength())
                .put("prefix",ar.getPrefix())
                .put("toUppercase",toUppercase)
                .put("remark",remark)
                .put("corps",corps)
                .build();

        log.info(JSON.toJSONString(m));

        String rsp = post(imsConfig.getEnterpriseClient()+"/ProdTest/genlicense",m );
        JSONObject obj = JSON.parseObject(rsp);
        JSONArray arr= obj.getJSONArray("data");

        List<String> ls =new ArrayList<>();
        if(arr !=null){
            for(int i=0;i<arr.size();i++){
                ls.add(arr.getString(i));
            }
        }
        return ls;
    }

    public String flowCorpList(Long deptId){
        Map m =  MapUtil.builder().put("deptId",deptId).build();
        return post(imsConfig.getEnterpriseClient()+"/ProdTest/flowCorpList",m );
    }
    public String licenseRecycle(LicenseRecycleData data){

        return post(imsConfig.getProduct()+"/licence/licenseRecycle",JSON.toJSONString(data) );
    }

    public SysDept getDept(Long deptId){
        Map m =  MapUtil.builder().put("deptId",deptId).build();
        String rsp = post(imsConfig.getEnterpriseClient()+"/ProdTest/getDept",m );
        return JSON.parseObject(rsp,SysDept.class);
    }
    public SysUser getUser(Long userId){
        Map m =  MapUtil.builder().put("userId",userId).build();
        String rsp = post(imsConfig.getEnterpriseClient()+"/ProdTest/getUser",m );
        return JSON.parseObject(rsp,SysUser.class);
    }

    private String post(String url,Map m){
        long ts = System.currentTimeMillis();
        log.info("{} url={},req={}",ts,url,m);
        String rsp="";
        try{
            rsp = HttpUtil.post(url,m );
        }catch (Exception e){
            log.error(e.getMessage(),e);
            ThreadUtil.safeSleep(2*1000);
            rsp = HttpUtil.post(url,m );
        }
        log.info("{} url={},rsp={}",ts,url,rsp);
        return rsp;
    }

    private String post(String url,String json){
        long ts = System.currentTimeMillis();
        log.info("{} url={},req={}",ts,url,json);
        String rsp;
        try{
            rsp = HttpUtil.post(url,json);
        }catch (Exception e){
            log.error(e.getMessage(),e);
            ThreadUtil.safeSleep(2*1000);
            rsp = HttpUtil.post(url,json);
        }

        log.info("{} url={},rsp={}",ts,url,rsp);
        return rsp;
    }
}
