package com.productiontest.controller;

import java.util.List;

import javax.servlet.http.HttpServletResponse;

import com.alibaba.fastjson2.JSONObject;
import com.productiontest.domain.AgingTaskDetail;
import com.productiontest.service.IAgingTaskDetailService;
import org.apache.commons.lang3.RandomStringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import com.productiontest.common.annotation.Log;
import com.productiontest.common.core.controller.BaseController;
import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.common.core.page.TableDataInfo;
import com.productiontest.common.enums.BusinessType;
import com.productiontest.common.utils.poi.ExcelUtil;
import com.productiontest.domain.AgingTask;
import com.productiontest.service.IAgingTaskService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.multipart.MultipartFile;

/**
 * 老化任务Controller
 *
 * @author cf
 * @date 2023-02-15
 */
@RestController
@RequestMapping("/agingtask/v1")
@Api(value = "老化任务", tags = "老化任务")
public class AgingTaskController extends BaseController {

    @Autowired
    private IAgingTaskService agingTaskService;
    @Autowired
    private IAgingTaskDetailService iAgingTaskDetailService;

    /**
     * 查询老化任务列表
     */
    @GetMapping("/list")
    @ApiOperation(value = "查询老化任务列表", notes = "查询老化任务列表", response = AgingTask.class, produces = "application/json")
    public TableDataInfo list(AgingTask agingTask) {
        startPage();
        List<AgingTask> list = agingTaskService.selectAgingTaskList(agingTask);
        return getDataTable(list);
    }



    /**
     * 导出老化任务列表
     */
    @Log(title = "老化任务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出老化任务列表", notes = "导出老化任务列表", response = AgingTask.class, produces = "application/json")
    public void export(HttpServletResponse response, AgingTask agingTask) {
        List<AgingTask> list = agingTaskService.selectAgingTaskList(agingTask);
        ExcelUtil<AgingTask> util = new ExcelUtil<AgingTask>(AgingTask.class);
        util.exportExcel(response, list, "老化任务数据");
    }

    @PostMapping("/uploadDeviceFile")
    @ApiOperation(value = "上传设备", notes = "上传设备", produces = "application/json")
    @ApiImplicitParams({@ApiImplicitParam(name = "file", value = "文件流", required = false),})
    public AjaxResult uploadDeviceFile(@RequestParam(value = "file") @RequestPart MultipartFile file)
            throws Exception {
        return agingTaskService.uploadDeviceFile(file);
    }


    /**
     * 获取老化任务详细信息
     */
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "根据主键id获取老化任务详细信息", notes = "根据主键id获取老化任务详细信息", response = AgingTask.class, produces = "application/json")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "获取老化任务详细信息", required = false, paramType = "query")})
    public AjaxResult getInfo(@PathVariable("id") String id) {
        return success(agingTaskService.selectAgingTaskById(id));
    }

    /**
     * 新增老化任务
     */
    @Log(title = "新增老化任务", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增老化任务", notes = "新增老化任务", response = AgingTask.class, produces = "application/json")
    public AjaxResult add(@RequestBody AgingTask agingTask) {
        return toAjax(agingTaskService.insertAgingTask(agingTask));
    }

    /**
     * 修改老化任务
     */
    @Log(title = "修改老化任务", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改老化任务", notes = "修改老化任务", response = AgingTask.class, produces = "application/json")
    public AjaxResult edit(@RequestBody AgingTask agingTask) {
        return toAjax(agingTaskService.updateAgingTask(agingTask));
    }

    /**
     * 停止任务
     * @param agingTask
     * @return
     */
    @PostMapping("stopAgingTask")
    @ApiOperation(value = "停止老化任务", notes = "停止老化任务", response = AgingTask.class, produces = "application/json")
    public AjaxResult stopAgingTask(@RequestBody AgingTask agingTask) {
        return toAjax(agingTaskService.stopAgingTask(agingTask));
    }

    @PostMapping("noticeAgingTask")
    @ApiOperation(value = "通知任务老化任务 开始、结束", notes = "通知任务老化任务 开始、结束")
    public AjaxResult noticeAgingTask(@RequestBody JSONObject json) {
        return toAjax(agingTaskService.noticeAgingTask(json));
    }



    /**
     * 删除老化任务
     */
    @Log(title = "老化任务", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "根据主键ids删除老化任务", notes = "根据主键ids删除老化任务", response = AgingTask.class, produces = "application/json")
    @ApiImplicitParams({@ApiImplicitParam(name = "ids", value = "根据主键ids删除", required = false)})
    public AjaxResult remove(@PathVariable String[] ids) {
        return toAjax(agingTaskService.deleteAgingTaskByIds(ids));
    }

    /**
     * 查询老化任务-测试详情列表
     */
    @GetMapping("/selectAgingTaskDetailList")
    @ApiOperation(value = "查询老化任务-设备明细列表", notes = "查询老化任务-设备明细列表", response = AgingTaskDetail.class, produces = "application/json")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "agingTaskId", value = "aging_task表主键id", required = false, paramType = "query"),})
    public TableDataInfo selectAgingTaskDetailList(AgingTaskDetail agingTaskDetail) {
        startPage();
        List<AgingTaskDetail> list = iAgingTaskDetailService.selectAgingTaskDetailList(agingTaskDetail);
        return getDataTable(list);
    }

}
