package com.productiontest.controller;

import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.productiontest.common.annotation.Log;
import com.productiontest.common.core.controller.BaseController;
import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.common.core.page.TableDataInfo;
import com.productiontest.common.enums.BusinessType;
import com.productiontest.common.utils.poi.ExcelUtil;
import com.productiontest.domain.AgingTaskDetail;
import com.productiontest.service.IAgingTaskDetailService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 老化任务-测试详情Controller
 * 
 * @author cf
 * @date 2023-02-15
 */
@RestController
@RequestMapping("/agingtaskdetail/v1")
@Api(value = "老化任务-测试详情", tags = "老化任务-测试详情")
public class AgingTaskDetailController extends BaseController {
	@Autowired
	private IAgingTaskDetailService agingTaskDetailService;

	/**
	 * 查询老化任务-测试详情列表
	 */
	@GetMapping("/list")
	@ApiOperation(value = "查询老化任务-测试详情列表", notes = "查询老化任务-测试详情列表", response = AgingTaskDetail.class, produces = "application/json")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "agingTaskId", value = "aging_task表主键id", required = false, paramType = "query"), })
	public TableDataInfo list(AgingTaskDetail agingTaskDetail) {
		startPage();
		List<AgingTaskDetail> list = agingTaskDetailService.selectAgingTaskDetailList(agingTaskDetail);
		return getDataTable(list);
	}

	@GetMapping("/getListAgingTaskDetailNopage")
	@ApiOperation(value = "查询老化任务-测试详情列表 无分页", notes = "查询老化任务-测试详情列表 无分页", response = AgingTaskDetail.class, produces = "application/json")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "agingTaskId", value = "aging_task表主键id", required = false, paramType = "query"), })
	public List<AgingTaskDetail> getListAgingTaskDetailNopage(AgingTaskDetail agingTaskDetail) {
		return agingTaskDetailService.selectAgingTaskDetailList(agingTaskDetail);
	}



	/**
	 * 导出老化任务-测试详情列表
	 */
	@Log(title = "老化任务-测试详情", businessType = BusinessType.EXPORT)
	@PostMapping("/export")
	@ApiOperation(value = "导出老化任务-测试详情列表", notes = "导出老化任务-测试详情列表", response = AgingTaskDetail.class, produces = "application/json")
	public void export(HttpServletResponse response, AgingTaskDetail agingTaskDetail) {
		List<AgingTaskDetail> list = agingTaskDetailService.selectAgingTaskDetailList(agingTaskDetail);
		ExcelUtil<AgingTaskDetail> util = new ExcelUtil<AgingTaskDetail>(AgingTaskDetail.class);
		util.exportExcel(response, list, "老化任务-测试详情数据");
	}

	/**
	 * 获取老化任务-测试详情详细信息
	 */
	@GetMapping(value = "/{id}")
	@ApiOperation(value = "根据主键id获取老化任务-测试详情详细信息", notes = "根据主键id获取老化任务-测试详情详细信息", response = AgingTaskDetail.class, produces = "application/json")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "根据主键id获取老化任务-测试详情", required = false, paramType = "query") })
	public AjaxResult getInfo(@PathVariable("id") String id) {
		return success(agingTaskDetailService.selectAgingTaskDetailById(id));
	}

	/**
	 * 新增老化任务-测试详情
	 */
	@Log(title = "新增老化任务-测试详情", businessType = BusinessType.INSERT)
	@PostMapping
	@ApiOperation(value = "新增老化任务-测试详情", notes = "新增老化任务-测试详情", response = AgingTaskDetail.class, produces = "application/json")
	public AjaxResult add(@RequestBody AgingTaskDetail agingTaskDetail) {
		return toAjax(agingTaskDetailService.insertAgingTaskDetail(agingTaskDetail));
	}

	/**
	 * 修改老化任务-测试详情
	 */
	@Log(title = "修改老化任务-测试详情", businessType = BusinessType.UPDATE)
	@PutMapping
	@ApiOperation(value = "修改老化任务-测试详情", notes = "修改老化任务-测试详情", response = AgingTaskDetail.class, produces = "application/json")
	public AjaxResult edit(@RequestBody AgingTaskDetail agingTaskDetail) {
		return toAjax(agingTaskDetailService.updateAgingTaskDetail(agingTaskDetail));
	}

	/**
	 * 删除老化任务-测试详情
	 */
	@Log(title = "老化任务-测试详情", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
	@ApiOperation(value = "根据主键ids删除老化任务-测试详情", notes = "根据主键ids删除老化任务-测试详情", response = AgingTaskDetail.class, produces = "application/json")
	@ApiImplicitParams({ @ApiImplicitParam(name = "ids", value = "根据主键ids删除", required = false) })
	public AjaxResult remove(@PathVariable String[] ids) {
		return toAjax(agingTaskDetailService.deleteAgingTaskDetailByIds(ids));
	}
}
