package com.productiontest.controller;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.productiontest.common.annotation.Log;
import com.productiontest.common.core.controller.BaseController;
import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.common.core.page.TableDataInfo;
import com.productiontest.common.enums.BusinessType;
import com.productiontest.domain.DataDictionary;
import com.productiontest.service.IDataDictionaryService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * 数据字典Controller
 * 
 * @author cf
 * @date 2022-08-10
 */
@RestController
@RequestMapping("/dictionary/v1")
@Api(value = "数据字典", tags = "数据字典")
public class DataDictionaryController extends BaseController {
	@Autowired
	private IDataDictionaryService dataDictionaryService;

	/**
	 * 查询数据字典列表
	 */
	@GetMapping("/list")
	@ApiOperation("查询数据字典表 data_dictionary 可带参数查询 有分页")
	public TableDataInfo list(DataDictionary dataDictionary) {
		startPage();
		List<DataDictionary> list = dataDictionaryService.selectDataDictionaryList(dataDictionary);
		return getDataTable(list);
	}

	@GetMapping("/getDataDictionaryList")
	@ApiOperation("查询数据字典表 data_dictionary 可带参数查询 无分页 返回list")
	public List<DataDictionary> getDataDictionaryList(DataDictionary dataDictionary) {
		return dataDictionaryService.selectDataDictionaryList(dataDictionary);
	}

	/**
	 * 获取数据字典详细信息
	 */
	@GetMapping(value = "/{id}")
	@ApiOperation("根据主键id查询详细数据")
	public AjaxResult getInfo(@PathVariable("id") Long id) {
		return AjaxResult.success(dataDictionaryService.selectDataDictionaryById(id));
	}

	/**
	 * 新增数据字典
	 */
	@Log(title = "数据字典", businessType = BusinessType.INSERT)
	@PostMapping
	@ApiOperation("新增数据字典 入参为对象")
	public AjaxResult add(@RequestBody DataDictionary dataDictionary) {
		return toAjax(dataDictionaryService.insertDataDictionary(dataDictionary));
	}

	/**
	 * 修改数据字典
	 */
	@Log(title = "数据字典", businessType = BusinessType.UPDATE)
	@PutMapping
	@ApiOperation("修改数据字典 入参为对象")
	public AjaxResult edit(@RequestBody DataDictionary dataDictionary) {
		return toAjax(dataDictionaryService.updateDataDictionary(dataDictionary));
	}

	/**
	 * 删除数据字典
	 */
	@Log(title = "数据字典", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
	@ApiOperation("根据主键id删除数据 id可传多个批量删除")
	public AjaxResult remove(@PathVariable Long[] ids) {
		return toAjax(dataDictionaryService.deleteDataDictionaryByIds(ids));
	}
}
