package com.productiontest.controller;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson2.JSONObject;
import com.productiontest.common.annotation.Log;
import com.productiontest.common.core.controller.BaseController;
import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.common.enums.BusinessType;
import com.productiontest.domain.AgingTaskDetail;
import com.productiontest.domain.InventoryTestRecord;
import com.productiontest.service.IInventoryTestRecordService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 生产库存-测试记录Controller
 * 
 * @author cf
 * @date 2023-02-16
 */
@RestController
@RequestMapping("/inventorytestrecord/v1")
@Api(value = "生产库存-测试记录", tags = "生产库存-测试记录")
public class InventoryTestRecordController extends BaseController {
	@Autowired
	private IInventoryTestRecordService inventoryTestRecordService;

	/**
	 * 查询生产库存-测试记录列表
	 */
	@GetMapping("/list")
	@ApiOperation(value = "查询生产库存-测试记录列表 无分页", notes = "查询生产库存-测试记录列表 无分页", response = InventoryTestRecord.class, produces = "application/json")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "productionInventoryId", value = "production_inventory主键id", required = false, paramType = "query"), })
	public List<InventoryTestRecord> list(InventoryTestRecord inventoryTestRecord) {
		return inventoryTestRecordService.selectInventoryTestRecordList(inventoryTestRecord);
	}

	/**
	 * 新增生产库存-测试记录
	 */
	@Log(title = "新增生产库存-测试记录", businessType = BusinessType.INSERT)
	@PostMapping
	@ApiOperation(value = "新增生产库存-测试记录", notes = "新增生产库存-测试记录", response = InventoryTestRecord.class, produces = "application/json")
	public AjaxResult add(@RequestBody InventoryTestRecord inventoryTestRecord) {
		return toAjax(inventoryTestRecordService.insertInventoryTestRecord(inventoryTestRecord));
	}

	/**
	 * 修改生产库存-测试记录
	 */
	@Log(title = "修改生产库存-测试记录", businessType = BusinessType.UPDATE)
	@PutMapping
	@ApiOperation(value = "修改生产库存-测试记录", notes = "修改生产库存-测试记录", response = InventoryTestRecord.class, produces = "application/json")
	public AjaxResult edit(@RequestBody InventoryTestRecord inventoryTestRecord) {
		return toAjax(inventoryTestRecordService.updateInventoryTestRecord(inventoryTestRecord));
	}

	/**
	 * 删除生产库存-测试记录
	 */
	@Log(title = "生产库存-测试记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
	@ApiOperation(value = "根据主键ids删除生产库存-测试记录", notes = "根据主键ids删除生产库存-测试记录", response = AgingTaskDetail.class, produces = "application/json")
	@ApiImplicitParams({ @ApiImplicitParam(name = "ids", value = "根据主键ids删除", required = false) })
	public AjaxResult remove(@PathVariable Long[] ids) {
		return toAjax(inventoryTestRecordService.deleteInventoryTestRecordByIds(ids));
	}

	@PostMapping("uploadTestResult")
	public JSONObject uploadTestResult(@RequestBody JSONObject js) {
		return inventoryTestRecordService.uploadTestResult(js);
	}

	/**
	 * 根据license查询sn
	 * @param js
	 * @return
	 */
	@PostMapping("selectDeviceSNByLicense")
	public JSONObject selectDeviceSNByLicense(@RequestBody JSONObject js) {
		return inventoryTestRecordService.selectDeviceSNByLicense(js);
	}

}
