package com.productiontest.controller;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RequestPart;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import com.productiontest.common.annotation.Log;
import com.productiontest.common.core.controller.BaseController;
import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.common.enums.BusinessType;
import com.productiontest.domain.LabelTemplate;
import com.productiontest.service.ILabelTemplateService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 标签模板Controller
 * 
 * @author cf
 * @date 2023-02-15
 */
@RestController
@RequestMapping("/labeltemplate/v1")
@Api(value = "标签模板", tags = "标签模板")
public class LabelTemplateController extends BaseController {

	@Autowired
	private ILabelTemplateService labelTemplateService;

	/**
	 * 查询标签模板列表
	 */
	@GetMapping("/getList")
	@ApiOperation(value = "查询标签模板列表 无分页", notes = "查询标签模板列表  无分页", response = LabelTemplate.class, produces = "application/json")
	public List<LabelTemplate> getList(LabelTemplate labelTemplate) {
		return labelTemplateService.selectLabelTemplateList(labelTemplate);
	}

	/**
	 * 获取标签模板详细信息
	 */
	@GetMapping(value = "/{id}")
	@ApiOperation(value = "获取标签模板详细信息", notes = "获取标签模板详细信息", response = LabelTemplate.class, produces = "application/json")
	@ApiImplicitParams({ @ApiImplicitParam(name = "id", value = "根据主键id查询", required = false, paramType = "query") })
	public AjaxResult getInfo(@PathVariable("id") String id) {
		return success(labelTemplateService.selectLabelTemplateById(id));
	}

	/**
	 * 新增标签模板
	 */
	@Log(title = "标签模板", businessType = BusinessType.INSERT)
	@PostMapping
	@ApiOperation(value = "新增标签模板", notes = "新增标签模板", response = LabelTemplate.class, produces = "application/json")
	public AjaxResult add(@RequestBody LabelTemplate labelTemplate) {
		return toAjax(labelTemplateService.insertLabelTemplate(labelTemplate));
	}

	@Log(title = "修改标签模板", businessType = BusinessType.UPDATE)
	@PutMapping
	@ApiOperation(value = "修改标签模板", notes = "修改标签模板", response = LabelTemplate.class, produces = "application/json")
	public AjaxResult edit(@RequestBody LabelTemplate LabelTemplate) {
		return toAjax(labelTemplateService.updateLabelTemplate(LabelTemplate));
	}

	@PostMapping("/importLabelTemplate")
	@ApiOperation(value = "导入标签模板", notes = "导入标签模板")
	@ApiImplicitParams({ @ApiImplicitParam(name = "file", value = "文件流", required = false) })
	public AjaxResult importLabelTemplate(@RequestParam(value = "file") @RequestPart MultipartFile file) {
		return toAjax(labelTemplateService.importLabelTemplate(file));
	}

	/**
	 * 删除标签模板
	 */
	@Log(title = "删除标签模板", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
	@ApiOperation(value = "删除标签模板", notes = "删除标签模板", response = LabelTemplate.class, produces = "application/json")
	@ApiImplicitParams({ @ApiImplicitParam(name = "ids", value = "根据主键ids删除 ", required = false), })
	public AjaxResult remove(@PathVariable String[] ids) {
		return toAjax(labelTemplateService.deleteLabelTemplateByIds(ids));
	}
}
