package com.productiontest.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.productiontest.common.annotation.Log;
import com.productiontest.common.core.controller.BaseController;
import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.common.enums.BusinessType;
import com.productiontest.domain.LicenseData;
import com.productiontest.service.ILicenseDataService;
import com.productiontest.common.utils.poi.ExcelUtil;
import com.productiontest.common.core.page.TableDataInfo;

/**
 * 导入license数据Controller
 *
 * @author cf
 * @date 2023-02-17
 */
@RestController
@RequestMapping("/licensedata/v1")
@Api(tags = "授权明细",value = "授权明细")
public class LicenseDataController extends BaseController {
    @Autowired
    private ILicenseDataService licenseDataService;

    /**
     * 查询导入license数据列表
     */
    @GetMapping("list")
    @ApiOperation(value = "查询授权明细列表带分页",notes = "查询授权明细列表带分页")
    public TableDataInfo list(LicenseData licenseData) {
        startPage();
        List<LicenseData> list = licenseDataService.selectLicenseDataList(licenseData);
        return getDataTable(list);
    }

    /**
     * 导出导入license数据列表
     */
    @Log(title = "导入license数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导入授权明细",notes = "导入授权明细")
    public void export(HttpServletResponse response, LicenseData licenseData) {
        List<LicenseData> list = licenseDataService.selectLicenseDataList(licenseData);
        ExcelUtil<LicenseData> util = new ExcelUtil<LicenseData>(LicenseData.class);
        util.exportExcel(response, list, "导入license数据数据");
    }

    /**
     * 获取导入license数据详细信息
     */
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "根据id获取授权明细",notes = "根据id获取授权明细")
    public AjaxResult getInfo(@PathVariable("id") String id) {
        LicenseData licenseData=new LicenseData();
        licenseData.setId(id);
        return success(licenseDataService.selectLicenseDataById(licenseData));
    }

    /**
     * 新增license数据
     */
    @Log(title = "导入license数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody LicenseData licenseData) {
        return toAjax(licenseDataService.insertLicenseData(licenseData));
    }

    /**
     * 修改license数据
     */
    @Log(title = "修改license数据", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改授权明细数据",notes = "修改授权明细数据")
    public AjaxResult edit(@RequestBody LicenseData licenseData) {
        return toAjax(licenseDataService.updateLicenseData(licenseData));
    }

    /**
     * 删除license数据
     */
    @Log(title = "删除授权明细数据", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除授权明细数据",notes = "删除授权明细数据")
    public AjaxResult remove(@PathVariable String[] ids) {
        return toAjax(licenseDataService.deleteLicenseDataByIds(ids));
    }
}
