package com.productiontest.controller;

import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson2.JSONObject;
import com.productiontest.common.annotation.Log;
import com.productiontest.common.core.controller.BaseController;
import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.common.core.page.TableDataInfo;
import com.productiontest.common.enums.BusinessType;
import com.productiontest.common.utils.poi.ExcelUtil;
import com.productiontest.domain.ProductionInventory;
import com.productiontest.service.IProductionInventoryService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 生产库存-pcba和整机Controller
 *
 * @author cf
 * @date 2023-02-16
 */
@RestController
@RequestMapping("/productioninventory/v1")
@Api(value = "生产库存-pcba和整机", tags = "生产库存-pcba和整机")
public class ProductionInventoryController extends BaseController {

    @Autowired
    private IProductionInventoryService productionInventoryService;

    /**
     * 查询生产库存-pcba和整机列表
     */
    @GetMapping("/list")
    @ApiOperation(value = "查询生产库存-pcba和整机列表", notes = "查询生产库存-pcba和整机列表", response = ProductionInventory.class, produces = "application/json")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "productionInventoryId", value = "production_inventory主键id", required = false, paramType = "query"),})
    public TableDataInfo list(ProductionInventory productionInventory) {
        startPage();
        List<ProductionInventory> list = productionInventoryService.selectProductionInventoryList(productionInventory);
        return getDataTable(list);
    }

    /**
     * 导出生产库存-pcba和整机列表
     */
    @Log(title = "生产库存-pcba和整机", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出生产库存-pcba和整机列表", notes = "导出生产库存-pcba和整机列表", response = ProductionInventory.class, produces = "application/json")
    public void export(HttpServletResponse response, @RequestBody ProductionInventory productionInventory) {
        List<ProductionInventory> list = productionInventoryService.selectProductionInventoryList(productionInventory);
        ExcelUtil<ProductionInventory> util = new ExcelUtil<ProductionInventory>(ProductionInventory.class);
        String name = "";
        if (productionInventory.getInventoryType().equals("1")) {
            name = "整机生产库存";
        } else {
            name = "PCBA生产库存";
        }
        util.exportExcel(response, list, name);
    }

    /**
     * 获取生产库存-pcba和整机详细信息
     */
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取生产库存-pcba和整机详细信息", notes = "获取生产库存-pcba和整机详细信息", response = ProductionInventory.class, produces = "application/json")
    @ApiImplicitParams({@ApiImplicitParam(name = "id", value = "根据主键id查询", required = false, paramType = "query")})
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(productionInventoryService.selectProductionInventoryById(id));
    }

    /**
     * 新增生产库存-pcba和整机
     */
    @Log(title = "新增生产库存-pcba和整机", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增生产库存-pcba和整机", notes = "新增生产库存-pcba和整机", response = ProductionInventory.class, produces = "application/json")
    public AjaxResult add(@RequestBody ProductionInventory productionInventory) {
        return toAjax(productionInventoryService.insertProductionInventory(productionInventory));
    }

    /**
     * 修改生产库存-pcba和整机
     */
    @Log(title = "生产库存-pcba和整机", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改生产库存-pcba和整机", notes = "修改生产库存-pcba和整机", response = ProductionInventory.class, produces = "application/json")
    public AjaxResult edit(@RequestBody ProductionInventory productionInventory) {
        return toAjax(productionInventoryService.updateProductionInventory(productionInventory));
    }

    /**
     * 删除生产库存-pcba和整机
     */
    @Log(title = "删除生产库存-pcba和整机", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除生产库存-pcba和整机", notes = "删除生产库存-pcba和整机", response = ProductionInventory.class, produces = "application/json")
    @ApiImplicitParams({@ApiImplicitParam(name = "ids", value = "根据主键ids删除 ", required = false),})
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(productionInventoryService.deleteProductionInventoryByIds(ids));
    }

    @PostMapping("getStatisticsProductionInventoryCount")
    @ApiOperation(value = "设备统计数量", notes = "设备统计数量", produces = "application/json")
    public ProductionInventory getStatisticsProductionInventoryCount(
            @RequestBody ProductionInventory productionInventory) {
        return productionInventoryService.getStatisticsProductionInventoryCount(productionInventory);
    }

    @PostMapping("getStatisticsByOderNo")
    @ApiOperation(value = "按订单分布", notes = "按订单分布", produces = "application/json")
    public List<Map<Object, Object>> getStatisticsByOderNo(@RequestBody ProductionInventory productionInventory) {
        return productionInventoryService.getStatisticsByOderNo(productionInventory);
    }

    @PostMapping("getStatisticsByMoth")
    @ApiOperation(value = "按月份统计数量", notes = "按月份统计数量", produces = "application/json")
    public List<String> getStatisticsByMoth(@RequestBody ProductionInventory productionInventory) {
        return productionInventoryService.getStatisticsByMoth(productionInventory);
    }

    /**
     * 申请License
     *
     * @param json
     * @return
     */
    @PostMapping("getLicense")
    public JSONObject getLicense(@RequestBody JSONObject json) {
        return productionInventoryService.getLicense(json);
    }

}
