package com.productiontest.controller;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletResponse;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.productiontest.common.utils.ImsUtil;
import com.productiontest.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RequestPart;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import com.productiontest.common.annotation.Log;
import com.productiontest.common.core.controller.BaseController;
import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.common.core.page.TableDataInfo;
import com.productiontest.common.enums.BusinessType;
import com.productiontest.common.utils.poi.ExcelUtil;
import com.productiontest.domain.ProductionOrder;
import com.productiontest.domain.ShippingRecord;
import com.productiontest.service.IProductionOrderService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 订单管理Controller
 *
 * @author cf
 * @date 2023-02-13
 */
@RestController
@RequestMapping("/productiontest/v1")
@Api(value = "订单管理", tags = "订单管理")
public class ProductionOrderController extends BaseController {

    @Autowired
    private IProductionOrderService productionOrderService;
    @Autowired
    private ImsUtil imsUtil;

    /**
     * 查询订单管理列表
     */
    @GetMapping("/list")
    @ApiOperation(value = "获取订单管理列表", notes = "获取订单管理列表", response = ProductionOrder.class, produces = "application/json")
    @ApiImplicitParams({@ApiImplicitParam(name = "orderName", value = "订单名称", required = false, paramType = "query"),
            @ApiImplicitParam(name = "productName", value = "产品名称", required = false, paramType = "query"),
            @ApiImplicitParam(name = "company", value = "下单企业", required = false, paramType = "query"),
            @ApiImplicitParam(name = "orderStatus", value = "订单状态", required = false, paramType = "query"),
            @ApiImplicitParam(name = "pageNum", value = "第几页", required = false, paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "一页显示多少条", required = false, paramType = "query"),

    })
    public TableDataInfo list(ProductionOrder productionOrder) {
        startPage();
        List<ProductionOrder> list = productionOrderService.selectProductionOrderList(productionOrder);
        return getDataTable(list);
    }

    @GetMapping("/getListProductionOrderNoPage")
    @ApiOperation(value = "所有订单列表 无分页", notes = "所有订单列表 无分页", response = ProductionOrder.class, produces = "application/json")
    public List<ProductionOrder> getListProductionOrderNoPage(ProductionOrder productionOrder) {
        return productionOrderService.getListProductionOrderNoPage(productionOrder);
    }

    /**
     * 导出订单管理列表
     */
    @Log(title = "订单管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出订单管理列表 可带参数导出", notes = "导出订单管理列表 可带参数导出", response = ProductionOrder.class, produces = "application/json")
    public void export(HttpServletResponse response, ProductionOrder productionOrder) {
        List<ProductionOrder> list = productionOrderService.selectProductionOrderList(productionOrder);
        ExcelUtil<ProductionOrder> util = new ExcelUtil<ProductionOrder>(ProductionOrder.class);
        util.exportExcel(response, list, "订单管理数据");
    }

    /**
     * 获取订单管理详细信息
     */
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取订单管理详细信息", notes = "获取订单管理详细信息", response = ProductionOrder.class, produces = "application/json")
    @ApiImplicitParams({@ApiImplicitParam(name = "id", value = "根据主键id查询", required = false, paramType = "query")})
    public AjaxResult getInfo(@PathVariable("id") String id) {
        return success(productionOrderService.selectProductionOrderById(id));
    }

    @GetMapping(value = "/getProductionOrderStatistics")
    @ApiOperation(value = "首页订单统计", notes = "首页订单统计 count=订单数量," +
            "unscheduledProduction=待安排生产,HaveArrangedProduction=已安排生产," +
            "ProductionTest=生产测试中,ProductionComplete=生产完成",
            response = ProductionOrder.class, produces = "application/json")
    public Map<Object, Object> getProductionOrderStatistics() {
        return productionOrderService.getSelectProductionOrderStatistics();
    }

    @GetMapping(value = "/selectProductionOrderStatisticsByEcharts")
    @ApiOperation(value = "首页统计订单生产进度 eachrts", notes = "首页统计订单生产进度 eachrts",
            response = ProductionOrder.class, produces = "application/json")
    public List<Map<Object, Object>> selectProductionOrderStatisticsByEcharts() {
        return productionOrderService.selectProductionOrderStatisticsByEcharts();
    }


    @GetMapping(value = "/selectProductionOrderListByNewDate")
    @ApiOperation(value = "首页 今日生产中的订单", notes = "首页 今日生产中的订单",
            response = ProductionOrder.class, produces = "application/json")
    public List<ProductionOrder> selectProductionOrderListByNewDate() {
        SimpleDateFormat sd = new SimpleDateFormat("yyyy-MM-dd");
        ProductionOrder po = new ProductionOrder();
        po.setCreateTime(sd.format(new Date()));
        return productionOrderService.selectProductionOrderListByNewDate(po);
    }

    @GetMapping(value = "/selectLicenseCountBymark")
    @ApiOperation(value = "订单详情-查询授权明细数量", notes = "订单详情-查询授权明细数量", produces = "application/json")
    public AjaxResult selectLicenseCountByMark(String mark) {
        return success(productionOrderService.selectLicenseCountByMark(mark));
    }
    @GetMapping(value = "/selectThirdCountByOrderId")
    @ApiOperation(value = "订单详情-第三方授权明细", notes = "订单详情-第三方授权明细", produces = "application/json")
    public AjaxResult selectThirdCountByOrderId(String id) {
        return success(productionOrderService.selectThirdCountByOrderId(id));
    }
    /**
     * 新增订单管理
     */
    @Log(title = "订单管理", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增订单管理信息", notes = "新增订单管理信息", response = ProductionOrder.class, produces = "application/json")
    public AjaxResult add(@RequestBody ProductionOrder productionOrder) {
        return productionOrderService.insertProductionOrder(productionOrder);
    }

    /**
     * 修改订单管理
     */
    @Log(title = "订单管理", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改订单管理信息", notes = "修改订单管理信息", response = ProductionOrder.class, produces = "application/json")
    public AjaxResult edit(@RequestBody ProductionOrder productionOrder) {
        return productionOrderService.updateProductionOrder(productionOrder);
    }

    /**
     * 删除订单管理
     */
    @Log(title = "订单管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除订单管理信息", notes = "删除订单管理信息", response = ProductionOrder.class, produces = "application/json")
    @ApiImplicitParams({@ApiImplicitParam(name = "ids", value = "根据主键ids删除 ", required = false),})
    public AjaxResult remove(@PathVariable String[] ids) {
        return toAjax(productionOrderService.deleteProductionOrderByIds(ids));
    }

    @PostMapping("/uploadFileReadFile")
    @ApiOperation(value = "license文件上传 读取文件内容", notes = "license文件上传 读取文件内容", produces = "application/json")
    @ApiImplicitParams({@ApiImplicitParam(name = "file", value = "文件流", required = false),})
    public AjaxResult uploadFileReadFile(@RequestParam(value = "file") @RequestPart MultipartFile file)
            throws Exception {
        return productionOrderService.uploadFileReadFile(file);
    }

    @PostMapping("/uploadThirdFile")
    @ApiOperation(value = "第三方授权文件上传 读取文件内容", notes = "第三方授权文件上传 读取文件内容", produces = "application/json")
    @ApiImplicitParams({@ApiImplicitParam(name = "file", value = "文件流", required = false),})
    public AjaxResult uploadThirdFile(@RequestParam(value = "file") @RequestPart MultipartFile file)
            throws Exception {
        return productionOrderService.uploadThirdFile(file);
    }



    @PostMapping("/uploadDeviceConfigFile")
    @ApiOperation(value = "上传设备配置", notes = "上传设备配置")
    @ApiImplicitParams({@ApiImplicitParam(name = "file", value = "文件流", required = false),})
    public AjaxResult uploadDeviceConfigFile(@RequestParam(value = "file") @RequestPart MultipartFile file)
            throws Exception {
        return productionOrderService.uploadDeviceConfigFile(file);
    }


    @PostMapping("/uploadEquipment")
    @ApiOperation(value = "出货交付 选择设备数上传 返回数量", notes = "出货交付 选择设备数上传  返回数量", produces = "application/json")
    @ApiImplicitParams({@ApiImplicitParam(name = "file", value = "文件流", required = false),})
    public AjaxResult uploadEquipment(@RequestParam(value = "file") @RequestPart MultipartFile file)
            throws Exception {
        return productionOrderService.uploadEquipment(file);
    }


    @PostMapping("selectProductionOrderDeliveryDetail")
    @ApiOperation(value = "出货交付页面显示详情", notes = "出货交付详情 productionQuantity=订单生产数量,deliveryCount=已交付数量,inventoryCount=库存数量", produces = "application/json")
    public Map<Object, Object> selectProductionOrderDeliveryDetail(@RequestBody ProductionOrder productionOrder) {
        return productionOrderService.selectProductionOrderDeliveryDetail(productionOrder);
    }

    @PostMapping("/insertShippingRecordByProductionOrder")
    @ApiOperation(value = "修改订单管理信息 出货交付提交", notes = "修改订单管理信息 出货交付提交", response = ProductionOrder.class, produces = "application/json")
    public AjaxResult insertShippingRecordByProductionOrder(@RequestBody ShippingRecord sr) {
        return productionOrderService.insertShippingRecordByProductionOrder(sr);
    }

    /**
     * 提供sdk查询是否要升级固件
     *
     * @param json
     * @return
     */
    @PostMapping("/getOrderDetail")
    public JSONObject getOrderDetail(@RequestBody JSONObject json) {
        return productionOrderService.getOrderDetail(json);
    }


    @PostMapping("/productlist")
    @ApiOperation(value = "生产产品列表", notes = "生产产品列表", produces = "application/json")
    public JSONObject productlist() {
        Long deptId= SecurityUtils.getDeptId();
        return JSON.parseObject(imsUtil.productlist(deptId));
    }

    @PostMapping("/getAuthNum")
    @ApiOperation(value = "产品授权数量", notes = "产品授权数量", produces = "application/json")
    public JSONObject getAuthNum(String appid) {
        Long deptId= SecurityUtils.getDeptId();
        return JSON.parseObject(imsUtil.getAuthNum(deptId,appid));
    }


}
