package com.productiontest.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.fastjson2.JSONObject;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.productiontest.common.annotation.Log;
import com.productiontest.common.core.controller.BaseController;
import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.common.enums.BusinessType;
import com.productiontest.domain.ProductionTestUserCard;
import com.productiontest.service.IProductionTestUserCardService;
import com.productiontest.common.utils.poi.ExcelUtil;
import com.productiontest.common.core.page.TableDataInfo;

/**
 * 人员绑定-4GController
 *
 * @author cf
 * @date 2023-06-14
 */
@RestController
@RequestMapping("/productionTestcard/v1")
public class ProductionTestUserCardController extends BaseController {
    @Autowired
    private IProductionTestUserCardService productionTestUserCardService;

    /**
     * 查询人员绑定-4G列表
     */
    @GetMapping("/list")
    public TableDataInfo list(ProductionTestUserCard productionTestUserCard) {
        startPage();
        List<ProductionTestUserCard> list = productionTestUserCardService.selectProductionTestUserCardList(productionTestUserCard);
        return getDataTable(list);
    }

    /**
     * 导出人员绑定-4G列表
     */
    @Log(title = "人员绑定-4G", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ProductionTestUserCard productionTestUserCard) {
        List<ProductionTestUserCard> list = productionTestUserCardService.selectProductionTestUserCardList(productionTestUserCard);
        ExcelUtil<ProductionTestUserCard> util = new ExcelUtil<ProductionTestUserCard>(ProductionTestUserCard.class);
        util.exportExcel(response, list, "人员绑定-4G数据");
    }

    /**
     * 获取人员绑定-4G详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id) {
        return success(productionTestUserCardService.selectProductionTestUserCardById(id));
    }

    /**
     * 绑定、解绑人员绑定-4G
     */
    @PostMapping("/bindUserCard")
    public JSONObject bindUserCard(@RequestBody JSONObject json) {
        return productionTestUserCardService.insertProductionTestUserCard(json);
    }

    /**
     * 根据人员账号查询sim卡号
     *
     * @param json
     * @return
     */
    @PostMapping("/selectSimCardByAccount")
    public JSONObject selectSimCardByAccount(@RequestBody JSONObject json) {
        return productionTestUserCardService.selectSimCardByAccount(json);
    }


    /**
     * 修改人员绑定-4G
     */
    @Log(title = "人员绑定-4G", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ProductionTestUserCard productionTestUserCard) {
        return toAjax(productionTestUserCardService.updateProductionTestUserCard(productionTestUserCard));
    }

    /**
     * 删除人员绑定-4G
     */
    @Log(title = "人员绑定-4G", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids) {
        return toAjax(productionTestUserCardService.deleteProductionTestUserCardByIds(ids));
    }

    //通过SIM卡号查询用户账号
    @PostMapping("/selectAccountByCard")
    public JSONObject selectAccountByCard(@RequestBody JSONObject json) {
        return productionTestUserCardService.selectAccountByCard(json);
    }


}
