package com.productiontest.controller;

import java.util.List;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import com.productiontest.common.config.RuoYiConfig;
import com.productiontest.domain.ProductionTestUserCard;
import com.productiontest.service.IProductionTestUserCardService;
import com.productiontest.util.ConnectUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson2.JSONObject;
import com.productiontest.common.annotation.Log;
import com.productiontest.common.core.controller.BaseController;
import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.common.core.page.TableDataInfo;
import com.productiontest.common.enums.BusinessType;
import com.productiontest.common.utils.poi.ExcelUtil;
import com.productiontest.domain.ProductionTestUser;
import com.productiontest.service.IProductionTestUserService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 产测人员管理Controller
 *
 * @author cf
 * @date 2023-02-14
 */
@RestController
@RequestMapping("/productionTestUser/v1")
@Api(value = "产测人员管理", tags = "产测人员管理")
public class ProductionTestUserController extends BaseController {

    @Resource
    private IProductionTestUserService productionTestUserService;
    @Resource
    private IProductionTestUserCardService productionTestUserCardService;


    /**
     * 查询产测人员管理列表
     */
    @GetMapping("/list")
    @ApiOperation(value = "查询产测人员管理列表 有分页参数", notes = "查询产测人员管理列表  有分页参数", response = ProductionTestUser.class, produces = "application/json")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "companyId", value = "企业id", required = false, paramType = "query"),})
    public TableDataInfo list(ProductionTestUser productionTestUser) {
        startPage();
        List<ProductionTestUser> list = productionTestUserService.selectProductionTestUserList(productionTestUser);
        return getDataTable(list);
    }

    @GetMapping("/getListNoPage")
    @ApiOperation(value = "查询产测人员管理列表 无分页参数", notes = "查询产测人员管理列表  无分页参数", response = ProductionTestUser.class, produces = "application/json")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "companyId", value = "企业id", required = false, paramType = "query"),})
    public List<ProductionTestUser> getListNoPage(ProductionTestUser productionTestUser) {
        return productionTestUserService.selectProductionTestUserList(productionTestUser);
    }

    @PostMapping("/selectCountProductionTestUser")
    @ApiOperation(value = "验证产测人员账号是否已经存在", notes = "验证产测人员账号是否已经存在")
    public int selectCountProductionTestUser(@RequestBody ProductionTestUser productionTestUser) {
        return productionTestUserService.selectCountProductionTestUser(productionTestUser);
    }


    /**
     * 导出产测人员管理列表
     */
    @Log(title = "产测人员管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出产测人员管理列表 可携带参数查询导出", notes = "导出产测人员管理列表 可携带参数查询导出")
    public void export(HttpServletResponse response, ProductionTestUser productionTestUser) {
        List<ProductionTestUser> list = productionTestUserService.selectProductionTestUserList(productionTestUser);
        ExcelUtil<ProductionTestUser> util = new ExcelUtil<ProductionTestUser>(ProductionTestUser.class);
        util.exportExcel(response, list, "产测人员管理");
    }

    /**
     * 获取产测人员管理详细信息
     */
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "根据主键id获取产测人员管理详细信息", notes = "根据主键id获取获取产测人员管理详细信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "获取产测人员管理详细信息", required = false, paramType = "query")})
    public AjaxResult getInfo(@PathVariable("id") String id) {
        return success(productionTestUserService.selectProductionTestUserById(id));
    }

    /**
     * 新增产测人员管理
     */
    @Log(title = "新增产测人员管理", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增产测人员管理", notes = "新增产测人员管理")
    public AjaxResult add(@RequestBody ProductionTestUser productionTestUser) {
        return productionTestUserService.insertProductionTestUser(productionTestUser);
    }

    /**
     * 修改产测人员管理
     */
    @Log(title = "修改产测人员管理", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改产测人员管理", notes = "修改产测人员管理")
    public AjaxResult edit(@RequestBody ProductionTestUser productionTestUser) {
        return toAjax(productionTestUserService.updateProductionTestUser(productionTestUser));
    }

    @PostMapping("resetPassword")
    @ApiOperation(value = "重置密码", notes = "重置密码")
    @ApiImplicitParams({@ApiImplicitParam(name = "id", value = "主键id，需要修改的账号id", required = false),
            @ApiImplicitParam(name = "password", value = "重置密码", required = false)})
    public AjaxResult resetPassword(@RequestBody ProductionTestUser productionTestUser) {
        return toAjax(productionTestUserService.resetPassword(productionTestUser));
    }

    /**
     * 删除产测人员管理
     */
    @Log(title = "删除产测人员管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "根据主键id删除人员管理", notes = "根据主键id删除人员管理")
    @ApiImplicitParams({@ApiImplicitParam(name = "ids", value = "根据主键ids删除", required = false)})
    public AjaxResult remove(@PathVariable String[] ids) {
        return toAjax(productionTestUserService.deleteProductionTestUserByIds(ids));
    }

    /**
     * 获取用户名
     *
     * @param json
     * @return
     */
    @PostMapping("getUsernameAndIcon")
    public JSONObject getUsernameAndIcon(@RequestBody JSONObject json) {
        return productionTestUserService.getUsernameAndIcon(json);
    }

    /**
     * 提供外部接口
     *
     * @param
     * @return
     */
    @PostMapping("/getAccountInfo")
    public JSONObject getAccountInfo(@RequestBody JSONObject json) {
        return productionTestUserService.getAccountInfo(json);
    }

    @GetMapping("selectTestUserCardDetail")
    @ApiOperation(value = "绑定4G卡号-查询卡号详情", notes = "绑定4G卡号-查询卡号详情")
    public AjaxResult selectTestUserCardDetail(String userId) {
        ProductionTestUserCard card = new ProductionTestUserCard();
        card.setUserId(userId);
        List<ProductionTestUserCard> cardList = productionTestUserCardService.selectProductionTestUserCardList(card);
        return success(cardList);
    }


}
