package com.productiontest.controller;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.io.IoUtil;
import cn.hutool.poi.excel.ExcelWriter;
import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.productiontest.common.annotation.Log;
import com.productiontest.common.core.controller.BaseController;
import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.common.core.page.TableDataInfo;
import com.productiontest.common.enums.BusinessType;
import com.productiontest.common.utils.ImsUtil;
import com.productiontest.common.utils.SecurityUtils;
import com.productiontest.common.utils.poi.ExcelUtil;
import com.productiontest.domain.LicenseData;
import com.productiontest.domain.ProductionOrder;
import com.productiontest.domain.ProductionWorkOrder;
import com.productiontest.domain.ThirdPartyData;
import com.productiontest.service.FirmwareConfigService;
import com.productiontest.service.IInventoryTestRecordService;
import com.productiontest.service.IProductionOrderService;
import com.productiontest.service.IProductionWorkOrderService;
import com.productiontest.vo.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.RandomStringUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.List;
import java.util.Map;

/**
 * 工单管理-生产工单Controller
 *
 * @author cf
 * @date 2023-02-07
 */
@RestController
@RequestMapping("/productionWorkOrder/v1")
@Api(value = "工单管理-生产工单", tags = "工单管理-生产工单")
public class ProductionWorkOrderController extends BaseController {
    @Resource
    private IProductionWorkOrderService ProductionWorkOrderService;
    @Resource
    private IProductionOrderService productionOrderService;
    @Resource
    private IInventoryTestRecordService IInventoryTestRecordService;
    @Resource
    private FirmwareConfigService firmwareConfigService;

    @Resource
    private ImsUtil imsUtil;



    /**
     * 查询生产工单列表
     */
    @GetMapping("/list")
    @ApiOperation(value = "查询生产工单列表 有分页参数", notes = "查询生产工单列表  有分页参数", response = ProductionWorkOrder.class, produces = "application/json")
    public TableDataInfo list(ProductionWorkOrder ProductionWorkOrder) {
        startPage();
        List<ProductionWorkOrder> list = ProductionWorkOrderService.selectProductionWorkOrderList(ProductionWorkOrder);
        return getDataTable(list);
    }

    @GetMapping("/getListProductionWorkOrderNoPage")
    @ApiOperation(value = "查询所有生产工单 无分页", notes = "查询所有生产工单   无分页", response = ProductionWorkOrder.class, produces = "application/json")
    public List<ProductionWorkOrder> getListProductionWorkOrderNoPage(ProductionWorkOrder ProductionWorkOrder) {
        return ProductionWorkOrderService.selectProductionWorkOrderList(ProductionWorkOrder);
    }

    @PostMapping("/getWorkOrderList")
    public JSONObject getWorkOrderList(@RequestBody JSONObject json) {
        return ProductionWorkOrderService.getWorkOrderList(json);
    }

    @GetMapping("/selectTestTotal")
    @ApiOperation(value = "测试统计图-工单详情", notes = "测试统计图-工单详情 wordOderId参数为工单id")
    public AjaxResult selectTestTotal(String wordOderId) {
        return IInventoryTestRecordService.selectTestTotal(wordOderId);
    }

    @GetMapping("/selectWorkOrderUserListById")
    @ApiOperation(value = "工单详情-查询4g人员列表 id为工单的id", notes = "工单详情-查询4g人员列表")
    public AjaxResult selectWorkOrderUserListById(String id) {
        return ProductionWorkOrderService.selectWorkOrderUserListById(id);
    }


    @GetMapping("/getStatisticsProductionWorkOrder")
    @ApiOperation(value = "查询生产工单列表 统计未开始、生产测试中、生产完成、已取消数量", notes = "查询生产工单列表  有分页参数")
    public ProductionWorkOrder getStatisticsProductionWorkOrder(ProductionWorkOrder ProductionWorkOrder) {
        return ProductionWorkOrderService.getStatisticsProductionWorkOrder(ProductionWorkOrder);
    }

    @GetMapping("/selectProductionWorkOrderCount")
    @ApiOperation(value = "根据对象字段属性验证字段的唯一性", notes = "根据对象字段属性验证字段的唯一性")
    public int selectProductionWorkOrderCount(ProductionWorkOrder ProductionWorkOrder) {
        return ProductionWorkOrderService.selectProductionWorkOrderCount(ProductionWorkOrder);
    }

//    @GetMapping("/selectDictData")
//    @ApiOperation(value = "配置参数查询", notes = "配置参数查询")
//    public AjaxResult selectDictData(SysDictData data) {
//        return success(sysDictDataService.selectDictData(data));
//    }

    @GetMapping("selectFirmwareConfig")
    @ApiOperation(value = "配置参数查询", notes = "配置参数查询")
    public AjaxResult selectFirmwareConfig(){
        return success(firmwareConfigService.selectFirmwareConfig());
    }



    public static void main(String[] args) {
        System.out.println(RandomStringUtils.randomAlphanumeric(12));
    }

    /**
     * 导出生产工单列表
     */
    @Log(title = "PCBA生产工单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出生产工单列表 可携带参数查询导出", notes = "导出生产工单列表 可携带参数查询导出")
    public void export(HttpServletResponse response, ProductionWorkOrder ProductionWorkOrder) {
        List<ProductionWorkOrder> list = ProductionWorkOrderService.selectProductionWorkOrderList(ProductionWorkOrder);
        ExcelUtil<ProductionWorkOrder> util = new ExcelUtil<ProductionWorkOrder>(ProductionWorkOrder.class);
        util.exportExcel(response, list, "生产工单数据");
    }

    /**
     * 获取生产工单详细信息
     */
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "根据主键id获取生产工单详细信息", notes = "根据主键id获取生产工单详细信息")
    @ApiImplicitParams({@ApiImplicitParam(name = "id", value = "根据主键id查询", required = false, paramType = "query")})
    public AjaxResult getInfo(@PathVariable("id") String id) {
        return AjaxResult.success(ProductionWorkOrderService.selectProductionWorkOrderById(id));
    }

    /**
     * 新建生产工单
     */
    @Log(title = "新建生产工单", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新建生产工单", notes = "新建生产工单")
    public AjaxResult add(@RequestBody ProductionWorkOrder ProductionWorkOrder) {
        return (ProductionWorkOrderService.insertProductionWorkOrder(ProductionWorkOrder));
    }

    /**
     * 修改生产工单
     */
    @Log(title = "修改生产工单", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改生产工单", notes = "修改生产工单")
    public AjaxResult edit(@RequestBody ProductionWorkOrder ProductionWorkOrder) {
        return (ProductionWorkOrderService.updateProductionWorkOrder(ProductionWorkOrder));
    }

    /**
     * 删除生产工单
     */
    @Log(title = "删除生产工单", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "根据主键id删除生产工单", notes = "根据主键id删除生产工单")
    @ApiImplicitParams({@ApiImplicitParam(name = "ids", value = "根据主键ids删除", required = false)})
    public AjaxResult remove(@PathVariable String[] ids) {
        return toAjax(ProductionWorkOrderService.deleteProductionWorkOrderByIds(ids));
    }

    /**
     * 获取订单管理详细信息
     */
    @GetMapping("selectProductionOrderByProductOrder")
    @ApiOperation(value = "生产工单-查看详情接口", notes = "生产工单-查看详情接口", response = ProductionOrder.class, produces = "application/json")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "ProductOrder", value = "根据生产订单ProductOrder查询", required = false, paramType = "query")})
    public AjaxResult selectProductionOrderByProductOrder(String ProductOrder) {
        return success(productionOrderService.selectProductionOrderById(ProductOrder));
    }

    @GetMapping("getProductionOrderTestDetail")
    @ApiOperation(value = "生产工单-查看详情接口 测试明细数据", notes = "生产工单-查看详情接口 测试明细数据", response = ProductionOrder.class, produces = "application/json")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "workOrderId", value = "根据生产工单workOrderId查询", required = false, paramType = "query")})
    public Map<String, Object> getProductionOrderTestDetail(String workOrderId) {
        return IInventoryTestRecordService.getProductionOrderTestDetail(workOrderId);
    }

    @PostMapping("/uploadFourCard")
    @ApiOperation(value = "上传4G卡", notes = "上传4G卡")
    @ApiImplicitParams({@ApiImplicitParam(name = "file", value = "文件流", required = false),})
    public AjaxResult uploadFourCard(@RequestParam(value = "file") @RequestPart MultipartFile file, String id)
            throws Exception {
        return ProductionWorkOrderService.uploadFourCard(file, id);
    }

    @PostMapping("/getWorkOrderInfo")
    public JSONObject getWorkOrderInfo(@RequestBody JSONObject json) {
        return ProductionWorkOrderService.getWorkOrderInfo(json);
    }

    @PostMapping("/noticeWorkOrderStatus")
    public JSONObject noticeWorkOrderStatus(@RequestBody JSONObject json) {
        return ProductionWorkOrderService.noticeWorkOrderStatus(json);
    }

    /**
     * 提供给产测工具查询设备配置信息
     * @param json
     * @return
     */
    @PostMapping("/selectWorkOrderDeviceConfig")
    public JSONObject selectWorkOrderDeviceConfig(@RequestBody JSONObject json) {
        return ProductionWorkOrderService.selectWorkOrderDeviceConfig(json);
    }


    @ApiOperation(value = "卡商列表", notes = "卡商列表", produces = "application/json")
    @PostMapping("/flowCorpList")
    public JSONObject flowCorpList() {
        return JSON.parseObject( imsUtil.flowCorpList(SecurityUtils.getDeptId()));
    }

    @PostMapping("/getAuthNum")
    @ApiOperation(value = "产品授权数量", notes = "产品授权数量", produces = "application/json")
    public JSONObject getAuthNum(@RequestBody AuthNumReq req) {
        Long deptId= SecurityUtils.getDeptId();
        ProductionOrder o = productionOrderService.selectProductionOrderById(req.getOrderId());

        return JSON.parseObject(imsUtil.getAuthNum(deptId,o.getAppId()));
    }


    @PostMapping("/updateStatus")
    @ApiOperation(value = "更新工单状态", notes = "更新工单状态", produces = "application/json")
    public AjaxResult updateStatus(@RequestBody UpdateStatusVo vo) {

       return ProductionWorkOrderService.updateStatus(vo.getWorkorderId(),vo.getStatus());
    }

    @GetMapping("/delete")
    @ApiOperation(value = "删除工单", notes = "删除工单", produces = "application/json")
    public AjaxResult delete(String workorderId) {

        return ProductionWorkOrderService.delete(workorderId);
    }

    @GetMapping("/licenseList")
    @ApiOperation(value = "授权明细", notes = "授权明细", produces = "application/json")
    public TableDataInfo licenseList( LicenseDataReq req) {
        startPage();
        List<LicenseData> list = ProductionWorkOrderService.licenseList(req);
        return getDataTable(list);
    }

    @Log(title = "授权明细导出", businessType = BusinessType.EXPORT)
    @PostMapping("/licenseListExport")
    @ApiOperation(value = "授权明细导出",notes = "授权明细导出")
    public void licenseListExport(HttpServletResponse response, @RequestBody LicenseDataReq licenseData) throws IOException {
        List<LicenseData> list = ProductionWorkOrderService.licenseList(licenseData);
        ExcelUtil<LicenseData> util = new ExcelUtil<LicenseData>(LicenseData.class);
        util.exportExcel(response, list, "sheet1");

    }

    @GetMapping("/thirdPartyDataList")
    @ApiOperation(value = "方案授权明细", notes = "方案授权明细", produces = "application/json")
    public TableDataInfo thirdPartyDataList( ThirdPartyDataReq req) {
        startPage();
        List<ThirdPartyData> list = ProductionWorkOrderService.thirdPartyDataList(req);
        return getDataTable(list);
    }

    @Log(title = "方案授权导出", businessType = BusinessType.EXPORT)
    @PostMapping("/thirdPartyDataExport")
    @ApiOperation(value = "方案授权导出",notes = "授方案授权导出")
    public void thirdPartyDataExport(HttpServletResponse response,@RequestBody  ThirdPartyDataReq licenseData) {
        List<ThirdPartyData> list = ProductionWorkOrderService.thirdPartyDataList(licenseData);
        List<ThirdPartyDataExport> ls= BeanUtil.copyToList(list,ThirdPartyDataExport.class);
        ExcelUtil<ThirdPartyDataExport> util = new ExcelUtil<ThirdPartyDataExport>(ThirdPartyDataExport.class);
        util.exportExcel(response, ls, "sheet1");
    }

}
