package com.productiontest.controller;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.productiontest.common.annotation.Log;
import com.productiontest.common.core.controller.BaseController;
import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.common.enums.BusinessType;
import com.productiontest.domain.ProductionWorkOrderTestdetail;
import com.productiontest.service.IProductionWorkOrderTestdetailService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 测试工单详情Controller
 * 
 * @author cf
 * @date 2023-02-16
 */
@RestController
@RequestMapping("/workordertestdetail/v1")
@Api(value = "测试工单详情", tags = "测试工单详情")
public class ProductionWorkOrderTestdetailController extends BaseController {

	@Autowired
	private IProductionWorkOrderTestdetailService productionWorkOrderTestdetailService;

	@GetMapping(value = "/selectTestDetailByworkorderId")
	@ApiOperation(value = "根据workorderId获取测试工单详情详细信息", notes = "根据workorderId获取测试工单详情详细信息")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "workorderId", value = "根据workorderId查询", required = false, paramType = "query") })
	public List<ProductionWorkOrderTestdetail> selectTestDetailByworkorderId(String workorderId) {
		return productionWorkOrderTestdetailService.selectTestDetailByworkorderId(workorderId);
	}

	/**
	 * 获取测试工单详情详细信息
	 */
	@GetMapping(value = "/{id}")
	@ApiOperation(value = "根据主键id获取测试工单详情详细信息", notes = "根据主键id获取测试工单详情详细信息")
	@ApiImplicitParams({ @ApiImplicitParam(name = "id", value = "根据主键id查询", required = false, paramType = "query") })
	public AjaxResult getInfo(@PathVariable("id") Long id) {
		return success(productionWorkOrderTestdetailService.selectProductionWorkOrderTestdetailById(id));
	}

	/**
	 * 新增测试工单详情
	 */
	@Log(title = "测试工单详情", businessType = BusinessType.INSERT)
	@PostMapping
	@ApiOperation(value = "新增测试工单详情", notes = "新增测试工单详情")
	public AjaxResult add(@RequestBody ProductionWorkOrderTestdetail productionWorkOrderTestdetail) {
		return toAjax(productionWorkOrderTestdetailService
				.insertProductionWorkOrderTestdetail(productionWorkOrderTestdetail));
	}

	/**
	 * 删除测试工单详情
	 */
	@Log(title = "测试工单详情", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
	public AjaxResult remove(@PathVariable Long[] ids) {
		return toAjax(productionWorkOrderTestdetailService.deleteProductionWorkOrderTestdetailByIds(ids));
	}
}
