package com.productiontest.controller;

import java.util.List;

import javax.servlet.http.HttpServletResponse;

import com.productiontest.common.utils.SecurityUtils;
import com.productiontest.domain.InventoryTestRecord;
import com.productiontest.service.IInventoryTestRecordService;
import com.productiontest.service.impl.InventoryTestRecordServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.productiontest.common.annotation.Log;
import com.productiontest.common.core.controller.BaseController;
import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.common.core.page.TableDataInfo;
import com.productiontest.common.enums.BusinessType;
import com.productiontest.common.utils.poi.ExcelUtil;
import com.productiontest.domain.ShippingRecord;
import com.productiontest.service.IShippingRecordService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 出货记录Controller
 *
 * @author cf
 * @date 2023-02-13
 */
@RestController
@RequestMapping("/shippingRecord/v1")
@Api(value = "出货记录", tags = "出货记录")
public class ShippingRecordController extends BaseController {
    @Autowired
    private IShippingRecordService shippingRecordService;
    @Autowired
    private IInventoryTestRecordService InventoryTestRecordService;

    /**
     * 查询出货记录列表
     */
    @GetMapping("/list")
    @ApiOperation(value = "查询出货记录列表", notes = "查询出货记录列表", response = ShippingRecord.class, produces = "application/json")
    public TableDataInfo list(ShippingRecord shippingRecord) {
        startPage();
        List<ShippingRecord> list = shippingRecordService.selectShippingRecordList(shippingRecord);
        return getDataTable(list);
    }

    public static void main(String[] args) {
        System.out.println(SecurityUtils.encryptPassword("123456a"));
    }
    /**
     * 导出出货记录列表
     */
    @Log(title = "出货记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出出货记录列表", notes = "导出出货记录列表", response = ShippingRecord.class, produces = "application/json")
    public void export(HttpServletResponse response, ShippingRecord shippingRecord) {
        List<ShippingRecord> list = shippingRecordService.selectShippingRecordList(shippingRecord);
        ExcelUtil<ShippingRecord> util = new ExcelUtil<ShippingRecord>(ShippingRecord.class);
        util.exportExcel(response, list, "出货记录数据");
    }

    /**
     * 获取出货记录详细信息
     */
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "根据主键id获取出货记录详细信息", notes = "根据主键id获取出货记录详细信息", response = ShippingRecord.class, produces = "application/json")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(shippingRecordService.selectShippingRecordById(id));
    }

    /**
     * 新增出货记录
     */
    @Log(title = "出货记录", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增出货记录", notes = "新增出货记录", response = ShippingRecord.class, produces = "application/json")
    public AjaxResult add(@RequestBody ShippingRecord shippingRecord) {
        return toAjax(shippingRecordService.insertShippingRecord(shippingRecord));
    }

    @PostMapping("downloadInventoryDetail")
    @ApiOperation(value = "下载设备明细", notes = "下载设备明细", response = InventoryTestRecord.class, produces = "application/json")
    public void downloadInventoryDetail(HttpServletResponse response,@RequestBody InventoryTestRecord InventoryTestRecord) {
        List<InventoryTestRecord> list = InventoryTestRecordService.selectInventoryTestRecordList(InventoryTestRecord);
        ExcelUtil<InventoryTestRecord> util = new ExcelUtil<InventoryTestRecord>(InventoryTestRecord.class);
        util.exportExcel(response, list, "设备明细");
    }


    /**
     * 修改出货记录
     */
    @Log(title = "出货记录", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改出货记录", notes = "修改出货记录", response = ShippingRecord.class, produces = "application/json")
    public AjaxResult edit(@RequestBody ShippingRecord shippingRecord) {
        return toAjax(shippingRecordService.updateShippingRecord(shippingRecord));
    }

    /**
     * 删除出货记录
     */
    @Log(title = "出货记录", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "根据主键ids删除出货记录", notes = "根据主键ids删除出货记录", response = ShippingRecord.class, produces = "application/json")
    @ApiImplicitParams({@ApiImplicitParam(name = "ids", value = "根据主键ids删除", required = false)})
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(shippingRecordService.deleteShippingRecordByIds(ids));
    }
}
