package com.productiontest.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.productiontest.domain.ThirdPartyData;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.productiontest.common.annotation.Log;
import com.productiontest.common.core.controller.BaseController;
import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.common.enums.BusinessType;
import com.productiontest.service.IThirdPartyDataService;
import com.productiontest.common.utils.poi.ExcelUtil;
import com.productiontest.common.core.page.TableDataInfo;

/**
 * 第三方授权Controller
 *
 * @author cf
 * @date 2023-06-15
 */
@RestController
@RequestMapping("/ThirdPartyData/v1")
@Api(tags = "第三方授权明细", value = "第三方授权明细")
public class ThirdPartyDataController extends BaseController {
    @Autowired
    private IThirdPartyDataService thirdPartyDataService;

    /**
     * 查询第三方授权列表
     */
    @GetMapping("/list")
    @ApiOperation(value = "查询第三方授权列表",notes = "查询第三方授权列表")
    public TableDataInfo list(ThirdPartyData thirdPartyData) {
        startPage();
        List<ThirdPartyData> list = thirdPartyDataService.selectThirdPartyDataList(thirdPartyData);
        return getDataTable(list);
    }

    /**
     * 导出第三方授权列表
     */
    @Log(title = "第三方授权", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出第三方授权列表",notes = "导出第三方授权列表")
    public void export(HttpServletResponse response, ThirdPartyData thirdPartyData) {
        List<ThirdPartyData> list = thirdPartyDataService.selectThirdPartyDataList(thirdPartyData);
        ExcelUtil<ThirdPartyData> util = new ExcelUtil<ThirdPartyData>(ThirdPartyData.class);
        util.exportExcel(response, list, "第三方授权数据");
    }

    /**
     * 获取第三方授权详细信息
     */
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取第三方授权详细信息",notes = "获取第三方授权详细信息")
    public AjaxResult getInfo(@PathVariable("id") String id) {
        return success(thirdPartyDataService.selectThirdPartyDataById(id));
    }

    /**
     * 新增第三方授权
     */
    @Log(title = "第三方授权", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ThirdPartyData thirdPartyData) {
        return toAjax(thirdPartyDataService.insertThirdPartyData(thirdPartyData));
    }

    /**
     * 修改第三方授权
     */
    @Log(title = "第三方授权", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ThirdPartyData thirdPartyData) {
        return toAjax(thirdPartyDataService.updateThirdPartyData(thirdPartyData));
    }

    /**
     * 删除第三方授权
     */
    @Log(title = "删除第三方授权", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除第三方授权",notes = "删除第三方授权")
    public AjaxResult remove(@PathVariable String[] ids) {
        return toAjax(thirdPartyDataService.deleteThirdPartyDataByIds(ids));
    }
}
