package com.productiontest.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.productiontest.common.annotation.Log;
import com.productiontest.common.core.controller.BaseController;
import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.common.enums.BusinessType;
import com.productiontest.domain.UpdateOrderLog;
import com.productiontest.service.IUpdateOrderLogService;
import com.productiontest.common.utils.poi.ExcelUtil;
import com.productiontest.common.core.page.TableDataInfo;
@RestController
@RequestMapping("/updateOrderLog/v1")
@Api(value = "修改日志、订单或工单", tags = "修改日志、订单或工单")
public class UpdateOrderLogController extends BaseController {


    @Autowired
    private IUpdateOrderLogService updateUpdateorderLog;

    /**
     * 查询修改日志-订单、工单列表
     */

    @GetMapping("/list")
    @ApiOperation(value = "查询修改日志-订单、工单列表",notes = "查询修改日志-订单、工单列表")
    public TableDataInfo list(UpdateOrderLog updateorderLog)
    {
        startPage();
        List<UpdateOrderLog> list =updateUpdateorderLog.selectUpdateOrderLogList(updateorderLog);
        return getDataTable(list);
    }

    /**
     * 导出修改日志-订单、工单列表
     */
    @Log(title = "修改日志-订单、工单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, UpdateOrderLog updateorderLog)
    {
        List<UpdateOrderLog> list = updateUpdateorderLog.selectUpdateOrderLogList(updateorderLog);
        ExcelUtil<UpdateOrderLog> util = new ExcelUtil<UpdateOrderLog>(UpdateOrderLog.class);
        util.exportExcel(response, list, "修改日志-订单、工单数据");
    }

    /**
     * 获取修改日志-订单、工单详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(updateUpdateorderLog.selectUpdateOrderLogById(id));
    }

    /**
     * 新增修改日志-订单、工单
     */
    @Log(title = "修改日志-订单、工单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody UpdateOrderLog updateorderLog)
    {
        return toAjax(updateUpdateorderLog.insertUpdateOrderLog(updateorderLog));
    }

    /**
     * 修改修改日志-订单、工单
     */
    @Log(title = "修改日志-订单、工单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody UpdateOrderLog updateorderLog)
    {
        return toAjax(updateUpdateorderLog.updateUpdateOrderLog(updateorderLog));
    }

    /**
     * 删除修改日志-订单、工单
     */
    @Log(title = "修改日志-订单、工单", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(updateUpdateorderLog.deleteUpdateOrderLogByIds(ids));
    }


}
