package com.productiontest.domain;

import com.alibaba.fastjson2.JSON;
import com.productiontest.common.annotation.Excel;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

import java.util.List;
import java.util.Map;

/**
 * PCBA生产工单对象 pcba_work_order
 *
 * @author cf
 * @date 2023-02-07
 */
@Getter
@Setter
@ToString
public class ProductionWorkOrder {

    /**
     * 主键id
     */
    private String id;

    /**
     * 工单ID
     */
    @Excel(name = "工单ID")
    @ApiModelProperty("工单ID")
    private String workorderId;

    @Excel(name = "工单编号")
    @ApiModelProperty("工单编号")
    private String workorderNo;

    /**
     * 工单名称
     */
    @Excel(name = "工单名称")
    @ApiModelProperty("工单名称")
    private String workorderName;

    @Excel(name = "工单类型")
    @ApiModelProperty("工单类型 0:pcba 1:整机")
    private String workorderType;

    @Excel(name = "工单完成时间")
    private String finishTime;

    /**
     * 生产订单
     */
    @Excel(name = "生产订单")
    private String productOrderName;

    @ApiModelProperty("生产订单 存订单id")
    private String productOrder;

    /**
     * 生产数量
     */
    @Excel(name = "生产数量")
    @ApiModelProperty("生产数量")
    private int productNumber;

    @ApiModelProperty("已生产数量")
    private int finishNumber;

    /**
     * 工位账号
     */
    @Excel(name = "工位账号")
    @ApiModelProperty("工位账号")
    private String stationAccountName;

    @Excel(name = "创建时间")
    @ApiModelProperty("创建时间")
    private String createTime;

    private String stationAccount;

    /**
     * 生产进度
     */
    @Excel(name = "生产进度")
    @ApiModelProperty("生产进度")
    private String productSchedule;

    /**
     * 工单状态
     */
    @Excel(name = "工单状态")
    private String workorderStatusName;

    @ApiModelProperty("工单状态")
    private Long workorderStatus;

    @ApiModelProperty("订单名称")
    private String orderName;

    @Excel(name = "备注")
    @ApiModelProperty("备注")
    private String remark;

    @Excel(name = "企业id")
    @ApiModelProperty("企业id")
    private String companyId;

    // 未开始
    private Long notStarted;
    // 生产测试中
    private Long productionTest;
    // 生产完成
    private Long productionComplete;
    // 已取消
    private Long cancel;

    private String account;

    @ApiModelProperty(value = "测试项")
    private String testItem;

    // 人员操作标识 0 结束，1 开始
    private Long operationStatus;

    private String finishFlag;

    @Excel(name = "所属企业")
    @ApiModelProperty("所属企业")
    private Long deptId;

    private String beginTime;

    private String endTime;

    @ApiModelProperty("授权剩余")
    private String accreditRemaining;

    //通讯方式
    private String netAccessType;
    //工单通过数量
    private String workOrderPassedNum;
    //工单总数量
    private String workOrderTotalNumber;

    private List<ProductionTestUser> userList;

    private String userListJson;

    private String pushStatus;

    //License剩余授权
    private String licenseUsableAuth;
    //订单授权总量
    private String licenseTotalNum;

    private String del;

    @ApiModelProperty(value = "固件文件")
    private String romFile;

    @ApiModelProperty("固件版本")
    private String firmwareVersion;

    //设备配置
    @ApiModelProperty("设备配置")
    private String deviceConfigFile;

    @ApiModelProperty("设备配置MD5")
    private String deviceConfigMd;

    @ApiModelProperty("标签模板ID")
    private String templateId;

    @ApiModelProperty("配置参数")
    private String argumentConfig;

    @ApiModelProperty("设备配置类型")
    private Integer configType;

    private String argumentConfigLabel;

    @ApiModelProperty("固件模板ID")
    private Integer firmwareConfigId;

    private Map<String,Object> firmwareConfig;

    @ApiModelProperty("固件MD5值")
    private String romFileMd;

    private String sign;

    /**
     * license文件
     */
    @ApiModelProperty(value = "license文件")
    private String licenseFile;

    @ApiModelProperty("上传license 对应id")
    private String mark;

    @ApiModelProperty(value = "按规则生成license数量")
    private Integer licenseNum;

    @ApiModelProperty("卡商")
    private String corps;

    @ApiModelProperty("第三方授权文件")
    private String thirdPartyFile;

    public void setFirmwareConfig(Object firmwareConfig) {
        if(firmwareConfig instanceof CharSequence){
            this.firmwareConfig = JSON.parseObject((String)firmwareConfig);
        }else {
            this.firmwareConfig = (Map<String, Object>) firmwareConfig;
        }
    }

}
