package com.productiontest.encapsulation;

import com.productiontest.common.utils.poi.ExcelUtil;
import com.productiontest.domain.LicenseData;
import com.productiontest.domain.ThirdPartyData;
import com.productiontest.util.BaseUtil;
import org.apache.commons.codec.digest.DigestUtils;

import java.io.*;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.Base64;
import java.util.List;
import java.util.zip.ZipEntry;
import java.util.zip.ZipInputStream;

public class ThirdPartyReadTool {

    /**
     * 读取bin文件 base64解码
     *
     * @param url
     * @return
     */
    public List<ThirdPartyData> zipReadBin(String url) {
        List<ThirdPartyData> dataList = new ArrayList<ThirdPartyData>();
        try {
            InputStream fis = new FileInputStream(url);
            ZipInputStream zis = new ZipInputStream(fis, Charset.forName("GBK"));
            ZipEntry zipEntry = zis.getNextEntry();
            while (zipEntry != null) {
                // 如果该项是一个文件
                if (!zipEntry.isDirectory()) {
                    String fileName = zipEntry.getName().substring(zipEntry.getName().lastIndexOf("/") + 1);
                    String suffix = fileName.substring(fileName.lastIndexOf(".") + 1);
                    if (suffix.equals("bin")) {
                        ByteArrayOutputStream bos = new ByteArrayOutputStream();
                        byte[] buffer = new byte[256];
                        int len;
                        while ((len = zis.read(buffer)) > 0) {
                            bos.write(buffer, 0, len);
                        }
                        String sign = DigestUtils.md5Hex(buffer);
                        System.out.println(Base64.getEncoder().encodeToString(buffer));
                        ThirdPartyData thirdPartyData = new ThirdPartyData();
                        thirdPartyData.setBaseCode(Base64.getEncoder().encodeToString(buffer));
                        thirdPartyData.setMdConfig(sign);
                        thirdPartyData.setFileName(fileName);
                        dataList.add(thirdPartyData);
                    }
                }
                zis.closeEntry();
                zipEntry = zis.getNextEntry();
            }

            zis.close();
            fis.close();
        } catch (
                IOException e) {
            e.printStackTrace();
        }
        return dataList;
    }

    /**
     * 读取excel
     *
     * @param url
     * @return
     */
    public List<ThirdPartyData> excelRead(String url) {
        List<ThirdPartyData> dataList = new ArrayList<>();
        try {
            ExcelUtil<ThirdPartyData> util = new ExcelUtil<ThirdPartyData>(ThirdPartyData.class);
            List<ThirdPartyData> thirdPartyDataList = util.importExcel(new FileInputStream(url));
            thirdPartyDataList.forEach(x -> {
                ThirdPartyData thirdPartyData = new ThirdPartyData();
                thirdPartyData.setBaseCode(x.getBaseCode());
                dataList.add(thirdPartyData);
            });
        } catch (Exception e) {
            e.printStackTrace();
        }
        return dataList;
    }

    /**
     * 读取txt文件
     *
     * @param url
     * @return
     */
    public List<ThirdPartyData> txtRead(String url) {
        List<ThirdPartyData> dataList = new ArrayList<>();
        try {
            InputStream inputStream = new FileInputStream(url);//创建最基本的流
            //将InputStreamReader包裹在BufferedReader中以获得最佳效率。
            BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(inputStream));
            String strTmp = "";
            while ((strTmp = bufferedReader.readLine()) != null) {
                ThirdPartyData thirdPartyData = new ThirdPartyData();
                thirdPartyData.setBaseCode(strTmp);
                dataList.add(thirdPartyData);
            }
            bufferedReader.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return dataList;
    }
}
