package com.productiontest.service;

import java.util.List;
import java.util.Map;

import com.alibaba.fastjson2.JSONObject;
import com.productiontest.vo.LicenseProductStatistics;
import org.springframework.web.multipart.MultipartFile;

import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.domain.ProductionOrder;
import com.productiontest.domain.ShippingRecord;

/**
 * 订单管理Service接口
 *
 * @author cf
 * @date 2023-02-13
 */
public interface IProductionOrderService {
    /**
     * 查询订单管理
     *
     * @param id 订单管理主键
     * @return 订单管理
     */
    public ProductionOrder selectProductionOrderById(String id);

    /**
     * 查询订单管理列表
     *
     * @param productionOrder 订单管理
     * @return 订单管理集合
     */
    public List<ProductionOrder> selectProductionOrderList(ProductionOrder productionOrder);

    /**
     * 新增订单管理
     *
     * @param productionOrder 订单管理
     * @return 结果
     */
    public AjaxResult insertProductionOrder(ProductionOrder productionOrder);

    /**
     * 修改订单管理
     *
     * @param productionOrder 订单管理
     * @return 结果
     */
    public AjaxResult updateProductionOrder(ProductionOrder productionOrder);

    /**
     * 批量删除订单管理
     *
     * @param ids 需要删除的订单管理主键集合
     * @return 结果
     */
    public int deleteProductionOrderByIds(String[] ids);

    /**
     * 删除订单管理信息
     *
     * @param id 订单管理主键
     * @return 结果
     */
    public int deleteProductionOrderById(String id);

    public AjaxResult uploadFileReadFile(MultipartFile file);

    public Map<Object, Object> selectProductionOrderDeliveryDetail(ProductionOrder productionOrder);

    public AjaxResult insertShippingRecordByProductionOrder(ShippingRecord sr);

    public Map<Object, Object> getSelectProductionOrderStatistics();

    List<ProductionOrder> selectProductionOrderListByNewDate(ProductionOrder po);

    List<Map<Object, Object>> selectProductionOrderStatisticsByEcharts();

    AjaxResult uploadEquipment(MultipartFile file);

    List<ProductionOrder> getListProductionOrderNoPage(ProductionOrder productionOrder);

    JSONObject getOrderDetail(JSONObject json);

    LicenseProductStatistics selectLicenseCountByMark(String mark);

    AjaxResult uploadDeviceConfigFile(MultipartFile file);

    List<ProductionOrder> getListFile(String params);


    AjaxResult uploadThirdFile(MultipartFile file);

    LicenseProductStatistics selectThirdCountByOrderId(String orderId);
}
