package com.productiontest.service;

import java.util.List;

import com.alibaba.fastjson2.JSONObject;
import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.domain.LicenseData;
import com.productiontest.domain.ProductionWorkOrder;
import com.productiontest.domain.ThirdPartyData;
import com.productiontest.vo.LicenseDataReq;
import com.productiontest.vo.ThirdPartyDataReq;
import org.springframework.web.multipart.MultipartFile;

/**
 * PCBA生产工单Service接口
 * 
 * @author cf
 * @date 2023-02-07
 */
public interface IProductionWorkOrderService {
	/**
	 * 查询PCBA生产工单
	 * 
	 * @param id
	 *            PCBA生产工单主键
	 * @return PCBA生产工单
	 */
	public ProductionWorkOrder selectProductionWorkOrderById(String id);

	/**
	 * 查询PCBA生产工单列表
	 * 
	 * @param ProductionWorkOrder
	 *            PCBA生产工单
	 * @return PCBA生产工单集合
	 */
	public List<ProductionWorkOrder> selectProductionWorkOrderList(ProductionWorkOrder ProductionWorkOrder);

	/**
	 * 新增PCBA生产工单
	 * 
	 * @param ProductionWorkOrder
	 *            PCBA生产工单
	 * @return 结果
	 */
	public AjaxResult insertProductionWorkOrder(ProductionWorkOrder ProductionWorkOrder);

	/**
	 * 修改PCBA生产工单
	 * 
	 * @param ProductionWorkOrder
	 *            PCBA生产工单
	 * @return 结果
	 */
	public AjaxResult updateProductionWorkOrder(ProductionWorkOrder ProductionWorkOrder);

	/**
	 * 批量删除PCBA生产工单
	 * 
	 * @param ids
	 *            需要删除的PCBA生产工单主键集合
	 * @return 结果
	 */
	public int deleteProductionWorkOrderByIds(String[] ids);

	/**
	 * 删除PCBA生产工单信息
	 * 
	 * @param id
	 *            PCBA生产工单主键
	 * @return 结果
	 */
	public int deleteProductionWorkOrderById(String id);

	public ProductionWorkOrder getStatisticsProductionWorkOrder(ProductionWorkOrder ProductionWorkOrder);

	public int selectProductionWorkOrderCount(ProductionWorkOrder ProductionWorkOrder);

	public JSONObject getWorkOrderList(JSONObject json);

	public JSONObject getWorkOrderInfo(JSONObject json);

	public JSONObject noticeWorkOrderStatus(JSONObject json);

    AjaxResult uploadFourCard(MultipartFile file,String id);

    AjaxResult selectWorkOrderUserListById(String id);

    JSONObject selectWorkOrderDeviceConfig(JSONObject json);

	AjaxResult updateStatus(String workorderId,Long status);
	AjaxResult delete(String workorderId);

	List<LicenseData> licenseList(LicenseDataReq req);
	List<ThirdPartyData> thirdPartyDataList(ThirdPartyDataReq req);

	public void licenseRecycle(String workodrderId);
}
