package com.productiontest.service.impl;

import java.io.File;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

import cn.hutool.core.io.FileUtil;
import com.alibaba.fastjson2.JSONObject;
import com.productiontest.common.config.RuoYiConfig;
import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.common.utils.SecurityUtils;
import com.productiontest.constant.CodeConstant;
import com.productiontest.domain.AgingTaskDetail;
import com.productiontest.domain.LicenseData;
import com.productiontest.encapsulation.LicenseReadTool;
import com.productiontest.encapsulation.MultipartFileReadTool;
import com.productiontest.mapper.AgingTaskDetailMapper;
import com.productiontest.util.ConnectUtil;
import com.productiontest.util.QcloudUtil;
import com.productiontest.util.ToolUtil;
import com.productiontest.util.UUIDGenerator;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.productiontest.domain.AgingTask;
import com.productiontest.mapper.AgingTaskMapper;
import com.productiontest.service.IAgingTaskService;
import org.springframework.web.multipart.MultipartFile;

/**
 * 老化任务Service业务层处理
 *
 * @author cf
 * @date 2023-02-15
 */
@Service
public class AgingTaskServiceImpl implements IAgingTaskService {
    @Autowired
    private AgingTaskMapper agingTaskMapper;

    @Autowired
    private AgingTaskDetailMapper agingTaskDetailMapper;

    SimpleDateFormat sd = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

    /**
     * 查询老化任务
     *
     * @param id 老化任务主键
     * @return 老化任务
     */
    @Override
    public AgingTask selectAgingTaskById(String id) {
        return agingTaskMapper.selectAgingTaskById(id);
    }

    /**
     * 查询老化任务列表
     *
     * @param agingTask 老化任务
     * @return 老化任务
     */
    @Override
    public List<AgingTask> selectAgingTaskList(AgingTask agingTask) {
        agingTask.setDeptId(SecurityUtils.getDeptId());
        return agingTaskMapper.selectAgingTaskList(agingTask);
    }

    /**
     * 新增老化任务
     *
     * @param agingTask 老化任务
     * @return 结果
     */
    @Override
    public int insertAgingTask(AgingTask agingTask) {
        JSONObject js = JSONObject.parseObject(agingTask.getDeviceFile());
        List<String> deviceList = new LicenseReadTool().excelRead(RuoYiConfig.getUploadPath() + js.getString("name"));

        agingTask.setDeptId(SecurityUtils.getDeptId());
        agingTask.setEquipmentNumber(deviceList.size());
        agingTask.setId(UUIDGenerator.getUUID());
        agingTask.setCreateTime(sd.format(new Date()));
        agingTask.setTaskStatus(0L);
        int count = agingTaskMapper.insertAgingTask(agingTask);
        if (deviceList.size() > 0) {
            deviceList.stream().forEach(x -> {
                AgingTaskDetail agingTaskDetail = new AgingTaskDetail();
                agingTaskDetail.setId(UUIDGenerator.getUUID());
                agingTaskDetail.setAgingTaskId(agingTask.getId());
                agingTaskDetail.setDeviceSn(x);
                agingTaskDetail.setCreateTime(sd.format(new Date()));
                agingTaskDetailMapper.insertAgingTaskDetail(agingTaskDetail);
            });

        }
//        JSONObject object = new JSONObject();
//        object.put("taskId", agingTask.getId());
//        object.put("beginTime", agingTask.getBeginTime());
//        object.put("endTime", agingTask.getEndTime());
//        object.put("deviceList", deviceList);
//        ConnectUtil.connectPost(RuoYiConfig.getSdkIp() + "", object);


        return count;
    }

    /**
     * 修改老化任务
     *
     * @param agingTask 老化任务
     * @return 结果
     */
    @Override
    public int updateAgingTask(AgingTask agingTask) {
        agingTask.setPushStatus("wait");
        AgingTask task = agingTaskMapper.selectAgingTaskById(agingTask.getId());
        JSONObject js1 = JSONObject.parseObject(agingTask.getDeviceFile());
        JSONObject js2 = JSONObject.parseObject(task.getDeviceFile());
        if (!js1.get("url").equals(js2.get("url"))) {
            List<String> deviceList = new LicenseReadTool().excelRead(RuoYiConfig.getUploadPath() + js1.getString("name"));
            if (deviceList.size() > 0) {
                deviceList.stream().forEach(x -> {
                    AgingTaskDetail agingTaskDetail = new AgingTaskDetail();
                    agingTaskDetail.setId(UUIDGenerator.getUUID());
                    agingTaskDetail.setAgingTaskId(agingTask.getId());
                    agingTaskDetail.setDeviceSn(x);
                    agingTaskDetail.setCreateTime(sd.format(new Date()));
                    agingTaskDetailMapper.insertAgingTaskDetail(agingTaskDetail);
                });
            }
        }
        return agingTaskMapper.updateAgingTask(agingTask);
    }

    /**
     * 批量删除老化任务
     *
     * @param ids 需要删除的老化任务主键
     * @return 结果
     */
    @Override
    public int deleteAgingTaskByIds(String[] ids) {
        Arrays.asList(ids).stream().forEach(x -> {
            agingTaskDetailMapper.deleteAgingTaskDetailByTaskId(x);
        });
        return agingTaskMapper.deleteAgingTaskByIds(ids);
    }

    /**
     * 删除老化任务信息
     *
     * @param id 老化任务主键
     * @return 结果
     */
    @Override
    public int deleteAgingTaskById(String id) {
        return agingTaskMapper.deleteAgingTaskById(id);
    }

    /**
     * 停止老化任务
     * @param agingTask
     * @return
     */
    @Override
    public int stopAgingTask(AgingTask agingTask) {
        int res = agingTaskMapper.updateAgingTask(agingTask);
        JSONObject object = new JSONObject();
        object.put("taskId", agingTask.getId());
        ConnectUtil.connectPost(RuoYiConfig.getSdkIp() + "", object);
        return res;
    }

    @Override
    public AjaxResult uploadDeviceFile(MultipartFile file) {
        AjaxResult ajax = new AjaxResult();
        String filePath = RuoYiConfig.getUploadPath();
        String suffix = file.getOriginalFilename().substring(file.getOriginalFilename().lastIndexOf(".") + 1);
        try {
            List<String> repeatList = new ArrayList<>();
            if (suffix.equals("xls") || suffix.equals("xlsx")) {
                repeatList = new MultipartFileReadTool().licenseReadExcel(file);
            } else if (suffix.equals("txt")) {
                repeatList = new MultipartFileReadTool().txtRead(file);
            }
            List<String> collect = repeatList.stream().collect(Collectors.groupingBy(e -> e, Collectors.counting()))
                    .entrySet().stream().filter(e -> e.getValue() > 1)
                    .map(Map.Entry::getKey).collect(Collectors.toList());


            if (collect.size() > 0) {
                ajax.put("code", CodeConstant.RepeatLicenseCode);
                ajax.put("设备:", StringUtils.join(collect, ","));
                ajax.put("message", "设备重复存在:" + StringUtils.join(collect, ","));
                return ajax;
            }
            if (repeatList.size() < 1) {
//                throw new ServiceException("单次只支持上传10000个授权,请重新上传");
                ajax.put("message", "当前文件0设备,请重新上传");
                ajax.put("code", CodeConstant.NoContentCode);
                return ajax;
            }

            if (repeatList.size() > 1000) {
//                throw new ServiceException("单次只支持上传10000个授权,请重新上传");
                ajax.put("message", "单次只支持上传1000个台设备,请重新上传");
                ajax.put("code", CodeConstant.MaxDeviceCode);
                return ajax;
            }

            File fe = new File(filePath);
            if (!fe.exists()) {
                fe.mkdirs();
            }
            String path = filePath + file.getOriginalFilename();
            FileUtil.writeBytes(file.getBytes(), path);
            ajax.put("httpUrl", "");
            if (new ToolUtil().getNetwork()) {
                // 上传文件到oss中
                Map<String, String> map = new QcloudUtil().uploadFileInput(file);
                if (map.get("code").equals("200")) {
                    ajax.put("httpUrl", map.get("url"));
                }
            }
            ajax.put("newFileName", file.getOriginalFilename());
            ajax.put("originalFilename", file.getOriginalFilename());
            ajax.put("fileName", file.getOriginalFilename());
            ajax.put("url", RuoYiConfig.getNginxFile() + file.getOriginalFilename());

        } catch (Exception e) {
            ajax.put("code", CodeConstant.uploadErrorCode);
            e.printStackTrace();
        }
        return ajax;
    }


    @Override
    public int noticeAgingTask(JSONObject json) {
        String taskId=json.getString("");

        AgingTask agingTask=new AgingTask();
        agingTask.setId(taskId);
        agingTask.setTaskStatus(1L);
        return agingTaskMapper.updateAgingTask(agingTask);
    }
}
