package com.productiontest.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson2.JSONObject;
import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.domain.*;
import com.productiontest.mapper.*;
import com.productiontest.service.IInventoryTestRecordService;
import com.productiontest.util.DateTool;
import com.productiontest.util.UUIDGenerator;
import com.productiontest.vo.WorkTestStatistics;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 生产库存-测试记录Service业务层处理
 *
 * @author cf
 * @date 2023-02-16
 */
@Service
public class InventoryTestRecordServiceImpl implements IInventoryTestRecordService {
    @Resource
    private InventoryTestRecordMapper inventoryTestRecordMapper;
    @Resource
    private ProductionWorkOrderMapper productionworkordermapper;
    @Resource
    private ProductionOrderMapper productionordermapper;
    @Resource
    private ProductionWorkOrderTestdetailMapper productionworkordertestdetailmapper;
    @Resource
    private ProductionInventoryMapper productioninventorymapper;
    @Resource
    private DataDictionaryMapper DataDictionaryMapper;
    @Resource
    private ProductionTestUserMapper ProductionTestUserMapper;
    @Resource
    private LicenseDataMapper licensedatamapper;
    @Resource
    private ThirdPartyDataMapper thirdPartyDataMapper;

    private static final Logger logger = LoggerFactory.getLogger(InventoryTestRecordServiceImpl.class);

    /**
     * 查询生产库存-测试记录
     *
     * @param id 生产库存-测试记录主键
     * @return 生产库存-测试记录
     */
    @Override
    public InventoryTestRecord selectInventoryTestRecordById(Long id) {
        return inventoryTestRecordMapper.selectInventoryTestRecordById(id);
    }

    /**
     * 查询生产库存-测试记录列表
     *
     * @param inventoryTestRecord 生产库存-测试记录
     * @return 生产库存-测试记录
     */
    @Override
    public List<InventoryTestRecord> selectInventoryTestRecordList(InventoryTestRecord inventoryTestRecord) {
        return inventoryTestRecordMapper.selectInventoryTestRecordList(inventoryTestRecord);
    }

    /**
     * 新增生产库存-测试记录
     *
     * @param inventoryTestRecord 生产库存-测试记录
     * @return 结果
     */
    @Override
    public int insertInventoryTestRecord(InventoryTestRecord inventoryTestRecord) {
        inventoryTestRecord.setId(UUIDGenerator.getUUID());
        return inventoryTestRecordMapper.insertInventoryTestRecord(inventoryTestRecord);
    }

    /**
     * 修改生产库存-测试记录
     *
     * @param inventoryTestRecord 生产库存-测试记录
     * @return 结果
     */
    @Override
    public int updateInventoryTestRecord(InventoryTestRecord inventoryTestRecord) {
        return inventoryTestRecordMapper.updateInventoryTestRecord(inventoryTestRecord);
    }

    /**
     * 批量删除生产库存-测试记录
     *
     * @param ids 需要删除的生产库存-测试记录主键
     * @return 结果
     */
    @Override
    public int deleteInventoryTestRecordByIds(Long[] ids) {
        return inventoryTestRecordMapper.deleteInventoryTestRecordByIds(ids);
    }

    /**
     * 删除生产库存-测试记录信息
     *
     * @param id 生产库存-测试记录主键
     * @return 结果
     */
    @Override
    public int deleteInventoryTestRecordById(Long id) {
        return inventoryTestRecordMapper.deleteInventoryTestRecordById(id);
    }


    @Override
    public JSONObject uploadTestResult(JSONObject js) {
        // TODO Auto-generated method stub
        SimpleDateFormat sd = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        JSONObject json = new JSONObject();
        InventoryTestRecord itr = new InventoryTestRecord();
        Map<String, Object> map = new HashMap<String, Object>();
        try {
            // 先查询工单的订单id
            ProductionWorkOrder work = productionworkordermapper
                    .selectProductionWorkOrderByWorkOrderId(js.getString("WorkOrderId"));
            ProductionTestUser testUser = ProductionTestUserMapper.selectProductionTestUserByUserName(js.getString("Account"));

            // 在根据订单的id查询出来订单编号
            ProductionOrder order = productionordermapper.selectProductionOrderById(work.getProductOrder());
            ProductionInventory tory = new ProductionInventory();
            tory.setProductionId(js.getString("DeviceSN"));
            tory.setPcbaWorkorder(js.getString("WorkOrderId"));
            List<ProductionInventory> list = productioninventorymapper.getProductionInventoryList(tory);
            tory.setDeptId(testUser.getDeptId());
            tory.setOrderNo(order.getOrderNo());
            tory.setDeliveryTime(sd.format(new Date()));
            tory.setApplicationState(0L);
            tory.setInventoryType(Long.parseLong(work.getWorkorderType()));
            tory.setCompanyId(order.getCompanyId());
            tory.setAppId(order.getAppId());
            tory.setEquipmentLicense(js.getString("CTEI"));

//            List<String> license = licensedatamapper.selectLicenseDataListString(order.getMark());
            if (list.size() > 0) {
                tory.setId(list.get(0).getId());
                tory.setPushStatus("wait");
                productioninventorymapper.updateProductionInventory(tory);
            } else {
                tory.setId(UUIDGenerator.getUUID());
                productioninventorymapper.insertProductionInventory(tory);
            }
            logger.info("getWorkorderType", work.getWorkorderType());
            logger.error("TestResult:", js.getString("TestResult"));
            if (work.getWorkorderType().equals("1")  && (js.getString("TestResult").equals(1) ||
                    js.getString("TestResult").equals("1"))) {

                //更新第三方授权烧录状态
                ThirdPartyData partyData = new ThirdPartyData();
                partyData.setBaseCode(js.getString("FirmwareAuthID"));
                List<ThirdPartyData> thirdPartyDataList = thirdPartyDataMapper.getThirdPartyDataBaseCode(partyData);
                if (thirdPartyDataList.size() > 0) {
                    ThirdPartyData ta=new ThirdPartyData();
                    ta.setId(thirdPartyDataList.get(0).getId());
                    ta.setBurnStatus("1");
                    ta.setPushStatus("wait");
                    thirdPartyDataMapper.updateThirdPartyData(ta);
                }

                LicenseData ld = new LicenseData();
                ld.setLicense(js.getString("CTEI"));
                List<LicenseData> data = licensedatamapper.selectList(ld);
                if (data.size() > 0) {
                    data.stream().forEach(x->{
                        ld.setId(x.getId());
                        ld.setBurnStatus("1");
                        ld.setBurnTime(new Date());
                        ld.setPushStatus("wait");
                        if (thirdPartyDataList.size() > 0) {
                            ld.setThirdParty(x.getId());
                        }
                        licensedatamapper.updateLicenseData(ld);
                    });

                }

            }


            ProductionOrder der1 = new ProductionOrder();
            der1.setId(order.getId());
            der1.setOrderStatus(1L);
            der1.setPushStatus("wait");
            productionordermapper.updateProductionOrder(der1);

            itr.setId(UUIDGenerator.getUUID());
            itr.setProductionInventoryId(tory.getId());
            itr.setDeviceSn(js.getString("DeviceSN"));
            itr.setCetl(js.getString("CTEI"));
            itr.setWorkOrderId(js.getString("WorkOrderId"));
            itr.setTestResult(js.getString("TestResult"));
            itr.setSpendTime(js.getString("SpendTime"));
            itr.setItemJson(js.getString("FailedITems"));
            itr.setTestUser(js.getString("Account"));
            itr.setFirmwareAuthId(js.getString("FirmwareAuthID"));

            itr.setBeginTime(sd.format(new Date()));
            itr.setEndTime(sd.format(new Date().getTime() + Long.parseLong(js.getString("SpendTime"))));
            // 获取到所有的设备测试结果集合

            inventoryTestRecordMapper.insertInventoryTestRecord(itr);
            json.put("CODE", 0);
            List<InventoryTestRecord> data = inventoryTestRecordMapper
                    .selectInventoryTestRecordByWordOrderId(itr.getWorkOrderId());

            // 过滤出测试结果通过的数据
//            List<InventoryTestRecord> listpass = data.stream().filter(x -> x.getTestResult().equals("1"))
//                    .collect(Collectors.toList());
//            // 过滤出测试结果未通过的数据
//            List<InventoryTestRecord> listnopass = data.stream().filter(x -> x.getTestResult().equals("0"))
//                    .collect(Collectors.toList());

            List<String> listPass = productionworkordermapper.selectCountWorkOrderInDeviceSn(js.getString("WorkOrderId"), "1");
//            List<String> listNoPass = productionworkordermapper.selectCountWorkOrderInDeviceSn(js.getString("WorkOrderId"),"1");

            if (listPass.size() >= work.getProductNumber()) {
                ProductionWorkOrder wo = new ProductionWorkOrder();
                wo.setId(work.getId());
                wo.setWorkorderStatus(2L);
                wo.setFinishTime(sd.format(new Date()));
                wo.setOperationStatus(0L);
                wo.setPushStatus("wait");
                productionworkordermapper.updateProductionWorkOrder(wo);
            }
            int testCount = inventoryTestRecordMapper.selectCountTestRecordInOrder(js.getString("WorkOrderId"));
            if (testCount >= order.getProductionQuantity()) {
                ProductionOrder der = new ProductionOrder();
                der.setId(order.getId());
                der.setOrderStatus(2L);
                der.setPushStatus("wait");
                productionordermapper.updateProductionOrder(der);
            }
            int result = productioninventorymapper.selectCountByWorkOrderId(itr.getWorkOrderId());
            if (data.size() > 0) {
                Map<Object, Object> testMap = productionworkordertestdetailmapper
                        .selectTestDetailSumByworkorderId(js.getString("WorkOrderId"));
                map.put("SpendTime", 0); // 测试花费总时间
                map.put("PassedNum", 0);// 测试通过数目
                map.put("FailedNum", 0);// 测试未通过数目
                map.put("TotalProduceNum", listPass.size());// 工单已经生产通过数目
            } else {
                map.put("SpendTime", 0);
                map.put("PassedNum", 0);
                map.put("FailedNum", 0);
                map.put("TotalProduceNum", "");
            }
            map.put("CTEITotalNum", order.getLicenseTotalNum());
            map.put("CTEIRemainNum", order.getUsableAuth());
            json.put("BODY", map);
        } catch (Exception e) {
            json.put("CODE", -1);
            e.printStackTrace();
        }
        return json;
    }

    public static void main(String[] args) throws IOException {
        String result = "[\"101\", \"104\", \"105\"]";
       String str=result.replaceAll("\\[", "")
              .replaceAll("\\]", "").replaceAll("\"", "");
       Arrays.asList(str.split(",")).forEach(a->{
           System.out.println(a.trim());
       });

    }


    @Override
    public Map<String, Object> getProductionOrderTestDetail(String workOrderId) {
        Map<String, Object> map = inventoryTestRecordMapper.getProductionOrderTestDetail(workOrderId);
        List<String> noPassList = inventoryTestRecordMapper.selectTestResultList(workOrderId);
        List<String> list = new ArrayList<>();
        if (noPassList.size() > 0) {
            noPassList.stream().forEach(a -> {
                if(ObjectUtil.isNotNull(a)) {
                    String as = a.replaceAll("\\[", "")
                            .replaceAll("\\]", "").replaceAll("\"", "");
                    Arrays.asList(as.split(",")).forEach(c->{
                        DataDictionary data = DataDictionaryMapper.selectDataDictionaryByDataNo(c, "测试项");
                        if (ObjectUtil.isNotNull(data)) {
                            list.add(data.getDataKey());
                        }
                    });

                }
            });
        }


        if (map != null) {
//            if (map.containsKey("TestNo")) {
//                String str = map.get("TestNo").toString().replaceAll("\\[\"", "").replaceAll("]", "").replaceAll("\"", "").replaceAll("\\\"]", "");
//                if (StringUtils.isNotEmpty(str)) {
//                    String[] strSp = str.split(",");
//                    Arrays.asList(strSp).forEach(x -> {
//
//                        if (data != null) {
//                            list.add(data.getDataKey());
//                        }
//                    });
//                }
//            }
            map.put("testItem", list.stream().distinct().collect(Collectors.toList()));
        } else {
            map = new HashMap<>();
            map.put("beginTime", "");
            map.put("endTime", "");
            map.put("testSumduration", "");
            map.put("testCount", "");
            map.put("passCount", "");
            map.put("passRate", "");
            map.put("psc", "");
            map.put("testItem", list);
            map.put("exceptionNum", 0);
        }
        return map;
    }

    @Override
    public JSONObject selectDeviceSNByLicense(JSONObject js) {
        JSONObject json = new JSONObject();
        String license = js.getString("License");
        Map<String, Object> map = new HashMap<String, Object>();
        String sn = inventoryTestRecordMapper.selectDeviceSNByLicense(license);
        map.put("DeviceSn", sn);
        json.put("CODE", 0);
        json.put("BODY", map);

        return json;
    }

    @Override
    public AjaxResult selectTestTotal(String wordOderId) {
        Map<String, Object> map = new HashMap<>();
        InventoryTestRecord inventoryTestRecord = inventoryTestRecordMapper.selectDateByWordOderId(wordOderId);
        if (ObjectUtil.isNotNull(inventoryTestRecord)) {
            //获取开始日期-结束日期中间的日期
            List<String> list = new DateTool().betweenDate(inventoryTestRecord.getBeginTime(), inventoryTestRecord.getEndTime());
            List<WorkTestStatistics> userList = inventoryTestRecordMapper.selectListUser(wordOderId);
            List<WorkTestStatistics> dataList = new ArrayList<>();
            userList.stream().forEach(x -> {
                List<Integer> countList = new ArrayList<>();
                list.stream().forEach(a -> {
                    countList.add(inventoryTestRecordMapper.selectTestTotal(a, wordOderId, x.getName()));
                });
                x.setData(countList);
            });
            map.put("dateList", list);
            map.put("DataList", userList);
        } else {
            map.put("dateList", null);
            map.put("DataList", null);
        }
        return AjaxResult.success(map);
    }


}
