package com.productiontest.service.impl;

import java.io.BufferedReader;
import java.io.File;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.io.FileUtil;
import com.productiontest.common.exception.ServiceException;
import com.productiontest.common.utils.DateUtils;
import com.productiontest.common.utils.SecurityUtils;
import com.productiontest.framework.config.ServerConfig;
import com.productiontest.mapper.ProductionOrderMapper;
import com.productiontest.mapper.ProductionWorkOrderMapper;
import com.productiontest.util.QcloudUtil;
import com.productiontest.util.ToolUtil;
import com.productiontest.util.UUIDGenerator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import com.alibaba.fastjson2.JSONObject;
import com.productiontest.common.config.RuoYiConfig;
import com.productiontest.domain.LabelTemplate;
import com.productiontest.mapper.LabelTemplateMapper;
import com.productiontest.service.ILabelTemplateService;

import javax.annotation.Resource;

/**
 * 标签模板Service业务层处理
 *
 * @author cf
 * @date 2023-02-15
 */
@Service
public class LabelTemplateServiceImpl implements ILabelTemplateService {

    @Resource
    private LabelTemplateMapper labelTemplateMapper;
    @Resource
    private ProductionWorkOrderMapper productionWorkOrderMapper;

    /**
     * 查询标签模板
     *
     * @param id 标签模板主键
     * @return 标签模板
     */
    @Override
    public LabelTemplate selectLabelTemplateById(String id) {
        return labelTemplateMapper.selectLabelTemplateById(id);
    }

    /**
     * 查询标签模板列表
     *
     * @param labelTemplate 标签模板
     * @return 标签模板
     */
    @Override
    public List<LabelTemplate> selectLabelTemplateList(LabelTemplate labelTemplate) {
        labelTemplate.setDeptId(SecurityUtils.getDeptId());
        return labelTemplateMapper.selectLabelTemplateList(labelTemplate);
    }

    /**
     * 新增标签模板
     *
     * @param labelTemplate 标签模板
     * @return 结果
     */
    @Override
    public int insertLabelTemplate(LabelTemplate labelTemplate) {
        labelTemplate.setDeptId(SecurityUtils.getDeptId());
        labelTemplate.setId(UUIDGenerator.getUUID());
        labelTemplate.setCreateTime(DateUtil.now());
        return labelTemplateMapper.insertLabelTemplate(labelTemplate);
    }

    /**
     * 修改标签模板
     *
     * @param labelTemplate 标签模板
     * @return 结果
     */
    @Override
    public int updateLabelTemplate(LabelTemplate labelTemplate) {
        labelTemplate.setPushStatus("wait");
        return labelTemplateMapper.updateLabelTemplate(labelTemplate);
    }

    /**
     * 批量删除标签模板
     *
     * @param ids 需要删除的标签模板主键
     * @return 结果
     */
    @Override
    public int deleteLabelTemplateByIds(String[] ids) {
        Arrays.asList(ids).stream().forEach(x -> {
            int count = productionWorkOrderMapper.selectCountTemplateId(x);
            if (count > 0) {
                throw new ServiceException("标签模板已绑定工单,无法删除");
            }
        });
        return labelTemplateMapper.deleteLabelTemplateByIds(ids);
    }

    /**
     * 删除标签模板信息
     *
     * @param id 标签模板主键
     * @return 结果
     */
    @Override
    public int deleteLabelTemplateById(String id) {
        return labelTemplateMapper.deleteLabelTemplateById(id);
    }

    @Override
    @Transactional
    public int importLabelTemplate(MultipartFile file) {
        // TODO Auto-generated method stub
        LabelTemplate lt = new LabelTemplate();
        try {
            String filePath = RuoYiConfig.getUploadPath();
            File fe = new File(filePath);
            if (!fe.exists()) {
                fe.mkdirs();
            }
            String path = filePath + file.getOriginalFilename();
            FileUtil.writeBytes(file.getBytes(), path);
            if (new ToolUtil().getNetwork()) {
                // 上传文件到oss中
                Map<String, String> map = new QcloudUtil().uploadFileInput(file);
                if (map.get("code").equals("200")) {
                    lt.setHttpFile(map.get("url"));
                } else {
                    throw new ServiceException("上传失败");
                }
            }


            InputStream inputStream = file.getInputStream();//创建最基本的流
            //将InputStreamReader包裹在BufferedReader中以获得最佳效率。
            BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(inputStream));
            String strTmp = "";
            StringBuffer sb = new StringBuffer();
            while ((strTmp = bufferedReader.readLine()) != null) {
                sb.append(String.valueOf(strTmp));
            }
            bufferedReader.close();
            JSONObject js = JSONObject.parse(sb.toString());
            lt.setName(js.getString("LabelName"));
            lt.setDetail(sb.toString());
            lt.setDeptId(SecurityUtils.getDeptId());
            lt.setUrl(path);
            lt.setId(UUIDGenerator.getUUID());
            lt.setCreateTime(DateUtil.now());
        } catch (Exception e) {
            throw new ServiceException(e.getMessage());
        }

        return labelTemplateMapper.insertLabelTemplate(lt);
    }

    @Override
    public List<LabelTemplate> getLabelTemplateList() {
        return labelTemplateMapper.getLabelTemplateList();
    }
}
