package com.productiontest.service.impl;

import java.text.SimpleDateFormat;
import java.util.Arrays;
import java.util.Date;
import java.util.List;

import com.productiontest.common.utils.DateUtils;
import com.productiontest.common.utils.SecurityUtils;
import com.productiontest.domain.ProductionOrder;
import com.productiontest.domain.UpdateOrderLog;
import com.productiontest.enums.OrderType;
import com.productiontest.mapper.ProductionOrderMapper;
import com.productiontest.mapper.UpdateOrderLogMapper;
import com.productiontest.util.UUIDGenerator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.productiontest.mapper.LicenseDataMapper;
import com.productiontest.domain.LicenseData;
import com.productiontest.service.ILicenseDataService;

/**
 * 导入license数据Service业务层处理
 *
 * @author cf
 * @date 2023-02-17
 */
@Service
public class LicenseDataServiceImpl implements ILicenseDataService {
    @Autowired
    private LicenseDataMapper licenseDataMapper;
    @Autowired
    private UpdateOrderLogMapper updateOrderLogMapper;
    @Autowired
    private ProductionOrderMapper productionOrderMapper;

    SimpleDateFormat sd = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

    /**
     * 查询导入license数据
     *
     * @param
     * @return license数据
     */
    @Override
    public LicenseData selectLicenseDataById(LicenseData licenseData) {
        return licenseDataMapper.selectLicenseDataById(licenseData);
    }

    /**
     * 查询导入license数据列表
     *
     * @param licenseData 导入license数据
     * @return 导入license数据
     */
    @Override
    public List<LicenseData> selectLicenseDataList(LicenseData licenseData) {
        return licenseDataMapper.selectLicenseDataList(licenseData);
    }

    /**
     * 新增导入license数据
     *
     * @param licenseData 导入license数据
     * @return 结果
     */
    @Override
    public int insertLicenseData(LicenseData licenseData) {
        licenseData.setId(UUIDGenerator.getUUID());
        licenseData.setCreateTime(DateUtils.getNowDate());
        licenseData.setDeptId(SecurityUtils.getDeptId());
        return licenseDataMapper.insertLicenseData(licenseData);
    }

    /**
     * 修改导入license数据
     *
     * @param licenseData 导入license数据
     * @return 结果
     */
    @Override
    public int updateLicenseData(LicenseData licenseData) {
        licenseData.setPushStatus("wait");
        return licenseDataMapper.updateLicenseData(licenseData);
    }

    /**
     * 批量删除导入license数据
     *
     * @param ids 需要删除的导入license数据主键
     * @return 结果
     */
    @Override
    public int deleteLicenseDataByIds(String[] ids) {
        String str = licenseDataMapper.selectLicenseDataByList(ids);
        LicenseData licenseData=new LicenseData();
        licenseData.setId(ids[0]);
        LicenseData ld= licenseDataMapper.selectLicenseDataById(licenseData);
        ProductionOrder productionOrder= productionOrderMapper.selectLicenseByMark(ld.getMark());
        UpdateOrderLog updateOrderLog = new UpdateOrderLog();
        updateOrderLog.setId(UUIDGenerator.getUUID());
        updateOrderLog.setUpdateBy(SecurityUtils.getUsername());
        updateOrderLog.setUpdateTime(sd.format(new Date()));
        updateOrderLog.setCreateTime(sd.format(new Date()));
        updateOrderLog.setType("ORDER");
        updateOrderLog.setContent("删除授权-" + str);
        updateOrderLog.setOddId(productionOrder.getId());
        updateOrderLog.setDeptId(SecurityUtils.getDeptId());
        updateOrderLogMapper.insertUpdateOrderLog(updateOrderLog);
        return licenseDataMapper.deleteLicenseDataByIds(ids);
    }

    /**
     * 删除导入license数据信息
     *
     * @param id 导入license数据主键
     * @return 结果
     */
    @Override
    public int deleteLicenseDataById(String id) {

        return licenseDataMapper.deleteLicenseDataById(id);
    }
}
