package com.productiontest.service.impl;

import java.text.SimpleDateFormat;
import java.util.*;
import java.util.concurrent.locks.ReentrantLock;

import cn.hutool.core.util.StrUtil;
import com.productiontest.common.utils.SecurityUtils;
import com.productiontest.domain.*;
import com.productiontest.mapper.*;
import com.productiontest.service.IProductionOrderService;
import com.productiontest.service.IProductionWorkOrderService;
import com.productiontest.util.UUIDGenerator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson2.JSONObject;
import com.github.pagehelper.util.StringUtil;
import com.productiontest.service.IProductionInventoryService;

import javax.annotation.Resource;

/**
 * 生产库存-pcba和整机Service业务层处理
 *
 * @author cf
 * @date 2023-02-16
 */
@Service
public class ProductionInventoryServiceImpl implements IProductionInventoryService {
    @Resource
    private ProductionInventoryMapper productionInventoryMapper;
    @Resource
    private LicenseDataMapper licensedatamapper;
    @Resource
    private ProductionWorkOrderMapper ProductionWorkOrderMapper;
    @Resource
    private ProductionOrderMapper ProductionOrderMapper;
    @Resource
    private InventoryTestRecordMapper InventoryTestRecordMapper;
    @Resource
    private ThirdPartyDataMapper thirdPartyDataMapper;

    SimpleDateFormat sd = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

    /**
     * 查询生产库存-pcba和整机
     *
     * @param id 生产库存-pcba和整机主键
     * @return 生产库存-pcba和整机
     */
    @Override
    public ProductionInventory selectProductionInventoryById(Long id) {
        return productionInventoryMapper.selectProductionInventoryById(id);
    }

    /**
     * 查询生产库存-pcba和整机列表
     *
     * @param productionInventory 生产库存-pcba和整机
     * @return 生产库存-pcba和整机
     */
    @Override
    public List<ProductionInventory> selectProductionInventoryList(ProductionInventory productionInventory) {
        productionInventory.setDeptId(SecurityUtils.getDeptId());
        return productionInventoryMapper.selectProductionInventoryList(productionInventory);
    }

    /**
     * 新增生产库存-pcba和整机1
     *
     * @param productionInventory 生产库存-pcba和整机
     * @return 结果
     */
    @Override
    public int insertProductionInventory(ProductionInventory productionInventory) {
        productionInventory.setDeptId(SecurityUtils.getDeptId());
        productionInventory.setId(UUIDGenerator.getUUID());
        return productionInventoryMapper.insertProductionInventory(productionInventory);
    }

    /**
     * 修改生产库存-pcba和整机
     *
     * @param productionInventory 生产库存-pcba和整机
     * @return 结果
     */
    @Override
    public int updateProductionInventory(ProductionInventory productionInventory) {
        return productionInventoryMapper.updateProductionInventory(productionInventory);
    }

    /**
     * 批量删除生产库存-pcba和整机
     *
     * @param ids 需要删除的生产库存-pcba和整机主键
     * @return 结果
     */
    @Override
    public int deleteProductionInventoryByIds(Long[] ids) {
        return productionInventoryMapper.deleteProductionInventoryByIds(ids);
    }

    /**
     * 删除生产库存-pcba和整机信息
     *
     * @param id 生产库存-pcba和整机主键
     * @return 结果
     */
    @Override
    public int deleteProductionInventoryById(Long id) {
        return productionInventoryMapper.deleteProductionInventoryById(id);
    }

    @Override
    public ProductionInventory getStatisticsProductionInventoryCount(ProductionInventory productionInventory) {
        // TODO Auto-generated method stub
        productionInventory.setDeptId(SecurityUtils.getDeptId());
        return productionInventoryMapper.getStatisticsProductionInventoryCount(productionInventory);
    }

    @Override
    public List<Map<Object, Object>> getStatisticsByOderNo(ProductionInventory productionInventory) {
        // TODO Auto-generated method stub
        productionInventory.setDeptId(SecurityUtils.getDeptId());
        return productionInventoryMapper.getStatisticsByOderNo(productionInventory);
    }

    @Override
    public List<String> getStatisticsByMoth(ProductionInventory productionInventory) {
        // TODO Auto-generated method stub
        productionInventory.setDeptId(SecurityUtils.getDeptId());

        Map<String, Object> monthData = productionInventoryMapper.getStatisticsByMoth(productionInventory);
        //对数据进行升序排序
        List<Map.Entry<String, Object>> list = new ArrayList<Map.Entry<String, Object>>(monthData.entrySet());
        Collections.sort(list, new Comparator<Map.Entry<String, Object>>() {
            @Override
            public int compare(Map.Entry<String, Object> o1, Map.Entry<String, Object> o2) {
                //把获取的月份中的月去除在进行排序
                return Integer.valueOf(o1.getKey().replace("月", "")) - Integer.valueOf(o2.getKey().replace("月", ""));
            }
        });
        //返回排好的数据
        List<String> addList = new ArrayList<>();
        //进行对比排序
        for (Map.Entry<String, Object> m : list) {
            //monthData.get(m.getKey())是个object对象不能直接转integer,先把对象转换成String类型
            addList.add(String.valueOf(monthData.get(m.getKey()).toString()));
        }
        return addList;
    }

    private ReentrantLock lock = new ReentrantLock();

    @Override
    public JSONObject getLicense(JSONObject json) {

        // TODO Auto-generated method stub
        JSONObject js = new JSONObject();
        String str = null;
        Map<String, String> map = new HashMap<String, String>();
        try {
            lock.lock();
            ProductionInventory pi = new ProductionInventory();
            pi.setPcbaWorkorder(json.getString("WorkOrderID"));
            pi.setProductionId(json.getString("DeviceSN")); // 生产id
            List<ProductionInventory> data = productionInventoryMapper.selectProductionInventoryList(pi);
            pi.setCompanyId(json.getString("CompanyID"));
            pi.setAppId(json.getString("AppID"));
            ProductionWorkOrder workOrder = ProductionWorkOrderMapper.selectProductionWorkOrderByWorkOrderId(json.getString("WorkOrderID"));
            ProductionOrder order = ProductionOrderMapper.selectProductionOrderById(workOrder.getProductOrder());
            if (data.size() > 0) {
                if (StringUtil.isNotEmpty(data.get(0).getEquipmentLicense())) {
                    js.put("CODE", 2312);
                    js.put("License", data.get(0).getEquipmentLicense());
                    return js;
                }

            }

            List<String> license =new ArrayList<>();
            if(StrUtil.isBlank(order.getMark())){
                license = licensedatamapper.selectLicenseDataListString("", workOrder.getWorkorderId());
            }else{
                license = licensedatamapper.selectLicenseDataListString(order.getMark(), "");
            }
            if (license.size() < 1) {
                js.put("CODE", 4004);// 代表着无可用license号
                return js;
            }
            int index = (int) (Math.random() * license.size());
            LicenseData ld = new LicenseData();
            ld.setId(license.get(index));
            LicenseData ta = licensedatamapper.selectLicenseDataById(ld);
            //获取第三方授权文件

            List<ThirdPartyData> partyDataList = thirdPartyDataMapper.getThirdPartyDataListInWorkOrderId(json.getString("WorkOrderID"));

            pi.setOrderNo(order.getOrderNo());
            pi.setDeliveryTime(sd.format(new Date()));
            pi.setApplicationState(0L);
            pi.setInventoryType(Long.parseLong(workOrder.getWorkorderType()));
            pi.setCompanyId(order.getCompanyId());
            pi.setAppId(order.getAppId());
            pi.setId(UUIDGenerator.getUUID());
            if (data.size() < 1) {
                productionInventoryMapper.insertProductionInventory(pi);
            }

            LicenseData licenseData = new LicenseData();
            licenseData.setId(ta.getId());
            licenseData.setStatus("1");
            licenseData.setReqTime(new Date());
            licenseData.setPushStatus("wait");
            licensedatamapper.updateLicenseData(licenseData);
            js.put("CODE", 0);
            map.put("License", ta.getLicense());
            if (partyDataList.size() > 0) {
                map.put("FirmwareAuthID", partyDataList.get(0).getBaseCode());
                ThirdPartyData thirdPartyData = new ThirdPartyData();
                thirdPartyData.setId(partyDataList.get(0).getId());
                thirdPartyData.setStatus("1");
                thirdPartyData.setPushStatus("wait");
                thirdPartyDataMapper.updateThirdPartyData(thirdPartyData);
            } else {
                map.put("FirmwareAuthID", "");
            }
            js.put("BODY", map);
            pi.setEquipmentLicense(ta.getLicense());
            productionInventoryMapper.updateProductionInventory(pi);
        } catch (Exception e) {
            js.put("CODE", -1);
            e.printStackTrace();
        } finally {
            lock.unlock();
        }
        return js;
    }

    public static void main(String[] args) {

        System.out.println(SecurityUtils.encryptPassword("szwtcc123"));
    }

}
