package com.productiontest.service.impl;

import java.io.*;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.Stream;
import java.util.zip.ZipEntry;
import java.util.zip.ZipInputStream;

import cn.hutool.core.io.FileUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONArray;
import com.alibaba.fastjson2.JSONObject;
import com.productiontest.common.exception.ServiceException;
import com.productiontest.common.utils.DateUtils;
import com.productiontest.common.utils.ImsUtil;
import com.productiontest.common.utils.SecurityUtils;
import com.productiontest.common.utils.poi.ExcelUtil;
import com.productiontest.constant.CodeConstant;
import com.productiontest.domain.*;
import com.productiontest.encapsulation.LicenseReadTool;
import com.productiontest.encapsulation.MultipartFileReadTool;
import com.productiontest.encapsulation.ThirdPartyReadTool;
import com.productiontest.enums.OrderType;
import com.productiontest.mapper.*;
import com.productiontest.service.IProductionWorkOrderService;
import com.productiontest.util.*;

import com.productiontest.vo.LicenseProductStatistics;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang3.RandomStringUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import com.productiontest.common.config.RuoYiConfig;
import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.framework.config.ServerConfig;
import com.productiontest.service.IProductionOrderService;

import javax.annotation.Resource;

/**
 * 订单管理Service业务层处理
 *
 * @author cf
 * @date 2023-02-13
 */
@Service
public class ProductionOrderServiceImpl implements IProductionOrderService {
    @Resource
    private ProductionOrderMapper productionOrderMapper;
    @Resource
    private LicenseDataMapper licensedatamapper;
    @Resource
    private DataDictionaryMapper datadictionarymapper;
    @Resource
    private ShippingRecordMapper shippingrecordmapper;
    @Resource
    private ProductionWorkOrderMapper ProductionWorkOrderMapper;
    @Resource
    private InventoryTestRecordMapper InventoryTestRecordMapper;
    @Resource
    private ProductionInventoryMapper ProductionInventoryMapper;
    @Resource
    private UpdateOrderLogMapper updateOrderLogMapper;
    @Resource
    private ThirdPartyDataMapper thirdPartyDataMapper;

    @Resource
    private FirmwareConfigMapper firmwareConfigMapper;

    @Resource
    private IProductionWorkOrderService workOrderService;

    @Resource
    private ImsUtil imsUtil;

    SimpleDateFormat sd = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

    /**
     * 查询订单管理
     *
     * @param id 订单管理主键
     * @return 订单管理
     */
    @Override
    public ProductionOrder selectProductionOrderById(String id) {
        ProductionOrder po = productionOrderMapper.selectProductionOrderById(id);
        if(po!=null){
            List<String> list = new ArrayList<>();
            if (StringUtils.isNotEmpty(po.getTestItem())) {
                Arrays.asList(po.getTestItem().split(",")).forEach(x -> {
                    DataDictionary dd = datadictionarymapper.selectDataDictionaryById(Long.parseLong(x));
                    list.add(dd.getDataKey());
                });
                po.setTestItemList(list);
            }
            if (ObjectUtil.isNotNull(po.getArgumentConfig())) {
                Object provider = JSON.parseObject(po.getArgumentConfig()).get("provider");
                FirmwareConfig firmwareConfig = firmwareConfigMapper.selectFirmwareConfigByProvider(provider);
                if (ObjectUtil.isNotNull(firmwareConfig)) {
                    String l = new ConfigUtil().buildConfig(po.getArgumentConfig(), firmwareConfig.getItemList().toString());
                    po.setArgumentConfigLabel(l);
                }
            }
        }
        return po;
    }

    /**
     * 查询订单管理列表
     *
     * @param productionOrder 订单管理
     * @return 订单管理
     */
    @Override
    public List<ProductionOrder> selectProductionOrderList(ProductionOrder productionOrder) {
        productionOrder.setDeptId(SecurityUtils.getDeptId());
//        未开始：0
//        生成测试中：1
//        生产完成：2
        List<ProductionOrder> ls = productionOrderMapper.selectProductionOrderList(productionOrder);
//        ls.forEach(o->{
//            int fc= productionOrderMapper.selectProductionFinishCount(o.getId());
//            o.setFinishCount(fc);
//        });
        return ls;
    }


    /**
     * 新增订单管理
     *
     * @param productionOrder 订单管理
     * @return 结果
     */
    @Override
    @Transactional
    public AjaxResult insertProductionOrder(ProductionOrder productionOrder) {
        AjaxResult ajax = new AjaxResult();
        productionOrder.setOrderNo(new RandomUtil().getRandomNumber());
        productionOrder.setDeptId(SecurityUtils.getDeptId());
        productionOrder.setCreateTime(sd.format(new Date()));
        productionOrder.setId(UUIDGenerator.getUUID());
        int res = productionOrderMapper.selectProductionCount(productionOrder);
        if (res > 0) {
            throw new ServiceException("订单已经存在");
        }
        //第三方授权
        List<ThirdPartyData> baseCodeList = new ArrayList<>();
        if (StringUtils.isNotEmpty(productionOrder.getThirdPartyFile())) {
            JSONObject js = JSONObject.parseObject(productionOrder.getThirdPartyFile());
            String url = RuoYiConfig.getUploadPath() + js.getString("name");
            String suffix = js.getString("name").substring(js.getString("name").lastIndexOf(".") + 1);
//            if (suffix.equals("xls") || suffix.equals("xlsx")) {
//                baseCodeList = new ThirdPartyReadTool().excelRead(url);
//            } else if (suffix.equals("txt")) {
//                baseCodeList = new ThirdPartyReadTool().txtRead(url);
//            } else
            if (suffix.equals("zip")) {
                baseCodeList = new ThirdPartyReadTool().zipReadBin(url);
            }
            if (baseCodeList.size() > 0) {
//                String baseCodeName = thirdPartyDataMapper.selectThirdPartyDataByList(baseCodeList);
//                if (ObjectUtil.isNotNull(baseCodeName)) {
//                    ajax.put("code", 2002);
//                    ajax.put("message", "第三方授权文件已经存在:" + baseCodeName);
//                    return ajax;
//                }
            } else {
                ajax.put("code", 2003);
                ajax.put("message", "未解析出base64编码");
                return ajax;
            }
        }

//        if (StringUtils.isNotEmpty(productionOrder.getLicenseFile())) {
//            JSONObject js = JSONObject.parseObject(productionOrder.getLicenseFile());
//            String url = RuoYiConfig.getUploadPath() + js.getString("name");
//            String suffix = js.getString("name").substring(js.getString("name").lastIndexOf(".") + 1);
//            List<String> repeatList = new ArrayList<>();
//            if (suffix.equals("xls") || suffix.equals("xlsx")) {
//                repeatList = new LicenseReadTool().excelRead(url);
//            } else if (suffix.equals("txt")) {
//                repeatList = new LicenseReadTool().txtRead(url);
//            } else if (suffix.equals("zip")) {
//                repeatList = new LicenseReadTool().zipRead(url);
//            }
//            String str = licensedatamapper.selectLicenseDataByLicenseList(repeatList);
////            repeatList.stream().forEach(x -> {
////                if (StringUtils.isNotEmpty(x)) {
////                    int count = licensedatamapper.selectLicenseDataCountByLicense(x);
////                    if (count > 0) {
////                        sb.append(x).append(",");
////                    } else {
////                        LicenseData li = new LicenseData();
////                        li.setId(UUIDGenerator.getUUID());
////                        li.setMark(productionOrder.getMark());
////                        li.setLicense(x);
////                        li.setCreateTime(DateUtils.getNowDate());
////                        listData.add(li);
////                    }
////                }
////            });
//
//            if (ObjectUtil.isNotNull(str)) {
//                ajax.put("code", -2);
//                ajax.put("license", str);
//                return ajax;
//            } else {
//                licensedatamapper.insertLicenseDataList(repeatList, productionOrder.getMark(), SecurityUtils.getDeptId());
//            }
//        }

       String arg= productionOrder.getArgumentConfig();
        if(StrUtil.isNotBlank(arg)){
            try{
              if(StrUtil.isBlank(JSON.parseObject(arg).getString("provider"))){
                  productionOrder.setArgumentConfig(null);
              }
            }catch (Exception e){
            }
        }

        JSONObject prd=imsUtil.productInfo(productionOrder.getAppId()).getJSONObject("data");

        productionOrder.setProductName(prd.getString("productName"));
        productionOrder.setCompanyId(prd.getString("company_id"));

        productionOrderMapper.insertProductionOrder(productionOrder);
        baseCodeList.stream().forEach(x -> {
            ThirdPartyData thirdPartyData = new ThirdPartyData();
            thirdPartyData.setId(UUIDGenerator.getUUID());
            thirdPartyData.setBaseCode(x.getBaseCode());
            thirdPartyData.setMdConfig(x.getMdConfig());
            thirdPartyData.setCreateTime(DateUtils.getNowDate());
            thirdPartyData.setFileName(x.getFileName());
            thirdPartyData.setOrderId(productionOrder.getId());
            thirdPartyDataMapper.insertThirdPartyData(thirdPartyData);
        });


        UpdateOrderLog updateOrderLog = new UpdateOrderLog();
        updateOrderLog.setId(UUIDGenerator.getUUID());
        updateOrderLog.setOddId(productionOrder.getId());
        updateOrderLog.setUpdateBy(SecurityUtils.getUsername());
        updateOrderLog.setUpdateTime(sd.format(new Date()));
        updateOrderLog.setCreateTime(sd.format(new Date()));
        updateOrderLog.setType("ORDER");
        updateOrderLog.setContent("新增授权");
        updateOrderLog.setDeptId(SecurityUtils.getDeptId());
        updateOrderLogMapper.insertUpdateOrderLog(updateOrderLog);
        ajax.put("code", 200);
        return ajax;
    }


    /**
     * 修改订单管理
     *
     * @param productionOrder 订单管理
     * @return 结果
     */
    @Override
    @Transactional
    public AjaxResult updateProductionOrder(ProductionOrder productionOrder) {
        AjaxResult ajax = new AjaxResult();
        List<String> dataList = new ArrayList<>();
        productionOrder.setPushStatus("wait");
        ProductionOrder order = productionOrderMapper.selectProductionOrderById(productionOrder.getId());
//        JSONObject js1 = JSONObject.parseObject(productionOrder.getLicenseFile());
//        if (StringUtils.isNotEmpty(productionOrder.getLicenseFile()) && productionOrder.getLicenseFile() != null) {
//            JSONObject js = JSONObject.parseObject(productionOrder.getLicenseFile());
//            String url = RuoYiConfig.getUploadPath() + js.getString("name");
//            try {
//                String suffix = js.getString("name").substring(js.getString("name").lastIndexOf(".") + 1);
//                if (suffix.equals("xls") || suffix.equals("xlsx")) {
//                    dataList = new LicenseReadTool().excelRead(url);
//                } else if (suffix.equals("txt")) {
//                    dataList = new LicenseReadTool().txtRead(url);
//                } else if (suffix.equals("zip")) {
//                    dataList = new LicenseReadTool().zipRead(url);
//                }
//            } catch (Exception e) {
//                e.printStackTrace();
//            }
//        }
//        if (dataList.size() > 0) {
//            String str = licensedatamapper.selectLicenseDataByLicenseList(dataList);
//            //判断license是否重复
//            if (ObjectUtil.isNotNull(str)) {
//                ajax.put("code", -2);
//                ajax.put("license", str);
//                ajax.put("message", "license重复:" + str);
//                return ajax;
//            } else {
//                licensedatamapper.insertLicenseDataList(dataList, order.getMark(), SecurityUtils.getDeptId());
//            }
//        }

        if (ObjectUtil.isNotNull(productionOrder.getThirdPartyFile()) &&
                !productionOrder.getThirdPartyFile().equals("")) {
//            JSONObject third1 = JSONObject.parseObject(productionOrder.getThirdPartyFile());
//            JSONObject third2 = JSONObject.parseObject(order.getThirdPartyFile());
            save(productionOrder);

        }

        if (ObjectUtil.isNotNull(productionOrder.getLicenseFile())) {
            Map<String, Object> map = new HashMap<>();
            JSONObject js1 = JSONObject.parseObject(productionOrder.getLicenseFile());
            JSONArray js = new JSONArray();
            map.put("name", js1.get("name"));
            map.put("url", js1.get("url"));
            map.put("httpUrl", js1.get("httpUrl"));
            map.put("fileName", js1.get("fileName"));
            js.add(map);

            List<ProductionTestUser> userList = js.toJavaList(ProductionTestUser.class);
            ProductionTestUser testUser = new ProductionTestUser();
            testUser.setUrl(js1.getString("url"));
            testUser.setHttpUrl(js1.getString("httpUrl"));
            testUser.setName(js1.getString("name"));
            testUser.setFileName(js1.getString("fileName"));
            userList.add(testUser);
            productionOrder.setLicenseFile(JSON.toJSONString(userList));
        }

        String arg= productionOrder.getArgumentConfig();
        if(StrUtil.isNotBlank(arg)){
            try{
                if(StrUtil.isBlank(JSON.parseObject(arg).getString("provider"))){
                    productionOrder.setArgumentConfig(null);
                }
            }catch (Exception e){
            }
        }

        JSONObject prd= imsUtil.productInfo(productionOrder.getAppId()).getJSONObject("data");
        productionOrder.setProductName(prd.getString("productName"));
        productionOrder.setCompanyId(prd.getString("company_id"));

        productionOrderMapper.updateProductionOrderById(productionOrder);


        UpdateOrderLog updateOrderLog = new UpdateOrderLog();
        updateOrderLog.setId(UUIDGenerator.getUUID());
        updateOrderLog.setOddId(productionOrder.getId());
        updateOrderLog.setUpdateBy(SecurityUtils.getUsername());
        updateOrderLog.setUpdateTime(sd.format(new Date()));
        updateOrderLog.setCreateTime(sd.format(new Date()));
        updateOrderLog.setType("ORDER");
        updateOrderLog.setContent("编辑订单");
        updateOrderLog.setDeptId(SecurityUtils.getDeptId());
        updateOrderLogMapper.insertUpdateOrderLog(updateOrderLog);
        ajax.put("code", 200);
        return ajax;
    }


    public AjaxResult save(ProductionOrder productionOrder) {
        AjaxResult ajax = new AjaxResult();
        JSONObject js = JSONObject.parseObject(productionOrder.getThirdPartyFile());
        try {
            String suffix = js.getString("name").substring(js.getString("name").lastIndexOf(".") + 1);
            String url = RuoYiConfig.getUploadPath() + js.getString("name");
            List<ThirdPartyData> baseCodeList = new ArrayList<>();
            if (suffix.equals("zip")) {
                baseCodeList = new ThirdPartyReadTool().zipReadBin(url);
            }
            if (baseCodeList.size() > 0) {
                String baseCodeName = thirdPartyDataMapper.selectThirdPartyDataByList(baseCodeList);
                if (ObjectUtil.isNotNull(baseCodeName)) {
                    ajax.put("code", CodeConstant.LicenseExistCode);
                    ajax.put("message", "第三方授权文件已经存在:" + baseCodeName);
                    return ajax;
                }
                baseCodeList.stream().forEach(x -> {
                    ThirdPartyData thirdPartyData = new ThirdPartyData();
                    thirdPartyData.setId(UUIDGenerator.getUUID());
                    thirdPartyData.setBaseCode(x.getBaseCode());
                    thirdPartyData.setMdConfig(x.getMdConfig());
                    thirdPartyData.setCreateTime(DateUtils.getNowDate());
                    thirdPartyData.setFileName(x.getFileName());
                    thirdPartyData.setOrderId(productionOrder.getId());
                    thirdPartyDataMapper.insertThirdPartyData(thirdPartyData);
                });

            } else {
                ajax.put("code", CodeConstant.NoBaseCode);
                ajax.put("message", "未解析出base64编码");
                return ajax;
            }

        } catch (Exception e) {
            e.printStackTrace();
        }
        return ajax;
    }


    /**
     * 批量删除订单管理
     *
     * @param ids 需要删除的订单管理主键
     * @return 结果
     */
    @Override
    public int deleteProductionOrderByIds(String[] ids) {
        Arrays.asList(ids).stream().forEach(x -> {

            List<ProductionWorkOrder> ls =  ProductionWorkOrderMapper.getWorkOrderByOrderId(x);
            ls.forEach(p->{
                workOrderService.licenseRecycle(p.getWorkorderId());
            });

            ProductionOrder order = productionOrderMapper.selectProductionOrderById(x);
            licensedatamapper.deleteLicenseByMark(order.getMark(),"",order.getId());
            thirdPartyDataMapper.deleteThirdPartyDataByOrderId(x);

            ProductionWorkOrderMapper.delWorkOrderByOrderId(x);

        });

        return productionOrderMapper.deleteProductionOrderByIds(ids);
    }

    /**
     * 删除订单管理信息
     *
     * @param id 订单管理主键
     * @return 结果
     */
    @Override
    public int deleteProductionOrderById(String id) {
        ProductionOrder order = productionOrderMapper.selectProductionOrderById(id);
        licensedatamapper.deleteLicenseByMark(order.getMark(),"",order.getId());
        return productionOrderMapper.deleteProductionOrderById(id);
    }

    @Override
    public AjaxResult uploadFileReadFile(MultipartFile file) {
        AjaxResult ajax = new AjaxResult();
        String mark = RandomStringUtils.randomNumeric(15);
        try {
            List<String> repeatList = new ArrayList<>();
            //获取文件后缀
            String suffix = file.getOriginalFilename().substring(file.getOriginalFilename().lastIndexOf(".") + 1);
            if (suffix.equals("xls") || suffix.equals("xlsx")) {
                repeatList = new MultipartFileReadTool().licenseReadExcel(file);
            } else if (suffix.equals("txt")) {
                repeatList = new MultipartFileReadTool().txtRead(file);
            } else if (suffix.equals("zip")) {
                repeatList = new MultipartFileReadTool().zipReadLicense(file);
            }
            if (repeatList.size() < 1) {
//                throw new ServiceException("当前文件无内容,请重新上传");
                ajax.put("message", "当前文件无内容,请重新上传");
                ajax.put("code", CodeConstant.NoContentCode);
                return ajax;
            }

            if (repeatList.size() > 10000) {
//                throw new ServiceException("单次只支持上传10000个授权,请重新上传");
                ajax.put("message", "单次只支持上传10000个授权,请重新上传");
                ajax.put("code", CodeConstant.MaxLicenseCode);
                return ajax;
            }


            List<String> collect = repeatList.stream().collect(Collectors.groupingBy(e -> e, Collectors.counting()))
                    .entrySet().stream().filter(e -> e.getValue() > 1)
                    .map(Map.Entry::getKey).collect(Collectors.toList());

            if (collect.size() > 0) {
                ajax.put("code", CodeConstant.RepeatLicenseCode);
                ajax.put("license", StringUtils.join(collect, ","));
                ajax.put("message", "license重复:" + StringUtils.join(collect, ","));
                return ajax;
            }
            String filePath = RuoYiConfig.getUploadPath();
            File fe = new File(filePath);
            if (!fe.exists()) {
                fe.mkdirs();
            }
            String path = filePath + file.getOriginalFilename();
            FileUtil.writeBytes(file.getBytes(), path);
            ajax.put("httpUrl", "");
            if (new ToolUtil().getNetwork()) {
                // 上传文件到oss中
                Map<String, String> map = new QcloudUtil().uploadFileInput(file);
                if (map.get("code").equals("200")) {
                    ajax.put("httpUrl", map.get("url"));
                }
            }
            ajax.put("newFileName", file.getOriginalFilename());
            ajax.put("originalFilename", file.getOriginalFilename());
            ajax.put("fileName", file.getOriginalFilename());
            ajax.put("url", RuoYiConfig.getNginxFile() + file.getOriginalFilename());
            ajax.put("mark", mark);
            return ajax;
        } catch (Exception e) {
            ajax.put("code", CodeConstant.uploadErrorCode);
            e.printStackTrace();
        }

        return ajax;
    }

    @Override
    public AjaxResult uploadThirdFile(MultipartFile file) {
        AjaxResult ajax = new AjaxResult();
        try {
            List<ThirdPartyData> repeatList = new ArrayList<>();
            //获取文件后缀
            String suffix = file.getOriginalFilename().substring(file.getOriginalFilename().lastIndexOf(".") + 1);
            if (suffix.equals("zip")) {
                repeatList = new MultipartFileReadTool().zipRead(file);
            }
            if (repeatList.size() > 0) {
                String baseCodeName = thirdPartyDataMapper.selectThirdPartyDataByList(repeatList);
                if (ObjectUtil.isNotNull(baseCodeName)) {
                    ajax.put("code", CodeConstant.LicenseExistCode);
                    ajax.put("message", "第三方授权文件已经存在:" + baseCodeName);
                    return ajax;
                }
            } else {
                ajax.put("code", CodeConstant.NoBaseCode);
                ajax.put("message", "未解析出base64编码");
                return ajax;
            }
            String filePath = RuoYiConfig.getUploadPath();
            File fe = new File(filePath);
            if (!fe.exists()) {
                fe.mkdirs();
            }
            String path = filePath + file.getOriginalFilename();
            FileUtil.writeBytes(file.getBytes(), path);
            ajax.put("httpUrl", "");
            if (new ToolUtil().getNetwork()) {
                // 上传文件到oss中
                Map<String, String> map = new QcloudUtil().uploadFileInput(file);
                if (map.get("code").equals("200")) {
                    ajax.put("httpUrl", map.get("url"));
                }
            }
            ajax.put("newFileName", file.getOriginalFilename());
            ajax.put("originalFilename", file.getOriginalFilename());
            ajax.put("fileName", file.getOriginalFilename());
            ajax.put("size", repeatList.size());
            ajax.put("url", RuoYiConfig.getNginxFile() + file.getOriginalFilename());
            return ajax;
        } catch (Exception e) {
            ajax.put("code", CodeConstant.uploadErrorCode);
            ajax.put("message", "上传错误");
            e.printStackTrace();
        }

        return ajax;
    }

    @Override
    public LicenseProductStatistics selectThirdCountByOrderId(String orderId) {
        return productionOrderMapper.selectThirdCountByOrderId(orderId);
    }

    @Override
    public Map<Object, Object> selectProductionOrderDeliveryDetail(ProductionOrder productionOrder) {
        // TODO Auto-generated method stub
        productionOrder.setDeptId(SecurityUtils.getDeptId());
        return productionOrderMapper.selectProductionOrderDeliveryDetail(productionOrder);
    }


    @Override
    @Transactional
    public AjaxResult insertShippingRecordByProductionOrder(ShippingRecord sr) {
        AjaxResult aj = new AjaxResult();
        String mark = RandomStringUtils.randomNumeric(15);
        // 判断交付方式 如果为0 则生成license 为1上传读取license
        if (sr.getDeliveryMethod().equals("0")) {
            InventoryTestRecord it = new InventoryTestRecord();
            it.setDeptId(SecurityUtils.getDeptId());
            it.setProductOrder(sr.getOrderId());
            List<InventoryTestRecord> data = InventoryTestRecordMapper.selectListTestRecordByOrderId(it);
            if (data.size() > 0) {
                InventoryTestRecordMapper.updateInventoryTestRecordByList(data, mark);
                ProductionInventoryMapper.updateProductionInventoryList(data);
            }
        } else {

            JSONArray array = JSONArray.parseArray(sr.getFile());
            String url = "";
            String name = "";
            for (int i = 0; i < array.size(); i++) {
                JSONObject o = array.getJSONObject(i);
                name = o.getString("name");
                url = RuoYiConfig.getUploadPath() + o.getString("name");
            }
            List<String> repeatList = new ArrayList<>();
            StringBuffer sb = new StringBuffer();
            try {
                String suffix = name.substring(name.lastIndexOf(".") + 1);
                if (suffix.equals("xls") || suffix.equals("xlsx")) {
                    repeatList = new LicenseReadTool().excelRead(url);
                } else if (suffix.equals("txt")) {
                    repeatList = new LicenseReadTool().txtRead(url);
                }
                repeatList.stream().forEach(x -> {
                    int count = InventoryTestRecordMapper.selectInventoryTestRecordByCetl(x);
                    if (count < 1) {
                        sb.append(x).append(",");
                    }
                });
                //无效license
                if (StringUtils.isNotEmpty(sb)) {
                    aj.put("code", -4);
                    aj.put("license", sb.deleteCharAt(sb.length() - 1).toString());
                    aj.put("message", "无效license");
                    return aj;
                }
                //查询出license是否已经出库 返回已出库list
                String str = InventoryTestRecordMapper.selectInventoryTestRecordByList(repeatList);
                if (StringUtils.isNotEmpty(str)) {
                    aj.put("code", -3);
                    aj.put("license", str);
                    aj.put("message", "license已经出库");
                    return aj;
                }
                //查询出需要出库的数据
                List<InventoryTestRecord> trList = InventoryTestRecordMapper.getInventoryTestRecordListByStatus(repeatList);
                if (trList.size() > 0) {
                    InventoryTestRecordMapper.updateInventoryTestRecordByList(trList, mark);
                    ProductionInventoryMapper.updateProductionInventoryList(trList);
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        sr.setDeptId(SecurityUtils.getDeptId());
        sr.setTaskNumber(RandomStringUtils.randomAlphanumeric(15));
        sr.setCreateTime(DateUtils.getNowDate());
        sr.setCreateUser(SecurityUtils.getUsername());
        sr.setMark(mark);
        sr.setId(UUIDGenerator.getUUID());
        shippingrecordmapper.insertShippingRecord(sr);
        aj.put("code", 200);
        return aj;
    }

    @Override
    public Map<Object, Object> getSelectProductionOrderStatistics() {
        return productionOrderMapper.getSelectProductionOrderStatistics(SecurityUtils.getDeptId());
    }


    @Override
    public List<ProductionOrder> selectProductionOrderListByNewDate(ProductionOrder po) {

        po.setCreateTime(sd.format(new Date()));
        po.setDeptId(SecurityUtils.getDeptId());
        List<ProductionOrder> ls= productionOrderMapper.selectProductionOrderListByNewDate(po);
        ls.forEach(o->{
           int fc= productionOrderMapper.selectProductionFinishCount(o.getId());
           o.setFinishCount(fc);
        });
        return ls;
    }

    @Override
    public List<Map<Object, Object>> selectProductionOrderStatisticsByEcharts() {
        return productionOrderMapper.selectProductionOrderStatisticsByEcharts(SecurityUtils.getDeptId());
    }


    @Override
    public AjaxResult uploadEquipment(MultipartFile file) {
        AjaxResult ajax = new AjaxResult();
        String filePath = RuoYiConfig.getUploadPath();
        String suffix = file.getOriginalFilename().substring(file.getOriginalFilename().lastIndexOf(".") + 1);
        try {
            List<String> repeatList = new ArrayList<>();
            List<LicenseData> listData = new ArrayList<>();
            if (suffix.equals("xls") || suffix.equals("xlsx")) {
                repeatList = new MultipartFileReadTool().licenseReadExcel(file);
            } else if (suffix.equals("txt")) {
                repeatList = new MultipartFileReadTool().txtRead(file);
            }

            File fe = new File(filePath);
            if (!fe.exists()) {
                fe.mkdirs();
            }
            String path = filePath + file.getOriginalFilename();
            FileUtil.writeBytes(file.getBytes(), path);
            ajax.put("httpUrl", "");
            if (new ToolUtil().getNetwork()) {
                // 上传文件到oss中
                Map<String, String> map = new QcloudUtil().uploadFileInput(file);
                if (map.get("code").equals("200")) {
                    ajax.put("httpUrl", map.get("url"));
                }
            }
            ajax.put("newFileName", file.getOriginalFilename());
            ajax.put("originalFilename", file.getOriginalFilename());
            ajax.put("fileName", file.getOriginalFilename());
            ajax.put("url", RuoYiConfig.getNginxFile() + file.getOriginalFilename());
            ajax.put("count", repeatList.size());
        } catch (Exception e) {
            ajax.put("code", CodeConstant.uploadErrorCode);
            e.printStackTrace();
        }
        return ajax;
    }

    @Override
    public List<ProductionOrder> getListProductionOrderNoPage(ProductionOrder productionOrder) {
        productionOrder.setDeptId(SecurityUtils.getDeptId());
        return productionOrderMapper.getListProductionOrderNoPage(productionOrder);
    }

    @Override
    public JSONObject getOrderDetail(JSONObject json) {
        JSONObject js = new JSONObject();

        Map<String, Object> map2 = new HashMap<>();
        String workOrderId = json.getString("WorkOrderId");
        String version = json.getString("Version");
        boolean exitMD5 = json.containsKey("ConfigMD5");
//        String configMD5 = json.getString("ConfigMD5");
        ProductionOrder order = productionOrderMapper.selectProductionOrderByWorkOrderId(workOrderId);
        ProductionWorkOrder oe = ProductionWorkOrderMapper.selectProductionWorkOrderByWorkOrderId(workOrderId);
        js.put("code", 1000);

        if (exitMD5 && !json.getString("ConfigMD5").equals(oe.getDeviceConfigMd())) {
            try {
                map2.put("Version", oe.getFirmwareVersion());
                map2.put("CheckSum", "MD5");
                map2.put("PublicKey", RSASign.pubKey);
                map2.put("Signature", RSASign.sign_MD5withRSA(oe.getRomFileMd()));
                map2.put("Level", 1);

                if (StringUtils.isNotEmpty(oe.getRomFile())) {
                    JSONObject ob = JSONObject.parseObject(oe.getRomFile());
                    map2.put("DescURL", "");
                    map2.put("DownloadUrl", ob.getString("url"));
                    File fe = new File(RuoYiConfig.getUploadPath() + ob.getString("name"));
                    if (fe.exists()) {
                        map2.put("FileSize", fe.length());
                    } else {
                        map2.put("FileSize", 0);
                    }

                } else {
                    map2.put("DescURL", "");
                    map2.put("FileSize", 0);
                }
                if (exitMD5) {
                    if (!json.getString("ConfigMD5").equals(oe.getDeviceConfigMd())) {
                        if (ObjectUtil.isNotNull(oe.getDeviceConfigFile())) {
                            JSONObject je = JSONObject.parseObject(oe.getDeviceConfigFile());
                            map2.put("ConfigDownurl", je.getString("url"));
                        } else {
                            map2.put("ConfigDownurl", "");
                        }
                        map2.put("ConfigMD5", oe.getDeviceConfigMd());
                    }
                }
                js.put("data", map2);
                js.put("desc", "Success");
                js.put("msg", "OK");
                js.put("timestamp", new Date().getTime());
                js.put("type", "");
            } catch (Exception e) {
                e.printStackTrace();
            }
        } else if (StringUtils.isEmpty(oe.getFirmwareVersion()) || oe.getFirmwareVersion().equals(version)) {
            map2.put("Level", 0);
            js.put("data", map2);
            js.put("desc", "Success");
            js.put("msg", "OK");
            js.put("timestamp", new Date().getTime());
            js.put("type", "");
        } else {

            //判断当前版本号是否大于参数版本 如果等于则不需要升级 反之需要升级
            if (oe.getFirmwareVersion().compareToIgnoreCase(version) < 0) {
                map2.put("Level", 0);
                js.put("data", map2);
                js.put("desc", "Success");
                js.put("msg", "OK");
                js.put("timestamp", new Date().getTime());
                js.put("type", "");
            } else {
                try {
                    map2.put("Version", oe.getFirmwareVersion());
                    map2.put("CheckSum", "MD5");
                    map2.put("PublicKey", RSASign.pubKey);
                    map2.put("Signature", RSASign.sign_MD5withRSA(oe.getRomFileMd()));
                    map2.put("Level", 1);

                    if (StringUtils.isNotEmpty(oe.getRomFile())) {
                        JSONObject ob = JSONObject.parseObject(oe.getRomFile());
                        map2.put("DescURL", "");
                        map2.put("DownloadUrl", ob.getString("url"));
                        map2.put("FileSize", CommonFileUtils.getFileLength(ob.getString("url")));
                    } else {
                        map2.put("DescURL", "");
                        map2.put("FileSize", 0);
                    }
                    if (exitMD5) {
                        if (!json.getString("ConfigMD5").equals(oe.getDeviceConfigMd())) {
                            if (ObjectUtil.isNotNull(oe.getDeviceConfigFile())) {
                                JSONObject je = JSONObject.parseObject(oe.getDeviceConfigFile());
                                map2.put("ConfigDownurl", je.getString("url"));
                            } else {
                                map2.put("ConfigDownurl", "");
                            }
                            map2.put("ConfigMD5", oe.getDeviceConfigMd());
                        }
                    }
                    js.put("data", map2);
                    js.put("desc", "Success");
                    js.put("msg", "OK");
                    js.put("timestamp", new Date().getTime());
                    js.put("type", "");
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        }

        return js;
    }

    @Override
    public LicenseProductStatistics selectLicenseCountByMark(String mark) {
        return productionOrderMapper.selectLicenseCountByMark(mark);
    }

    @Override
    public AjaxResult uploadDeviceConfigFile(MultipartFile file) {
        AjaxResult ajax = new AjaxResult();
        try {
            String filePath = RuoYiConfig.getUploadPath();
            File fe = new File(filePath);
            if (!fe.exists()) {
                fe.mkdirs();
            }
            String path = filePath + file.getOriginalFilename();
            FileUtil.writeBytes(file.getBytes(), path);
            ajax.put("httpUrl", "");
            if (new ToolUtil().getNetwork()) {
                // 上传文件到oss中
                Map<String, String> map = new QcloudUtil().uploadFileInput(file);
                if (map.get("code").equals("200")) {
                    ajax.put("httpUrl", map.get("url"));
                }
            }
            byte[] bytes = file.getBytes();
            String sign = DigestUtils.md5Hex(bytes);
            ajax.put("md5", sign);
            ajax.put("newFileName", file.getOriginalFilename());
            ajax.put("originalFilename", file.getOriginalFilename());
            ajax.put("fileName", file.getOriginalFilename());
            ajax.put("url", RuoYiConfig.getNginxFile() + file.getOriginalFilename());
        } catch (Exception e) {
            ajax.put("code", CodeConstant.uploadErrorCode);
            e.printStackTrace();
        }
        return ajax;
    }

    @Override
    public List<ProductionOrder> getListFile(String params) {
        return productionOrderMapper.getListFile(params);
    }

//
//    public static void main(String[] args) {
////        String str = "{\"name\":\"\",\"url\":\"https://ecology-manage-1311597033.cos.ap-nanjing.myqcloud.com/1679984006808.xlsx\",\"fileName\":\"1679984006808.xlsx\"}";
////        JSONObject jsonObject = JSONObject.parseObject(str);
////        jsonObject.put("name", "123");
////        System.out.println(jsonObject);
////        String path = "D:\\productiontest-upload\\uploadPath\\upload\\license.xlsx";
////        MultipartFile file = new FileConMultipartFile().getMultipartFile(new File(path));
////        System.out.println(new QcloudUtil().uploadFileInput(file));
//        String str = "{\"name\":\"1687252975757 (2).xls\",\"url\":\"127.0.0.1:82/upload/1687252975757 (2).xls\",\"httpUrl\":\"https://ecology-manage-1311597033.cos.ap-nanjing.myqcloud.com/1688977457506.xls\",\"fileName\":\"1687252975757 (2).xls\"}";
//        Map<String, Object> map = new HashMap<>();
//        JSONArray js = new JSONArray();
//
//        map.put("name", JSONObject.parseObject(str).get("name"));
//        map.put("url", JSONObject.parseObject(str).get("url"));
//        map.put("httpUrl", JSONObject.parseObject(str).get("httpUrl"));
//        map.put("fileName", JSONObject.parseObject(str).get("fileName"));
//        js.add(map);
//        System.out.println(js);
//    }
}

