package com.productiontest.service.impl;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson2.JSONObject;
import com.productiontest.common.exception.ServiceException;
import com.productiontest.domain.ProductionTestUser;
import com.productiontest.domain.ProductionWorkOrder;
import com.productiontest.mapper.ProductionTestUserMapper;
import com.productiontest.mapper.ProductionWorkOrderMapper;
import com.productiontest.util.UUIDGenerator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.productiontest.mapper.ProductionTestUserCardMapper;
import com.productiontest.domain.ProductionTestUserCard;
import com.productiontest.service.IProductionTestUserCardService;

import javax.annotation.Resource;

/**
 * 人员绑定-4GService业务层处理
 *
 * @author cf
 * @date 2023-06-14
 */
@Service
public class ProductionTestUserCardServiceImpl implements IProductionTestUserCardService {
    @Resource
    private ProductionTestUserCardMapper productionTestUserCardMapper;

    @Resource
    private ProductionTestUserMapper productionTestUserMapper;

    /**
     * 查询人员绑定-4G
     *
     * @param id 人员绑定-4G主键
     * @return 人员绑定-4G
     */
    @Override
    public ProductionTestUserCard selectProductionTestUserCardById(String id) {
        return productionTestUserCardMapper.selectProductionTestUserCardById(id);
    }

    /**
     * 查询人员绑定-4G列表
     *
     * @param productionTestUserCard 人员绑定-4G
     * @return 人员绑定-4G
     */
    @Override
    public List<ProductionTestUserCard> selectProductionTestUserCardList(ProductionTestUserCard productionTestUserCard) {
        return productionTestUserCardMapper.selectProductionTestUserCardList(productionTestUserCard);
    }

    /**
     * 绑定、解绑人员绑定-4G
     *
     * @return 结果
     */
    @Override
    public JSONObject insertProductionTestUserCard(JSONObject json) {
        Map<String, Object> map = new HashMap<String, Object>();
        JSONObject js = new JSONObject();
        try {
            String account = json.getString("Account");
            String sim = json.getString("SIMID");
            String setCmd = json.getString("SetCmd");
            ProductionTestUser user = productionTestUserMapper.selectProductionTestUserByUserName(account);
            if (ObjectUtil.isNull(user)) {
                throw new ServiceException("用户不存在!!");
            }
            if (setCmd.equals("1")) {
                ProductionTestUserCard productionTestUserCard = new ProductionTestUserCard();
                productionTestUserCard.setPushStatus("wait");
                productionTestUserCard.setFourCard(sim);
                productionTestUserCard.setUserId(user.getId());
                productionTestUserCard.setId(UUIDGenerator.getUUID());
                productionTestUserCard.setDel(0L);
                ProductionTestUserCard card = productionTestUserCardMapper.selectCount(productionTestUserCard);
                if (ObjectUtil.isNull(card)) {
                    productionTestUserCardMapper.insertOrUpdate(productionTestUserCard);
                } else {
                    card.setDel(0L);
                    productionTestUserCardMapper.updateProductionTestUserCard(card);
                }
            } else {
                productionTestUserCardMapper.deleteCardBySIM(user.getId(), sim);
            }
            js.put("CODE", 0);
            js.put("MSG", "操作成功");
        } catch (Exception e) {
            js.put("CODE", 500);
            js.put("MSG", "操作错误:" + e);
            e.printStackTrace();
        }

        return js;
    }

    /**
     * 修改人员绑定-4G
     *
     * @param productionTestUserCard 人员绑定-4G
     * @return 结果
     */
    @Override
    public int updateProductionTestUserCard(ProductionTestUserCard productionTestUserCard) {
        productionTestUserCard.setPushStatus("wait");
        return productionTestUserCardMapper.updateProductionTestUserCard(productionTestUserCard);
    }

    /**
     * 批量删除人员绑定-4G
     *
     * @param ids 需要删除的人员绑定-4G主键
     * @return 结果
     */
    @Override
    public int deleteProductionTestUserCardByIds(String[] ids) {
        return productionTestUserCardMapper.deleteProductionTestUserCardByIds(ids);
    }

    /**
     * 删除人员绑定-4G信息
     *
     * @param id 人员绑定-4G主键
     * @return 结果
     */
    @Override
    public int deleteProductionTestUserCardById(String id) {
        return productionTestUserCardMapper.deleteProductionTestUserCardById(id);
    }

    @Override
    public JSONObject selectAccountByCard(JSONObject js) {
        JSONObject json = new JSONObject();
        String SIM = js.getString("SIM");
        Map<String, Object> map = new HashMap<String, Object>();
        //根据4g卡号列表查询人员
        ProductionTestUser productionTestUser = productionTestUserMapper.selectUserNameBySIM(SIM);
        if (ObjectUtil.isNotNull(productionTestUser)) {
            map.put("Account", productionTestUser.getUserName());
        } else {
            map.put("Account", "");
        }
        json.put("CODE", 0);
        json.put("BODY", map);
        return json;
    }

    @Override
    public JSONObject selectSimCardByAccount(JSONObject js) {
        Map<String, Object> map = new HashMap<String, Object>();
        JSONObject json = new JSONObject();
        String account = js.getString("Account");
        ProductionTestUser testUser = productionTestUserMapper.selectProductionTestUserByUserName(account);
        List<String> data = productionTestUserCardMapper.selectUserCardByUserId(testUser.getId());
        map.put("SIMIDList", data);
        json.put("CODE", 0);
        json.put("BODY", map);
        return json;
    }
}
