package com.productiontest.service.impl;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.productiontest.common.config.RuoYiConfig;
import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.util.ConnectUtil;
import com.productiontest.util.UUIDGenerator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson2.JSONObject;
import com.productiontest.common.utils.DateUtils;
import com.productiontest.common.utils.SecurityUtils;
import com.productiontest.domain.ProductionTestUser;
import com.productiontest.mapper.ProductionTestUserMapper;
import com.productiontest.service.IProductionTestUserService;

/**
 * 产测人员管理Service业务层处理
 *
 * @author cf
 * @date 2023-02-14
 */
@Service
public class ProductionTestUserServiceImpl implements IProductionTestUserService {

    @Autowired
    private ProductionTestUserMapper productionTestUserMapper;

    /**
     * 查询产测人员管理
     *
     * @param id 产测人员管理主键
     * @return 产测人员管理
     */
    @Override
    public ProductionTestUser selectProductionTestUserById(String id) {
        return productionTestUserMapper.selectProductionTestUserById(id);
    }

    /**
     * 查询产测人员管理列表
     *
     * @param productionTestUser 产测人员管理
     * @return 产测人员管理
     */
    @Override
    public List<ProductionTestUser> selectProductionTestUserList(ProductionTestUser productionTestUser) {
        productionTestUser.setDeptId(SecurityUtils.getDeptId());
        return productionTestUserMapper.selectProductionTestUserList(productionTestUser);
    }

    /**
     * 新增产测人员管理
     *
     * @param productionTestUser 产测人员管理
     * @return 结果
     */
    @Override
    public AjaxResult insertProductionTestUser(ProductionTestUser productionTestUser) {
        AjaxResult ajax=new AjaxResult();
        int result= productionTestUserMapper.selectCountProductionTestUser(productionTestUser);
        if(result>0){
            ajax.put("code",-1);
            ajax.put("msg","人员账号已存在!请更换账号");
            return  ajax;
        }
        productionTestUser.setCreateTime(DateUtils.getNowDate());
        productionTestUser.setPassword(SecurityUtils.encryptPassword(productionTestUser.getPassword()));
        productionTestUser.setDeptId(SecurityUtils.getDeptId());
        productionTestUser.setId(UUIDGenerator.getUUID());
        productionTestUserMapper.insertProductionTestUser(productionTestUser);
        ajax.put("code",200);
        return ajax;
    }

    /**
     * 修改产测人员管理
     *
     * @param productionTestUser 产测人员管理
     * @return 结果
     */
    @Override
    public int updateProductionTestUser(ProductionTestUser productionTestUser) {
        productionTestUser.setPushStatus("wait");
        if(productionTestUser.getStatus().equals("1")){
            ProductionTestUser testUser= productionTestUserMapper.selectProductionTestUserById(productionTestUser.getId());
            JSONObject jsonObject =new JSONObject();
            jsonObject.put("Account",testUser.getUserName());
            ConnectUtil.connectPost(RuoYiConfig.getSdkIp() + "/NoticeRmvUtoken", jsonObject);
        }
        return productionTestUserMapper.updateProductionTestUser(productionTestUser);
    }

    /**
     * 批量删除产测人员管理
     *
     * @param ids 需要删除的产测人员管理主键
     * @return 结果
     */
    @Override
    public int deleteProductionTestUserByIds(String[] ids) {
        Arrays.asList(ids).forEach(x->{
            ProductionTestUser testUser= productionTestUserMapper.selectProductionTestUserById(x);
            JSONObject jsonObject =new JSONObject();
            jsonObject.put("Account",testUser.getUserName());
            ConnectUtil.connectPost(RuoYiConfig.getSdkIp() + "/NoticeRmvUtoken", jsonObject);
        });
        return productionTestUserMapper.deleteProductionTestUserByIds(ids);
    }

    /**
     * 删除产测人员管理信息
     *
     * @param id 产测人员管理主键
     * @return 结果
     */
    @Override
    public int deleteProductionTestUserById(String id) {
        return productionTestUserMapper.deleteProductionTestUserById(id);
    }

    @Override
    public int resetPassword(ProductionTestUser productionTestUser) {
        productionTestUser.setPassword(SecurityUtils.encryptPassword(productionTestUser.getPassword()));
        ProductionTestUser testUser= productionTestUserMapper.selectProductionTestUserById(productionTestUser.getId());
        JSONObject jsonObject =new JSONObject();
        jsonObject.put("Account",testUser.getUserName());
        ConnectUtil.connectPost(RuoYiConfig.getSdkIp() + "/NoticeRmvUtoken", jsonObject);
        return productionTestUserMapper.updateProductionTestUser(productionTestUser);
    }




    @Override
    public JSONObject getUsernameAndIcon(JSONObject json) {
        ProductionTestUser pt = new ProductionTestUser();
        pt.setUserName(json.getString("Account"));
        ProductionTestUser data = productionTestUserMapper.selectProductionTestUserByUserName(pt.getUserName());
        JSONObject js = new JSONObject();
        Map<String, String> map = new HashMap<String, String>();
        if (data != null) {
            js.put("CODE", 0);
            map.put("Name", data.getNickName());
            js.put("BODY", map);
        } else {
            js.put("CODE", -1);
        }
        return js;
    }


    public JSONObject getAccountInfo(JSONObject js) {
        String username = js.getString("Account");
        String password = js.getString("Password");
        ProductionTestUser pt = productionTestUserMapper.selectProductionTestUserByUserName(username);
        JSONObject json = new JSONObject();
        JSONObject json2 = new JSONObject();
        if (pt == null) {
            json.put("CODE", "4191");
        } else if (pt.getStatus().equals(1) || pt.getStatus().equals("1") ) {
            json.put("CODE", "4189");
        } else {
            BCryptPasswordEncoder passwordEncoder = new BCryptPasswordEncoder();
            Boolean bl = passwordEncoder.matches(password, pt.getPassword());
//            = SecurityUtils.matchesPassword(password, pt.getPassword());
            if (bl) {
                json.put("CODE", "0");
                json2.put("Username", pt.getNickName());
                json.put("BODY", json2);
            } else {
                json.put("CODE", "4190");
            }
        }
        return json;
    }

    @Override
    public int selectCountProductionTestUser(ProductionTestUser productionTestUser) {
        return productionTestUserMapper.selectCountProductionTestUser(productionTestUser);
    }

}
