package com.productiontest.service.impl;

import cn.hutool.core.io.FileUtil;
import cn.hutool.core.thread.ThreadUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONArray;
import com.alibaba.fastjson2.JSONObject;
import com.productiontest.common.config.RuoYiConfig;
import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.common.core.text.Convert;
import com.productiontest.common.exception.ServiceException;
import com.productiontest.common.utils.DateUtils;
import com.productiontest.common.utils.ImsUtil;
import com.productiontest.common.utils.SecurityUtils;
import com.productiontest.common.vo.AuthRuleVo;
import com.productiontest.common.vo.LicenseRecycleData;
import com.productiontest.constant.CodeConstant;
import com.productiontest.domain.*;
import com.productiontest.encapsulation.LicenseReadTool;
import com.productiontest.encapsulation.ThirdPartyReadTool;
import com.productiontest.mapper.*;
import com.productiontest.service.IProductionWorkOrderService;
import com.productiontest.util.QcloudUtil;
import com.productiontest.util.ToolUtil;
import com.productiontest.util.UUIDGenerator;
import com.productiontest.vo.LicenseDataReq;
import com.productiontest.vo.ThirdPartyDataReq;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang3.RandomStringUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.File;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * 生产工单Service业务层处理
 *
 * @author cf
 * @date 2023-02-07
 */
@Service
public class ProductionWorkOrderImpl implements IProductionWorkOrderService {
    @Resource
    private ProductionWorkOrderMapper ProductionWorkOrderMapper;

    @Resource
    private DataDictionaryMapper datadictionarymapper;

    @Resource
    private ProductionWorkOrderTestdetailMapper productionworkordertestdetailmapper;

    @Resource
    private ProductionOrderMapper productionordermapper;

    @Resource
    private ProductionWorkOrderMapper productionworkordermapper;

    @Resource
    private InventoryTestRecordMapper InventoryTestRecordMapper;

    @Resource
    private LabelTemplateMapper LabelTemplateMapper;
    @Resource
    private ProductionTestUserMapper ProductionTestUserMapper;

    @Resource
    private UpdateOrderLogMapper updateOrderLogMapper;

    @Resource
    private ProductionTestUserCardMapper productionTestUserCardMapper;

    @Resource
    private ProductionTestUserMapper productionTestUserMapper;

    @Resource
    private FirmwareConfigMapper firmwareConfigMapper;

    @Resource
    private LicenseDataMapper licensedatamapper;
    @Resource
    private ImsUtil imsUtil;

    @Resource
    private ThirdPartyDataMapper thirdPartyDataMapper;

    SimpleDateFormat sd = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

    /**
     * 查询生产工单
     *
     * @param id 生产工单主键
     * @return 生产工单
     */
    @Override
    public ProductionWorkOrder selectProductionWorkOrderById(String id) {
        ProductionWorkOrder productionWorkOrder = ProductionWorkOrderMapper.selectProductionWorkOrderById(id);
        if (ObjectUtil.isNotNull(productionWorkOrder)) {
            if (ObjectUtil.isNotNull(productionWorkOrder.getArgumentConfig())) {
                Object provider = JSON.parseObject(productionWorkOrder.getArgumentConfig()).get("provider");
                if(provider!=null){
                    FirmwareConfig firmwareConfig = firmwareConfigMapper.selectFirmwareConfigByProvider(provider);
                    if (ObjectUtil.isNotNull(firmwareConfig)) {
                        String list = new ConfigUtil().buildConfig(productionWorkOrder.getArgumentConfig(), firmwareConfig.getItemList().toString());
                        productionWorkOrder.setArgumentConfigLabel(list);
                    }
                }
            }
        }
        return productionWorkOrder;
    }


    /**
     * 查询生产工单列表
     *
     * @param ProductionWorkOrder 生产工单
     * @return 生产工单
     */
    @Override
    public List<ProductionWorkOrder> selectProductionWorkOrderList(ProductionWorkOrder ProductionWorkOrder) {
        ProductionWorkOrder.setDeptId(SecurityUtils.getDeptId());
        List<ProductionWorkOrder> ls =  ProductionWorkOrderMapper.selectProductionWorkOrderList(ProductionWorkOrder);
        ls.forEach(wo->{
           int c = licensedatamapper.countFinish(wo.getWorkorderId());
           wo.setFinishNumber(c);
            int uc= wo.getProductNumber();
           wo.setAccreditRemaining((uc-c)+"");
           wo.setProductSchedule("0%");
           if(uc>0){
               int per = Convert.toInt(c * 1.0/uc*100);
               wo.setProductSchedule(per+"%");
           }
        });
        return ls;
    }


    /**
     * 新增生产工单
     *
     * @param productionWorkOrder 生产工单
     * @return 结果
     */
    @Override
    @Transactional
    public AjaxResult insertProductionWorkOrder(ProductionWorkOrder productionWorkOrder) {
        AjaxResult ajax = new AjaxResult();
        String UUID = UUIDGenerator.getUUID();
        productionWorkOrder.setId(UUID);
        productionWorkOrder.setWorkorderType("1");//工单类型 0 pcba 1整机
        productionWorkOrder.setCreateTime(sd.format(new Date()));
        productionWorkOrder.setWorkorderId(UUID);
        productionWorkOrder.setWorkorderNo(UUID);
        productionWorkOrder.setDeptId(SecurityUtils.getDeptId());
        productionWorkOrder.setRomFileMd(productionWorkOrder.getSign());
        String name = ProductionTestUserMapper.selectProductionTestUserByStringId(productionWorkOrder.getStationAccount());
        productionWorkOrder.setAccount(name);
        int count = ProductionWorkOrderMapper.getProductionWorkOrderCount(productionWorkOrder);
        if (count > 0) {
            throw new ServiceException("工单名称已存在");
        }
        //第三方授权
        List<ThirdPartyData> baseCodeList = new ArrayList<>();
        if (StringUtils.isNotEmpty(productionWorkOrder.getThirdPartyFile())) {
            JSONObject js = JSONObject.parseObject(productionWorkOrder.getThirdPartyFile());
            String url = RuoYiConfig.getUploadPath() + js.getString("name");
            String suffix = js.getString("name").substring(js.getString("name").lastIndexOf(".") + 1);
            if (suffix.equals("zip")) {
                baseCodeList = new ThirdPartyReadTool().zipReadBin(url);
            }
            if (baseCodeList.size() > 0) {
                String baseCodeName = thirdPartyDataMapper.selectThirdPartyDataByList(baseCodeList);
                if (ObjectUtil.isNotNull(baseCodeName)) {
                    ajax.put("code", 2002);
                    ajax.put("message", "第三方授权文件已经存在:" + baseCodeName);
                    return ajax;
                }
            } else {
                ajax.put("code", 2003);
                ajax.put("message", "未解析出base64编码");
                return ajax;
            }
        }

        int productNumber=0;
        ProductionOrder ord = productionordermapper.selectProductionOrderById(productionWorkOrder.getProductOrder());
        //上传license文件
        if (StringUtils.isNotEmpty(productionWorkOrder.getLicenseFile())) {
            JSONObject js = JSONObject.parseObject(productionWorkOrder.getLicenseFile());
            String url = RuoYiConfig.getUploadPath() + js.getString("name");
            String suffix = js.getString("name").substring(js.getString("name").lastIndexOf(".") + 1);
            List<String> repeatList = new ArrayList<>();
            if (suffix.equals("xls") || suffix.equals("xlsx")) {
                repeatList = new LicenseReadTool().excelRead(url);
            } else if (suffix.equals("txt")) {
                repeatList = new LicenseReadTool().txtRead(url);
            } else if (suffix.equals("zip")) {
                repeatList = new LicenseReadTool().zipRead(url);
            }
            String str = licensedatamapper.selectLicenseDataByLicenseList(repeatList);

            if (ObjectUtil.isNotNull(str)) {
                ajax.put("code", -2);
                ajax.put("license", str);
                return ajax;
            } else {
                licensedatamapper.insertLicenseDataList(repeatList, productionWorkOrder.getMark(), SecurityUtils.getDeptId(),ord.getId(),productionWorkOrder.getId(),productionWorkOrder.getCorps());
            }
            productNumber = repeatList.size();
        }else{//生成license
            productNumber = productionWorkOrder.getLicenseNum();
            AuthRuleVo ar=  JSON.parseObject(ord.getLicenseRule(), AuthRuleVo.class);

            if(productNumber>0) {
                List<String> arr = imsUtil.genLicense(SecurityUtils.getDeptId(), SecurityUtils.getUserId(), ord.getAppId(), productNumber, productionWorkOrder.getRemark(), productionWorkOrder.getCorps(), ar);

                if (arr.size() == 0) {
                    ajax.put("code", 2004);
                    ajax.put("message", "生成license失败");
                    return ajax;
                }
                licensedatamapper.insertLicenseDataList(arr, productionWorkOrder.getMark(), SecurityUtils.getDeptId(), ord.getId(), productionWorkOrder.getId(), productionWorkOrder.getCorps());
            }
        }

        productionWorkOrder.setProductNumber(productNumber);

        if(StringUtils.isBlank(productionWorkOrder.getArgumentConfig()) || "null".equalsIgnoreCase(productionWorkOrder.getArgumentConfig()) ){
            productionWorkOrder.setArgumentConfig(ord.getArgumentConfig());
        }

//        if(productionWorkOrder.getConfigType() !=null){
//            if (productionWorkOrder.getConfigType().equals(0) || productionWorkOrder.getConfigType().equals(1)) {
//                productionWorkOrder.setArgumentConfig(null);
//            }
//        }

        ProductionWorkOrderMapper.insertProductionWorkOrder(productionWorkOrder);

        baseCodeList.stream().forEach(x -> {
            ThirdPartyData thirdPartyData = new ThirdPartyData();
            thirdPartyData.setId(UUIDGenerator.getUUID());
            thirdPartyData.setBaseCode(x.getBaseCode());
            thirdPartyData.setMdConfig(x.getMdConfig());
            thirdPartyData.setCreateTime(DateUtils.getNowDate());
            thirdPartyData.setFileName(x.getFileName());
            thirdPartyData.setOrderId(ord.getId());
            thirdPartyData.setWorkorderId(productionWorkOrder.getId());
            thirdPartyDataMapper.insertThirdPartyData(thirdPartyData);
        });

        ajax.put("code", 200);
        return ajax;
    }

    /**
     * 修改生产工单
     *
     * @param productionWorkOrder 生产工单
     * @return 结果
     */
    @Override
    @Transactional
    public AjaxResult updateProductionWorkOrder(ProductionWorkOrder productionWorkOrder) {
        AjaxResult ajax = new AjaxResult();
        productionWorkOrder.setDeptId(SecurityUtils.getDeptId());
        productionWorkOrder.setPushStatus("wait");
        productionWorkOrder.setRomFileMd(productionWorkOrder.getSign());
        productionTestUserCardMapper.deleteProductionTestUserCardByWorkOrderId(productionWorkOrder.getId());
        int count = ProductionWorkOrderMapper.getProductionWorkOrderCount(productionWorkOrder);
        if (count > 0) {
            throw new ServiceException("工单名称已存在");
        }

        //第三方授权
        List<ThirdPartyData> baseCodeList = new ArrayList<>();
        if (StringUtils.isNotEmpty(productionWorkOrder.getThirdPartyFile())) {
            JSONObject js = JSONObject.parseObject(productionWorkOrder.getThirdPartyFile());
            String url = RuoYiConfig.getUploadPath() + js.getString("name");
            String suffix = js.getString("name").substring(js.getString("name").lastIndexOf(".") + 1);
            if (suffix.equals("zip")) {
                baseCodeList = new ThirdPartyReadTool().zipReadBin(url);
            }
            if (baseCodeList.size() > 0) {
                String baseCodeName = thirdPartyDataMapper.selectThirdPartyDataByList(baseCodeList);
                if (ObjectUtil.isNotNull(baseCodeName)) {
                    ajax.put("code", 2002);
                    ajax.put("message", "第三方授权文件已经存在:" + baseCodeName);
                    return ajax;
                }
            } else {
                ajax.put("code", 2003);
                ajax.put("message", "未解析出base64编码");
                return ajax;
            }
        }


        ProductionWorkOrder srwo= ProductionWorkOrderMapper.getWorkOrderInfo(productionWorkOrder.getId());
        Integer productNumber=0;
        ProductionOrder ord = productionordermapper.selectProductionOrderById(srwo.getProductOrder());
        //上传license文件
        if (StringUtils.isNotEmpty(productionWorkOrder.getLicenseFile())) {
            JSONObject js = JSONObject.parseObject(productionWorkOrder.getLicenseFile());
            String url = RuoYiConfig.getUploadPath() + js.getString("name");
            String suffix = js.getString("name").substring(js.getString("name").lastIndexOf(".") + 1);
            List<String> repeatList = new ArrayList<>();
            if (suffix.equals("xls") || suffix.equals("xlsx")) {
                repeatList = new LicenseReadTool().excelRead(url);
            } else if (suffix.equals("txt")) {
                repeatList = new LicenseReadTool().txtRead(url);
            } else if (suffix.equals("zip")) {
                repeatList = new LicenseReadTool().zipRead(url);
            }
            String str = licensedatamapper.selectLicenseDataByLicenseList(repeatList);

            if (ObjectUtil.isNotNull(str)) {
                ajax.put("code", -2);
                ajax.put("license", str);
                return ajax;
            } else {
                licensedatamapper.insertLicenseDataList(repeatList, productionWorkOrder.getMark(), SecurityUtils.getDeptId(),ord.getId(),productionWorkOrder.getId(),productionWorkOrder.getCorps());
            }
            productNumber = repeatList.size();
        }else{//生成license
            productNumber = productionWorkOrder.getLicenseNum();
            if(productNumber ==null){
                productNumber =0;
            }
            AuthRuleVo ar=  JSON.parseObject(ord.getLicenseRule(), AuthRuleVo.class);

            if(productNumber>0){
                List<String> arr =    imsUtil.genLicense(SecurityUtils.getDeptId(),SecurityUtils.getUserId(),ord.getAppId(),productNumber,productionWorkOrder.getRemark(),productionWorkOrder.getCorps(),ar);
                if (arr.size() == 0) {
                    ajax.put("code", 2004);
                    ajax.put("message", "生成license失败");
                    return ajax;
                }
                licensedatamapper.insertLicenseDataList(arr, productionWorkOrder.getMark(), SecurityUtils.getDeptId(),ord.getId(),productionWorkOrder.getId(),productionWorkOrder.getCorps());
            }
        }

        UpdateOrderLog updateOrderLog = new UpdateOrderLog();
        updateOrderLog.setId(UUIDGenerator.getUUID());
        updateOrderLog.setOddId(productionWorkOrder.getId());
        updateOrderLog.setUpdateBy(SecurityUtils.getUsername());
        updateOrderLog.setUpdateTime(sd.format(new Date()));
        updateOrderLog.setCreateTime(sd.format(new Date()));
        updateOrderLog.setType("WORK_ORDER");
        if (ObjectUtil.isNotNull(productionWorkOrder.getWorkorderStatus())) {
            if (productionWorkOrder.getWorkorderStatus().equals("3")) {
                updateOrderLog.setContent("取消工单");
            } else {
                updateOrderLog.setContent("编辑工单");
            }
        } else {
            updateOrderLog.setContent("编辑工单");
        }
        updateOrderLog.setDeptId(SecurityUtils.getDeptId());
        updateOrderLogMapper.insertUpdateOrderLog(updateOrderLog);
//        ProductionWorkOrder.setUserListJson(jsonArray.toString());
        if(StringUtils.isBlank(productionWorkOrder.getArgumentConfig()) || "null".equalsIgnoreCase(productionWorkOrder.getArgumentConfig()) ){
            productionWorkOrder.setArgumentConfig(ord.getArgumentConfig());
        }
        productionWorkOrder.setProductNumber(srwo.getProductNumber()+productNumber);

        ProductionWorkOrderMapper.updateProductionWorkOrderById(productionWorkOrder);

        baseCodeList.stream().forEach(x -> {
            ThirdPartyData thirdPartyData = new ThirdPartyData();
            thirdPartyData.setId(UUIDGenerator.getUUID());
            thirdPartyData.setBaseCode(x.getBaseCode());
            thirdPartyData.setMdConfig(x.getMdConfig());
            thirdPartyData.setCreateTime(DateUtils.getNowDate());
            thirdPartyData.setFileName(x.getFileName());
            thirdPartyData.setOrderId(ord.getId());
            thirdPartyData.setWorkorderId(productionWorkOrder.getId());
            thirdPartyDataMapper.insertThirdPartyData(thirdPartyData);
        });

        ajax.put("code", 200);
        return ajax;
    }


    /**
     * 批量删除生产工单
     *
     * @param ids 需要删除的生产工单主键
     * @return 结果
     */
    @Override
    public int deleteProductionWorkOrderByIds(String[] ids) {
        for(String id: ids){
            licenseRecycle(id);
        }
        return ProductionWorkOrderMapper.deleteProductionWorkOrderByIds(ids);
    }

    /**
     * 删除生产工单信息
     *
     * @param id 生产工单主键
     * @return 结果
     */
    @Override
    public int deleteProductionWorkOrderById(String id) {
        licenseRecycle(id);
        return ProductionWorkOrderMapper.deleteProductionWorkOrderById(id);
    }

    @Override
    public ProductionWorkOrder getStatisticsProductionWorkOrder(ProductionWorkOrder ProductionWorkOrder) {
        // TODO Auto-generated method stub
        ProductionWorkOrder.setDeptId(SecurityUtils.getDeptId());
        return ProductionWorkOrderMapper.getStatisticsProductionWorkOrder(ProductionWorkOrder);
    }

    @Override
    public int selectProductionWorkOrderCount(ProductionWorkOrder ProductionWorkOrder) {
        int count = 0;
        if (ProductionWorkOrder.getId() == "0") {
            count = ProductionWorkOrderMapper.selectProductionWorkOrderCount(ProductionWorkOrder);
        } else {
            ProductionWorkOrder pwo = ProductionWorkOrderMapper
                    .selectProductionWorkOrderById(ProductionWorkOrder.getId());
            int result = ProductionWorkOrderMapper.selectProductionWorkOrderCount(ProductionWorkOrder);
            if (pwo.getId().equals(ProductionWorkOrder.getId())) {
                if (pwo.getWorkorderName().equals(ProductionWorkOrder.getWorkorderName())) {
                    count = 0;
                } else {
                    count = result;
                }
            }

        }
        return count;
    }

    @Override
    public JSONObject getWorkOrderList(JSONObject js) {
        JSONObject json = new JSONObject();
        JSONObject json2 = new JSONObject();
        List<Map<String, Object>> map = new ArrayList<Map<String, Object>>();
        try {
            List<ProductionWorkOrder> data = ProductionWorkOrderMapper.getWorkOrderList(js.getString("Account"));

            data.stream().forEach(x -> {
                Map<String, Object> m = new HashMap<String, Object>();
                m.put("FinishFlag", x.getFinishFlag());
                m.put("WorkOrderNo", x.getWorkorderNo());
                m.put("ProductType", x.getWorkorderType());
                m.put("WorkOrderID", x.getWorkorderId());
                m.put("WorkOrderName", x.getWorkorderName());
                m.put("CTEITotalNum", x.getLicenseTotalNum());
                m.put("CTEIRemainNum", x.getLicenseUsableAuth());
                int count = 0;
                if (ObjectUtil.isNotNull(x.getNetAccessType())) {
                    for (String s : x.getNetAccessType().split(",")) {
                        if (s.equals("WiFi")) {
                            count += 2;
                        }
                        if (s.equals("4G")) {
                            count += 8;
                        }
                        if (s.equals("有线")) {
                            count += 1;
                        }
                    }
                }
                m.put("WorkOrderTotalNumber", x.getWorkOrderTotalNumber());
                List<String> passCount = ProductionWorkOrderMapper.selectCountWorkOrderInDeviceSn(x.getWorkorderId(), "1");
                m.put("WorkOrderPassedNum", passCount.size());
                m.put("NetAccessType", count);
                map.add(m);
            });
            json.put("CODE", 0);
            json2.put("WorkList", map);
            json.put("BODY", json2);
        } catch (Exception e) {
            json.put("CODE", -1);
            e.printStackTrace();
        }
        return json;
    }

    @Override
    public JSONObject getWorkOrderInfo(JSONObject ob) {
        String workOrderID = ob.getString("WorkOrderID");
        JSONObject json = new JSONObject();
        JSONObject json2 = new JSONObject();
        // JSONObject json3 = new JSONObject();
        Map<String, Object> map = new HashMap<String, Object>();
        Map<String, Object> maptestInfo = new HashMap<String, Object>();
        Map<String, Object> mapprouct = new HashMap<String, Object>();
        Map<String, Object> labelMap = new HashMap<String, Object>();
        List<Map<String, Object>> list = new ArrayList<>();
        try {
            ProductionWorkOrder oe = ProductionWorkOrderMapper.getWorkOrderInfo(workOrderID);
            List<String> cardList = productionTestUserCardMapper.selectProductionTestUserCardByUserId(oe.getStationAccount(), workOrderID);
            json.put("CODE", 0);
            int count = 0;
            if (oe != null) {
                ProductionOrder order = productionordermapper.selectProductionOrderById(oe.getProductOrder());
                map.put("WorkOrderTime", oe.getBeginTime());
                map.put("FinishTime", oe.getFinishTime());
                map.put("TotalNumber", oe.getProductNumber());
                map.put("Custome", oe.getRemark());
                if (ObjectUtil.isNotNull(oe)) {
                    if (StringUtils.isNotEmpty(String.valueOf(oe.getTemplateId())) && oe.getTemplateId() != null) {
                        LabelTemplate lt = LabelTemplateMapper.selectLabelTemplateById(oe.getTemplateId());
                        labelMap.put("LabelName", lt.getName());
                        labelMap.put("LabelURL", lt.getHttpFile());
                    } else {
                        labelMap.put("LabelName", "");
                        labelMap.put("LabelURL", "");
                    }

                    map.put("CommunicationModeName", order.getCommunicationModeName());
                    map.put("CTEITotalNum", order.getLicenseTotalNum());
                    map.put("CTEIRemainNum", order.getUsableAuth());


                    for (String s : order.getCommunicationModeName().split(",")) {
                        if (s.equals("WiFi")) {
                            count += 2;
                        }
                        if (s.equals("4G")) {
                            count += 8;
                        }
                        if (s.equals("有线")) {
                            count += 1;
                        }
                    }
                } else {
                    labelMap.put("LabelName", "");
                    labelMap.put("LabelURL", "");
                    map.put("CommunicationModeName", "");
                    map.put("CTEITotalNum", "");
                    map.put("CTEIRemainNum", "");
                }
                json2.put("ProductType", oe.getWorkorderType());
                json2.put("NetAccessType", count);
                json2.put("OrderInfo", map);
                json2.put("SIMCards", cardList.toArray());
                json2.put("LabelInfo", labelMap);


                if (StringUtils.isNotEmpty(oe.getTestItem())) {
                    Arrays.asList(oe.getTestItem().split(",")).forEach(x -> {
                        DataDictionary da = datadictionarymapper.selectDataDictionaryById(Long.parseLong(x));
                        Map<String, Object> mapitem = new HashMap<String, Object>();
                        if (ObjectUtil.isNotNull(da)) {
                            mapitem.put("TestNo", da.getDataNo());
                            mapitem.put("TestName", da.getDataKey());
                            mapitem.put("Auto", da.getDataItem());
                            list.add(mapitem);
                        }

                    });
                }
                json2.put("TestItem", list);

                Map<Object, Object> testmap = productionworkordertestdetailmapper
                        .selectTestDetailSumByworkorderId(workOrderID);
                List<String> passList = productionworkordermapper.selectCountWorkOrderInDeviceSn(workOrderID, "1");
                List<String> NopassList = productionworkordermapper.selectCountWorkOrderInDeviceSn(workOrderID, "0");
                if (testmap != null) {
//                    int num = 0;
//                    ProductionWorkOrder wo = productionworkordermapper.getWorkOrderInfo(workOrderID);
//                    if (wo != null) {
//                        num = wo.getProductNumber();
//                    }
                    maptestInfo.put("SpendTime", testmap.get("testSumduration")); // 测试花费总时间
//                    maptestInfo.put("PassedNum", testmap.get("passEquipmentsum"));// 测试通过数目
                    maptestInfo.put("PassedNum", passList.size());// 测试通过数目
                    maptestInfo.put("FailedNum", NopassList.size());// 测试未通过数目

                } else {
                    maptestInfo.put("SpendTime", "");
                    maptestInfo.put("PassedNum", "");
                    maptestInfo.put("FailedNum", "");
                }
                json2.put("TestInfo", maptestInfo);

                // ProductionOrder order =
                // productionordermapper.selectProductionOrderById(oe.getProductOrder());
                DataDictionary data = new DataDictionary();
                data.setDataType("Subdomains");
                List<DataDictionary> dict = datadictionarymapper.selectDataDictionaryList(data);
                if (order != null) {
                    mapprouct.put("ProductName", order.getProductName());
                    mapprouct.put("CompanyID", order.getCompanyId());
                    mapprouct.put("AppID", order.getAppId());
                    mapprouct.put("Subdomains", dict.get(0).getDataValue());
                    mapprouct.put("FirmwareVersion", oe.getFirmwareVersion());
                    mapprouct.put("ConfigMD5", oe.getDeviceConfigMd());
                }
                json2.put("ProductInf", mapprouct);

                json.put("BODY", json2);
            }
        } catch (Exception e) {
            json.put("CODE", -1);
            e.printStackTrace();
        }
        return json;
    }

    @Override
    public JSONObject noticeWorkOrderStatus(JSONObject json) {
        // TODO Auto-generated method stub

        JSONObject js = new JSONObject();
        Map<String, String> map = new HashMap<>();
        SimpleDateFormat sd = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        ProductionWorkOrder workorder = productionworkordermapper
                .selectProductionWorkOrderByWorkOrderId(json.getString("WorkOrderId"));
        if (workorder != null) {
            ProductionWorkOrderTestdetail pot = new ProductionWorkOrderTestdetail();
            pot.setAccount(json.getString("Account"));
            pot.setWorkorderId(json.getString("WorkOrderId"));
            pot.setFlag(Long.parseLong(json.getString("Flag")));
            pot.setTestEquipmentsum(workorder.getProductNumber());
            pot.setId(UUIDGenerator.getUUID());
            js.put("CODE", 0);
            if (json.getString("Flag").equals("1")) {
                String remark = RandomStringUtils.randomNumeric(15);
                pot.setBeginTime(sd.format(new Date()));
                pot.setRemark(remark);
                map.put("Remark", remark);

                ProductionOrder order = new ProductionOrder();
                order.setId(workorder.getProductOrder());
                order.setOrderStatus(1L);
                order.setPushStatus("wait");
                productionordermapper.updateProductionOrder(order);
                if (StringUtils.isEmpty(workorder.getBeginTime())) {
                    ProductionWorkOrder pwo = new ProductionWorkOrder();
                    pwo.setId(workorder.getId());
                    pwo.setWorkorderStatus(1L);
                    pwo.setBeginTime(sd.format(new Date()));
                    pwo.setPushStatus("wait");
                    productionworkordermapper.updateProductionWorkOrder(pwo);
                }
                productionworkordertestdetailmapper.insertProductionWorkOrderTestdetail(pot);

            } else {
                if (StringUtils.isEmpty(json.getString("Remark"))) {
                    return js;
                }
                ProductionWorkOrder pwo = new ProductionWorkOrder();
                pwo.setId(workorder.getId());
                pwo.setFinishTime(sd.format(new Date()));
                pwo.setPushStatus("wait");
                productionworkordermapper.updateProductionWorkOrder(pwo);
//                JSONObject ob1=JSONObject.parseObject(js.getString("Remark"));
//                JSONObject json2=ob1.getJSONObject("BODY");
//                System.out.println(json2.getString("Remark"));
                // 查询remark的数据
                ProductionWorkOrderTestdetail ot = productionworkordertestdetailmapper
                        .selectProductionWorkOrderTestdetailByRemark(json.getString("Remark"));
                ProductionWorkOrderTestdetail detail = new ProductionWorkOrderTestdetail();
                detail.setEndTime(sd.format(new Date()));
                detail.setTestSumduration(getTime(ot.getBeginTime(), sd.format(new Date())));
                detail.setId(ot.getId());
                detail.setPushStatus("wait");
                productionworkordertestdetailmapper.updateProductionWorkOrderTestdetail(detail);

//                List<InventoryTestRecord> list = InventoryTestRecordMapper.selectInventoryTestRecordByWordOrderId(json.getString("WorkOrderId"));
                int testCount = InventoryTestRecordMapper.selectCountTestRecordInOrder(json.getString("WorkOrderId"));
                ProductionOrder order = productionordermapper.selectProductionOrderById(workorder.getProductOrder());
                if (testCount >= order.getProductionQuantity()) {
                    ProductionOrder der = new ProductionOrder();
                    der.setId(order.getId());
                    der.setOrderStatus(2L);
                    der.setPushStatus("wait");
                    productionordermapper.updateProductionOrder(der);
                }
            }
        }

        js.put("BODY", map);
        return js;
    }

    @Override
    public AjaxResult uploadFourCard(MultipartFile file, String id) {
        AjaxResult ajax = new AjaxResult();
        try {
            String filePath = RuoYiConfig.getUploadPath();
            File fe = new File(filePath);
            if (!fe.exists()) {
                fe.mkdirs();
            }
            String path = filePath + file.getOriginalFilename();
            FileUtil.writeBytes(file.getBytes(), path);
            ajax.put("httpUrl", "");
            if (new ToolUtil().getNetwork()) {
                // 上传文件到oss中
                Map<String, String> map = new QcloudUtil().uploadFileInput(file);
                if (map.get("code").equals("200")) {
                    ajax.put("httpUrl", map.get("url"));
                }
            }
            byte[] bytes = file.getBytes();
            String sign = DigestUtils.md5Hex(bytes);
            ajax.put("md5", sign);
            ajax.put("newFileName", file.getOriginalFilename());
            ajax.put("originalFilename", file.getOriginalFilename());
            ajax.put("fileName", file.getOriginalFilename());
            ajax.put("url", RuoYiConfig.getNginxFile() + file.getOriginalFilename());
        } catch (Exception e) {
            ajax.put("code", CodeConstant.uploadErrorCode);
            e.printStackTrace();
        }
        return ajax;
    }

    @Override
    public AjaxResult selectWorkOrderUserListById(String id) {
        ProductionWorkOrder productionWorkOrder = productionworkordermapper.selectProductionWorkOrderById(id);
        ProductionOrder productionOrder = productionordermapper.selectProductionOrderById(productionWorkOrder.getProductOrder());
        if (productionOrder.getCommunicationModeName().contains("4G")) {
            JSONArray jsonArray = JSONArray.parseArray(productionWorkOrder.getUserListJson());
            List<ProductionTestUser> testUserList = jsonArray.toJavaList(ProductionTestUser.class);
            return AjaxResult.success(testUserList);
        }
        List<ProductionTestUser> testUserList = productionTestUserMapper.selectWorkOrderUserListById(id);
        return AjaxResult.success(testUserList);
    }

    @Override
    public JSONObject selectWorkOrderDeviceConfig(JSONObject json) {
        JSONObject js = new JSONObject();
        js.put("CODE", 0);
        Map<String, Object> map = new HashMap<>();
        String workOrderID = json.getString("WorkOrderID");
        ProductionWorkOrder productionWorkOrder = productionworkordermapper.selectProductionWorkOrderByWorkOrderId(workOrderID);
        if (ObjectUtil.isNotNull(productionWorkOrder)) {
            map.put("CfgJson", productionWorkOrder.getArgumentConfig());
            if (ObjectUtil.isNotNull(productionWorkOrder.getArgumentConfig())) {
                map.put("CfgMD5", DigestUtils.md5Hex(productionWorkOrder.getArgumentConfig()));
            } else {
                map.put("CfgMD5", null);
            }
            if (ObjectUtil.isNotNull(productionWorkOrder.getFirmwareConfig())) {
                map.put("CfgTemplate", JSON.toJSONString(productionWorkOrder.getFirmwareConfig()));
            } else {
                map.put("CfgTemplate", null);
            }
            js.put("BODY", map);
        }
        return js;
    }

    ;


    public static long getTime(String startTime, String endTime) {
        long diff = 0;
        try {
            SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            long eTime = df.parse(endTime).getTime();
            long sTime = df.parse(startTime).getTime();
            diff = (eTime - sTime) / 1000;
        } catch (Exception e) {
            e.printStackTrace();
        }
        return diff;
    }



    public AjaxResult updateStatus(String workorderId,Long status) {
        if(status == 0){
           int c =  licensedatamapper.countFinish(workorderId);
           if(c>0){
               status =1L;
           }
        }
        ProductionWorkOrder w=new ProductionWorkOrder();
        w.setWorkorderId(workorderId);
        w.setWorkorderStatus(status);
        productionworkordermapper.updateProductionWorkOrderByWorkorderId(w);
        return AjaxResult.success();
    }

    public AjaxResult delete(String workorderId){
        licenseRecycle(workorderId);
        ProductionWorkOrderMapper.deleteProductionWorkOrderByIds(new String[]{workorderId});

        return AjaxResult.success();
    }

    public List<LicenseData> licenseList(LicenseDataReq req){
       return licensedatamapper.licenseList(req);
    }
    public List<ThirdPartyData> thirdPartyDataList(ThirdPartyDataReq req){
       return thirdPartyDataMapper.thirdPartyDataList(req);
    }

    public void licenseRecycle(String workodrderId){
            ProductionWorkOrder workorder= productionworkordermapper.getWorkOrderInfo(workodrderId);
            if(workorder !=null){
                ProductionOrder order =  productionordermapper.selectProductionOrderById(workorder.getProductOrder());
                if(order !=null){
                    LicenseRecycleData data = new LicenseRecycleData();
                    data.setProductId(order.getAppId());
                    data.setProductName(order.getProductName());
                    data.setOrderId(workorder.getProductOrder());
                    data.setOrderName(order.getOrderName());
                    data.setWorkorderName(workorder.getWorkorderName());
                    data.setWorkorderId(workodrderId);
                    data.setDeptId(SecurityUtils.getDeptId());
                    data.setRecycleType(1);

                    LicenseDataReq req=new LicenseDataReq();
                    req.setWorkorderId(workodrderId);
                    List<LicenseData> ls= licensedatamapper.licenseList(req);
                    List<LicenseRecycleData.LicenseVo> lics=new ArrayList<>();
                    ls.forEach(l->{
                        LicenseRecycleData.LicenseVo v=new LicenseRecycleData.LicenseVo();
                        v.setLicense(l.getLicense());
                        // 0   已创建（已生成）     1   已生产           2    已激活x
                        v.setLicenseStatus("0");
                        if("1".equals(l.getBurnStatus())){
                            v.setLicenseStatus("1");
                        }
                        v.setReqStatus(l.getStatus());
                        v.setBurnStatus(l.getBurnStatus());
                        v.setAuthNo(l.getAuthValue());
                        lics.add(v);
                    });

                    data.setLics(lics);
                    ThreadUtil.execute(()->{
                        String rsp =  imsUtil.licenseRecycle(data);
                        if (StrUtil.isNotBlank(rsp)) {
                            JSONObject obj= JSON.parseObject(rsp);
                            if(obj !=null && obj.getIntValue("code") == 200){
                                ls.forEach(l-> {
                                    licensedatamapper.deleteLicenseById(l.getId());
                                });
                            }
                        }
                    });

                }
            }
    }
}
