package com.productiontest.service.impl;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

import com.productiontest.common.utils.SecurityUtils;
import com.productiontest.util.UUIDGenerator;
import org.apache.commons.lang3.RandomStringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.productiontest.common.utils.DateUtils;
import com.productiontest.domain.ShippingRecord;
import com.productiontest.mapper.ShippingRecordMapper;
import com.productiontest.service.IShippingRecordService;

/**
 * 出货记录Service业务层处理
 * 
 * @author cf
 * @date 2023-02-13
 */
@Service
public class ShippingRecordServiceImpl implements IShippingRecordService {
	@Autowired
	private ShippingRecordMapper shippingRecordMapper;

	/**
	 * 查询出货记录
	 * 
	 * @param id
	 *            出货记录主键
	 * @return 出货记录
	 */
	@Override
	public ShippingRecord selectShippingRecordById(Long id) {
		return shippingRecordMapper.selectShippingRecordById(id);
	}

	/**
	 * 查询出货记录列表
	 * 
	 * @param shippingRecord
	 *            出货记录
	 * @return 出货记录
	 */
	@Override
	public List<ShippingRecord> selectShippingRecordList(ShippingRecord shippingRecord) {
		shippingRecord.setDeptId(SecurityUtils.getDeptId());
		return shippingRecordMapper.selectShippingRecordList(shippingRecord);
	}

	/**
	 * 新增出货记录
	 * 
	 * @param shippingRecord
	 *            出货记录
	 * @return 结果
	 */
	@Override
	public int insertShippingRecord(ShippingRecord shippingRecord) {
		SimpleDateFormat sd = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
		shippingRecord.setCreateTime(DateUtils.getNowDate());
		shippingRecord.setDeptId(SecurityUtils.getDeptId());
		shippingRecord.setTaskNumber(RandomStringUtils.randomAlphanumeric(15));
//		shippingRecord.setCreatetime(sd.format(new Date()));
		shippingRecord.setCreateUser(SecurityUtils.getUsername());
		shippingRecord.setId(UUIDGenerator.getUUID());
		return shippingRecordMapper.insertShippingRecord(shippingRecord);
	}

	public static void main(String[] args) {
		System.out.println(RandomStringUtils.randomAlphanumeric(15));
	}
	/**
	 * 修改出货记录
	 * 
	 * @param shippingRecord
	 *            出货记录
	 * @return 结果
	 */
	@Override
	public int updateShippingRecord(ShippingRecord shippingRecord) {
		return shippingRecordMapper.updateShippingRecord(shippingRecord);
	}

	/**
	 * 批量删除出货记录
	 * 
	 * @param ids
	 *            需要删除的出货记录主键
	 * @return 结果
	 */
	@Override
	public int deleteShippingRecordByIds(Long[] ids) {
		return shippingRecordMapper.deleteShippingRecordByIds(ids);
	}

	/**
	 * 删除出货记录信息
	 * 
	 * @param id
	 *            出货记录主键
	 * @return 结果
	 */
	@Override
	public int deleteShippingRecordById(Long id) {
		return shippingRecordMapper.deleteShippingRecordById(id);
	}
}
