package com.productiontest.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONArray;
import com.productiontest.common.core.domain.AjaxResult;
import com.productiontest.common.utils.DateUtils;
import com.productiontest.common.utils.SecurityUtils;
import com.productiontest.domain.*;
import com.productiontest.framework.web.domain.server.Sys;
import com.productiontest.mapper.*;
import com.productiontest.service.SynchronizationDataService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;

@Service
public class SynchronizationDataServiceImpl implements SynchronizationDataService {
    private final Logger logger = LoggerFactory.getLogger(SynchronizationDataServiceImpl.class);

    @Autowired
    private AgingTaskMapper agingTaskMapper;
    @Autowired
    private AgingTaskDetailMapper agingTaskDetailMapper;
    @Autowired
    private InventoryTestRecordMapper inventoryTestRecordMapper;
    @Autowired
    private LabelTemplateMapper labelTemplateMapper;
    @Autowired
    private LicenseDataMapper licenseDataMapper;
    @Autowired
    private ProductionInventoryMapper productionInventoryMapper;
    @Autowired
    private ProductionOrderMapper productionOrderMapper;
    @Autowired
    private ProductionTestUserMapper productionTestUserMapper;
    @Autowired
    private ProductionTestUserCardMapper productionTestUserCardMapper;
    @Autowired
    private ProductionWorkOrderMapper productionWorkOrderMapper;
    @Autowired
    private ProductionWorkOrderTestdetailMapper productionWorkOrderTestdetailMapper;
    @Autowired
    private ShippingRecordMapper shippingRecordMapper;
    @Autowired
    private ThirdPartyDataMapper thirdPartyDataMapper;
    @Autowired
    private UpdateOrderLogMapper updateOrderLogMapper;

    @Override
    public Map<String, Object> pushData(Map<String, Object> paramMap) {
        Map<String, Object> resultMap = new HashMap<>();
        logger.info("paramMap:{}", paramMap);
        /** 获取老化任务数据表List ******************/
        resultMap.put("publicAgingTaskList", buildAgingTask(paramMap).get("publicAgingTaskList"));
        resultMap.put("returnAgingList", buildAgingTask(paramMap).get("returnAgingList"));

        /** 获取老化任务-详情List ******************/
        resultMap.put("publicAgingTaskDetailList", buildAgingTaskDetail(paramMap).get("publicAgingTaskDetailList"));
        resultMap.put("returnDetailList", buildAgingTaskDetail(paramMap).get("returnDetailList"));

        /** 获取生产库存-测试记录数据表List ******************/
        resultMap.put("publicTestRecordList", buildInventoryTestRecord(paramMap).get("publicTestRecordList"));
        resultMap.put("returnRecordList", buildInventoryTestRecord(paramMap).get("returnRecordList"));

        /***************** 获取标签模板数据表List ******************/
        resultMap.put("publicLabelTemplateList", buildLabelTemplate(paramMap).get("publicLabelTemplateList"));
        resultMap.put("returnTemplateList", buildLabelTemplate(paramMap).get("returnTemplateList"));

        /*****************License数据表List ******************/
        resultMap.put("publicLicenseDataList", buildLicenseData(paramMap).get("publicLicenseDataList"));
        resultMap.put("returnLicenseList", buildLicenseData(paramMap).get("returnLicenseList"));

        /*****************生产库存-数据表List ******************/
        resultMap.put("publicInventoryList", buildInventory(paramMap).get("publicInventoryList"));
        resultMap.put("returnInventoryList", buildInventory(paramMap).get("returnInventoryList"));

        /*****************生产订单-数据表List ******************/
        resultMap.put("publicOrderList", buildOrder(paramMap).get("publicOrderList"));
        resultMap.put("returnOrderList", buildOrder(paramMap).get("returnOrderList"));

        /*****************产测人员-数据表List ******************/
        resultMap.put("publicTestUserList", buildTestUser(paramMap).get("publicTestUserList"));
        resultMap.put("returnTestUserList", buildTestUser(paramMap).get("returnTestUserList"));

        /*****************产测人员4G卡号-列表List ******************/
        resultMap.put("publicCardList", buildCard(paramMap).get("publicCardList"));
        resultMap.put("returnCardList", buildCard(paramMap).get("returnCardList"));

        /*****************生产工单-列表List ******************/
        resultMap.put("publicWorkOrderList", buildWorkOrder(paramMap).get("publicWorkOrderList"));
        resultMap.put("returnWorkOrderList", buildWorkOrder(paramMap).get("returnWorkOrderList"));

        /*****************生产工单-详情-列表List ******************/
        resultMap.put("publicWorkOrderDetailList", buildWorkOrderDetail(paramMap).get("publicWorkOrderDetailList"));
        resultMap.put("returnWorkOrderDetailList", buildWorkOrderDetail(paramMap).get("returnWorkOrderDetailList"));

        /*****************出货记录-列表List ******************/
        resultMap.put("publicShippingRecordList", buildShippingRecord(paramMap).get("publicShippingRecordList"));
        resultMap.put("returnShippingRecordList", buildShippingRecord(paramMap).get("returnShippingRecordList"));

        /*****************第三方授权-列表List ******************/
        resultMap.put("publicThirdPartyList", buildThirdParty(paramMap).get("publicThirdPartyList"));
        resultMap.put("returnThirdPartyDataList", buildThirdParty(paramMap).get("returnThirdPartyDataList"));

        /*****************修改日志-列表List ******************/
        resultMap.put("publicUpdateLogList", buildUpdateLog(paramMap).get("publicUpdateLogList"));
        resultMap.put("returnUpdateOrderLogList", buildUpdateLog(paramMap).get("returnUpdateOrderLogList"));

        return resultMap;
    }

    @Override
    public Map<String, Object> updateData(Map<String, Object> paramMap) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray agingJsonArray = JSONArray.parseArray(JSON.toJSONString(paramMap.get("updateAgingList")));
        if (ObjectUtil.isNotNull(agingJsonArray)) {
            List<AgingTask> agingList = agingJsonArray.toJavaList(AgingTask.class);
            agingList.stream().forEach(x -> {
                AgingTask agingTask = new AgingTask();
                agingTask.setId(x.getId());
                agingTask.setPushStatus("push");
                agingTaskMapper.updateAgingTask(agingTask);
            });
        }
        JSONArray detailJsonArray = JSONArray.parseArray(JSON.toJSONString(paramMap.get("updateAgingTaskDetailList")));
        if (ObjectUtil.isNotNull(detailJsonArray)) {
            List<AgingTaskDetail> detailList = detailJsonArray.toJavaList(AgingTaskDetail.class);
            detailList.stream().forEach(x -> {
                AgingTaskDetail agingTaskDetail = new AgingTaskDetail();
                agingTaskDetail.setId(x.getId());
                agingTaskDetail.setPushStatus("push");
                agingTaskDetailMapper.updateAgingTaskDetail(agingTaskDetail);
            });
        }

        JSONArray recordJsonArray = JSONArray.parseArray(JSON.toJSONString(paramMap.get("updateInventoryTestRecordList")));
        logger.error("paramMap==============="+paramMap);
        if (ObjectUtil.isNotNull(recordJsonArray)) {
            List<InventoryTestRecord> recordList = recordJsonArray.toJavaList(InventoryTestRecord.class);
            recordList.stream().forEach(x -> {
                InventoryTestRecord inventoryTestRecord = new InventoryTestRecord();
                inventoryTestRecord.setId(x.getId());
                inventoryTestRecord.setPushStatus("push");
                inventoryTestRecordMapper.updateInventoryTestRecord(inventoryTestRecord);
            });
        }

        JSONArray labelTemplateJsonArray = JSONArray.parseArray(JSON.toJSONString(paramMap.get("updateLabelTemplateList")));
        if (ObjectUtil.isNotNull(labelTemplateJsonArray)) {
            List<LabelTemplate> templateList = labelTemplateJsonArray.toJavaList(LabelTemplate.class);
            templateList.stream().forEach(x -> {
                LabelTemplate labelTemplate = new LabelTemplate();
                labelTemplate.setId(x.getId());
                labelTemplate.setPushStatus("push");
                labelTemplateMapper.updateLabelTemplate(labelTemplate);
            });
        }


        JSONArray licenseJsonArray = JSONArray.parseArray(JSON.toJSONString(paramMap.get("updateLicenseList")));
        if (ObjectUtil.isNotNull(licenseJsonArray)) {
            List<LicenseData> licenseList = licenseJsonArray.toJavaList(LicenseData.class);
            licenseList.stream().forEach(x -> {
                LicenseData licenseData = new LicenseData();
                licenseData.setId(x.getId());
                licenseData.setPushStatus("push");
                licenseDataMapper.updateLicenseData(licenseData);
            });
        }

        JSONArray inventoryJsonArray = JSONArray.parseArray(JSON.toJSONString(paramMap.get("updateProductionInventoryList")));
        if (ObjectUtil.isNotNull(inventoryJsonArray)) {
            List<ProductionInventory> inventoryList = inventoryJsonArray.toJavaList(ProductionInventory.class);
            inventoryList.stream().forEach(x -> {
                ProductionInventory inventory = new ProductionInventory();
                inventory.setId(x.getId());
                inventory.setPushStatus("push");
                productionInventoryMapper.updateProductionInventory(inventory);
            });
        }

        JSONArray orderJsonArray = JSONArray.parseArray(JSON.toJSONString(paramMap.get("updateProductionOrderList")));
        if (ObjectUtil.isNotNull(orderJsonArray)) {
            List<ProductionOrder> orderList = orderJsonArray.toJavaList(ProductionOrder.class);
            orderList.stream().forEach(x -> {
                ProductionOrder order = new ProductionOrder();
                order.setId(x.getId());
                order.setPushStatus("push");
                productionOrderMapper.updateProductionOrder(order);
            });
        }

        JSONArray testUserJsonArray = JSONArray.parseArray(JSON.toJSONString(paramMap.get("updateProductionTestUserList")));
        if (ObjectUtil.isNotNull(testUserJsonArray)) {
            List<ProductionTestUser> testUserList = testUserJsonArray.toJavaList(ProductionTestUser.class);
            testUserList.stream().forEach(x -> {
                ProductionTestUser testUser = new ProductionTestUser();
                testUser.setId(x.getId());
                testUser.setPushStatus("push");
                productionTestUserMapper.updateProductionTestUser(testUser);
            });
        }

        JSONArray cardJsonArray = JSONArray.parseArray(JSON.toJSONString(paramMap.get("updateCardList")));
        if (ObjectUtil.isNotNull(cardJsonArray)) {
            List<ProductionTestUserCard> cardList = cardJsonArray.toJavaList(ProductionTestUserCard.class);
            cardList.stream().forEach(x -> {
                ProductionTestUserCard testUserCard = new ProductionTestUserCard();
                testUserCard.setId(x.getId());
                testUserCard.setPushStatus("push");
                productionTestUserCardMapper.updateProductionTestUserCard(testUserCard);
            });
        }
        JSONArray workOrderJsonArray = JSONArray.parseArray(JSON.toJSONString(paramMap.get("updateWorkOrderList")));
        if (ObjectUtil.isNotNull(workOrderJsonArray)) {
            List<ProductionWorkOrder> workOrderList = workOrderJsonArray.toJavaList(ProductionWorkOrder.class);
            workOrderList.stream().forEach(x -> {
                ProductionWorkOrder productionWorkOrder = new ProductionWorkOrder();
                productionWorkOrder.setId(x.getId());
                productionWorkOrder.setPushStatus("push");
                productionWorkOrderMapper.updateProductionWorkOrder(productionWorkOrder);
            });
        }
        JSONArray shippingRecordJsonArray = JSONArray.parseArray(JSON.toJSONString(paramMap.get("updateShippingRecordList")));
        if (ObjectUtil.isNotNull(shippingRecordJsonArray)) {
            List<ShippingRecord> shippingRecordList = shippingRecordJsonArray.toJavaList(ShippingRecord.class);
            shippingRecordList.stream().forEach(x -> {
                ShippingRecord shippingRecord = new ShippingRecord();
                shippingRecord.setId(x.getId());
                shippingRecord.setPushStatus("push");
                shippingRecordMapper.updateShippingRecord(shippingRecord);
            });
        }

        JSONArray workOrderDetailJsonArray = JSONArray.parseArray(JSON.toJSONString(paramMap.get("updateWorkOrderDetailList")));
        if (ObjectUtil.isNotNull(workOrderDetailJsonArray)) {
            List<ProductionWorkOrderTestdetail> workOrderDetailList = workOrderDetailJsonArray.toJavaList(ProductionWorkOrderTestdetail.class);
            workOrderDetailList.stream().forEach(x -> {
                ProductionWorkOrderTestdetail productionWorkOrderTestdetail = new ProductionWorkOrderTestdetail();
                productionWorkOrderTestdetail.setId(x.getId());
                productionWorkOrderTestdetail.setPushStatus("push");
                productionWorkOrderTestdetailMapper.updateProductionWorkOrderTestdetail(productionWorkOrderTestdetail);
            });
        }

        JSONArray thirdPartyDataJsonArray = JSONArray.parseArray(JSON.toJSONString(paramMap.get("updateThirdPartyList")));
        if (ObjectUtil.isNotNull(thirdPartyDataJsonArray)) {
            List<ThirdPartyData> thirdPartyDataList = thirdPartyDataJsonArray.toJavaList(ThirdPartyData.class);
            thirdPartyDataList.stream().forEach(x -> {
                ThirdPartyData thirdPartyData = new ThirdPartyData();
                thirdPartyData.setId(x.getId());
                thirdPartyData.setPushStatus("push");
                thirdPartyDataMapper.updateThirdPartyData(thirdPartyData);
            });
        }

        JSONArray logJsonArray = JSONArray.parseArray(JSON.toJSONString(paramMap.get("updateOrderLogList")));
        if (ObjectUtil.isNotNull(logJsonArray)) {
            List<UpdateOrderLog> updateOrderLogList = logJsonArray.toJavaList(UpdateOrderLog.class);
            updateOrderLogList.stream().forEach(x -> {
                UpdateOrderLog updateOrderLog = new UpdateOrderLog();
                updateOrderLog.setId(x.getId());
                updateOrderLog.setPushStatus("push");
                updateOrderLogMapper.updateUpdateOrderLog(updateOrderLog);
            });
        }
        return resultMap;
    }

    // 获取老化任务-数据List
    public Map<String, Object> buildAgingTask(Map<String, Object> paramMap) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray agingJsonArray = JSONArray.parseArray(String.valueOf(paramMap.get("agingList")));
        List<AgingTask> agingList = agingJsonArray.toJavaList(AgingTask.class);
        //存在就更新
        if (agingList.size() > 0) {
            agingTaskMapper.insertOrUpdateAgingTaskList(agingList);
        }
        //查询公有云需要推送到私有云的数据
        List<AgingTask> publicAgingTaskList = agingTaskMapper.getAgingTaskList("wait", String.valueOf(paramMap.get("deptId")));
        //返回公有云数据
        resultMap.put("publicAgingTaskList", publicAgingTaskList);
        //返回私有云传过来的数据
        resultMap.put("returnAgingList", agingList);
        return resultMap;
    }

    //老化任务详情
    public Map<String, Object> buildAgingTaskDetail(Map<String, Object> paramMap) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray detailJsonArray = JSONArray.parseArray(String.valueOf(paramMap.get("agingTaskDetailList")));
        List<AgingTaskDetail> detailList = detailJsonArray.toJavaList(AgingTaskDetail.class);
        //存在就更新
        if (detailList.size() > 0) {
            agingTaskDetailMapper.insertOrUpdateAgingTaskDetailList(detailList);
        }
        //查询公有云需要推送到私有云的数据
        List<AgingTaskDetail> publicAgingTaskDetailList = agingTaskDetailMapper.getAgingTaskDetailWaitList("wait", String.valueOf(paramMap.get("deptId")));

        //返回公有云数据
        resultMap.put("publicAgingTaskDetailList", publicAgingTaskDetailList);
        //返回私有云传过来的数据
        resultMap.put("returnDetailList", detailList);
        return resultMap;
    }


    // 获取生产库存-测试记录数据List
    public Map<String, Object> buildInventoryTestRecord(Map<String, Object> paramMap) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray recordJsonArray = JSONArray.parseArray(String.valueOf(paramMap.get("inventoryTestRecordList")));
        List<InventoryTestRecord> recordList = recordJsonArray.toJavaList(InventoryTestRecord.class);
        //存在就更新
        if (recordList.size() > 0) {
            inventoryTestRecordMapper.insertOrUpdateInventoryTestRecordList(recordList);
        }
        //查询公有云需要推送到私有云的数据
        List<InventoryTestRecord> publicTestRecordList = inventoryTestRecordMapper.getInventoryTestRecordList("wait", String.valueOf(paramMap.get("deptId")));

        //返回公有云数据
        resultMap.put("publicTestRecordList", publicTestRecordList);
        //返回私有云传过来的数据
        resultMap.put("returnRecordList", recordList);
        return resultMap;
    }

    //获取标签模板数据表List
    public Map<String, Object> buildLabelTemplate(Map<String, Object> paramMap) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray labelTemplateJsonArray = JSONArray.parseArray(String.valueOf(paramMap.get("labelTemplateList")));
        List<LabelTemplate> templateList = labelTemplateJsonArray.toJavaList(LabelTemplate.class);
        //存在就更新
        if (templateList.size() > 0) {
            labelTemplateMapper.insertOrUpdateLabelTemplateList(templateList);
        }
        //查询公有云需要推送到私有云的数据
        List<LabelTemplate> publicLabelTemplateList = labelTemplateMapper.getLabelTemplateWaitList("wait", String.valueOf(paramMap.get("deptId")));

        //返回公有云数据
        resultMap.put("publicLabelTemplateList", publicLabelTemplateList);
        //返回私有云传过来的数据
        resultMap.put("returnTemplateList", templateList);
        return resultMap;
    }

    //License数据表List
    public Map<String, Object> buildLicenseData(Map<String, Object> paramMap) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray licenseJsonArray = JSONArray.parseArray(String.valueOf(paramMap.get("licenseDataList")));
        List<LicenseData> licenseList = licenseJsonArray.toJavaList(LicenseData.class);
        //存在就更新
        if (licenseList.size() > 0) {
            licenseDataMapper.insertOrUpdateLicenseDataList(licenseList);
        }
        //查询公有云需要推送到私有云的数据
        List<LicenseData> publicLicenseDataList = licenseDataMapper.getLicenseDataWaitList("wait", String.valueOf(paramMap.get("deptId")));

        //返回公有云数据
        resultMap.put("publicLicenseDataList", publicLicenseDataList);
        //返回私有云传过来的数据
        resultMap.put("returnLicenseList", licenseList);
        return resultMap;
    }

    //生产库存-数据表List
    public Map<String, Object> buildInventory(Map<String, Object> paramMap) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray inventoryJsonArray = JSONArray.parseArray(String.valueOf(paramMap.get("inventoryList")));
        List<ProductionInventory> inventoryList = inventoryJsonArray.toJavaList(ProductionInventory.class);
        //存在就更新
        if (inventoryList.size() > 0) {
            productionInventoryMapper.insertOrUpdateProductionInventoryList(inventoryList);
        }
        //查询公有云需要推送到私有云的数据
        List<ProductionInventory> publicInventoryList = productionInventoryMapper.getInventoryWaitList("wait", String.valueOf(paramMap.get("deptId")));

        //返回公有云数据
        resultMap.put("publicInventoryList", publicInventoryList);
        //返回私有云传过来的数据
        resultMap.put("returnInventoryList", inventoryList);
        return resultMap;
    }

    //生产订单-数据表List
    public Map<String, Object> buildOrder(Map<String, Object> paramMap) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray orderJsonArray = JSONArray.parseArray(String.valueOf(paramMap.get("orderList")));
        List<ProductionOrder> orderList = orderJsonArray.toJavaList(ProductionOrder.class);
        //存在就更新
        if (orderList.size() > 0) {
            productionOrderMapper.insertOrUpdateProductionOrderList(orderList);
        }
        //查询公有云需要推送到私有云的数据
        List<ProductionOrder> publicOrderList = productionOrderMapper.getOrderWaitList("wait", String.valueOf(paramMap.get("deptId")));

        //返回公有云数据
        resultMap.put("publicOrderList", publicOrderList);
        //返回私有云传过来的数据
        resultMap.put("returnOrderList", orderList);
        return resultMap;
    }

    // 产测人员-数据表List
    public Map<String, Object> buildTestUser(Map<String, Object> paramMap) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray testUserJsonArray = JSONArray.parseArray(String.valueOf(paramMap.get("testUserList")));
        List<ProductionTestUser> testUserList = testUserJsonArray.toJavaList(ProductionTestUser.class);
        //存在就更新
        if (testUserList.size() > 0) {
            productionTestUserMapper.insertOrUpdateProductionTestUserList(testUserList);
        }
        //查询公有云需要推送到私有云的数据
        List<ProductionTestUser> publicTestUserList = productionTestUserMapper.getTestUserWaitList("wait", String.valueOf(paramMap.get("deptId")));

        //返回公有云数据
        resultMap.put("publicTestUserList", publicTestUserList);
        //返回私有云传过来的数据
        resultMap.put("returnTestUserList", testUserList);
        return resultMap;
    }

    //4G卡号列表
    public Map<String, Object> buildCard(Map<String, Object> paramMap) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray cardJsonArray = JSONArray.parseArray(String.valueOf(paramMap.get("cardList")));
        List<ProductionTestUserCard> cardList = cardJsonArray.toJavaList(ProductionTestUserCard.class);
        //存在就更新
        if (cardList.size() > 0) {
            productionTestUserCardMapper.insertOrUpdateProductionTestUserCardList(cardList);
        }
        //查询公有云需要推送到私有云的数据
        List<ProductionTestUserCard> publicTestUserCardList = productionTestUserCardMapper.getTestUserCardWaitList("wait", String.valueOf(paramMap.get("deptId")));

        //返回公有云数据
        resultMap.put("publicCardList", publicTestUserCardList);
        //返回私有云传过来的数据
        resultMap.put("returnCardList", cardList);
        return resultMap;
    }

    //生产工单列表
    public Map<String, Object> buildWorkOrder(Map<String, Object> paramMap) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray workOrderJsonArray = JSONArray.parseArray(String.valueOf(paramMap.get("workOrderList")));
        List<ProductionWorkOrder> workOrderList = workOrderJsonArray.toJavaList(ProductionWorkOrder.class);
        //存在就更新
        if (workOrderList.size() > 0) {
            productionWorkOrderMapper.insertOrUpdateProductionWorkOrderList(workOrderList);
        }
        //查询公有云需要推送到私有云的数据
        List<ProductionWorkOrder> publicWorkOderList = productionWorkOrderMapper.getWorkOrderWaitList("wait", String.valueOf(paramMap.get("deptId")));

        //返回公有云数据
        resultMap.put("publicWorkOrderList", publicWorkOderList);
        //返回私有云传过来的数据
        resultMap.put("returnWorkOrderList", workOrderList);
        return resultMap;
    }

    //测试工单详情
    public Map<String, Object> buildWorkOrderDetail(Map<String, Object> paramMap) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray workOrderDetailJsonArray = JSONArray.parseArray(String.valueOf(paramMap.get("workOrderDetailList")));
        List<ProductionWorkOrderTestdetail> workOrderDetailList = workOrderDetailJsonArray.toJavaList(ProductionWorkOrderTestdetail.class);
        //存在就更新
        if (workOrderDetailList.size() > 0) {
            productionWorkOrderTestdetailMapper.insertOrUpdateTestDetailList(workOrderDetailList);
        }
        //查询公有云需要推送到私有云的数据
        List<ProductionWorkOrderTestdetail> testDetailList = productionWorkOrderTestdetailMapper.getTestDetailWaitList("wait", String.valueOf(paramMap.get("deptId")));

        //返回公有云数据
        resultMap.put("publicWorkOrderDetailList", testDetailList);
        //返回私有云传过来的数据
        resultMap.put("returnWorkOrderDetailList", workOrderDetailList);
        return resultMap;
    }

    //出货记录
    public Map<String, Object> buildShippingRecord(Map<String, Object> paramMap) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray shippingRecordJsonArray = JSONArray.parseArray(String.valueOf(paramMap.get("shippingRecordList")));
        List<ShippingRecord> shippingRecordList = shippingRecordJsonArray.toJavaList(ShippingRecord.class);
        //存在就更新
        if (shippingRecordList.size() > 0) {
            shippingRecordMapper.insertOrUpdateShippingRecordList(shippingRecordList);
        }
        //查询公有云需要推送到私有云的数据
        List<ShippingRecord> publicShippingRecordList = shippingRecordMapper.getShippingRecordWaitList("wait", String.valueOf(paramMap.get("deptId")));

        //返回公有云数据
        resultMap.put("publicShippingRecordList", publicShippingRecordList);
        //返回私有云传过来的数据
        resultMap.put("returnShippingRecordList", shippingRecordList);
        return resultMap;
    }

    //第三方授权
    public Map<String, Object> buildThirdParty(Map<String, Object> paramMap) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray thirdPartyDataJsonArray = JSONArray.parseArray(String.valueOf(paramMap.get("thirdPartyDataList")));
        List<ThirdPartyData> thirdPartyDataList = thirdPartyDataJsonArray.toJavaList(ThirdPartyData.class);
        //存在就更新
        if (thirdPartyDataList.size() > 0) {
            thirdPartyDataMapper.insertOrUpdateThirdPartyList(thirdPartyDataList);
        }
        //查询公有云需要推送到私有云的数据
        List<ThirdPartyData> publicThirdPartyList = thirdPartyDataMapper.getThirdPartyWaitList("wait", String.valueOf(paramMap.get("deptId")));

        //返回公有云数据
        resultMap.put("publicThirdPartyList", publicThirdPartyList);
        //返回私有云传过来的数据
        resultMap.put("returnThirdPartyDataList", thirdPartyDataList);
        return resultMap;
    }

    //工单-订单的操作日志
    public Map<String, Object> buildUpdateLog(Map<String, Object> paramMap) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray logJsonArray = JSONArray.parseArray(String.valueOf(paramMap.get("updateOrderLogList")));
        List<UpdateOrderLog> updateOrderLogList = logJsonArray.toJavaList(UpdateOrderLog.class);
        //存在就更新
        if (updateOrderLogList.size() > 0) {
            updateOrderLogMapper.insertOrUpdateUpdateOrderLogList(updateOrderLogList);
        }
        //查询公有云需要推送到私有云的数据
        List<UpdateOrderLog> publicLogList = updateOrderLogMapper.getUpdateOrderLogWaitList("wait", String.valueOf(paramMap.get("deptId")));

        //返回公有云数据
        resultMap.put("publicUpdateLogList", publicLogList);
        //返回私有云传过来的数据
        resultMap.put("returnUpdateOrderLogList", updateOrderLogList);
        return resultMap;
    }


}
