package com.productiontest.service.impl;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import com.productiontest.common.utils.DateUtils;
import com.productiontest.common.utils.SecurityUtils;
import com.productiontest.domain.UpdateOrderLog;
import com.productiontest.enums.OrderType;
import com.productiontest.mapper.ProductionOrderMapper;
import com.productiontest.mapper.UpdateOrderLogMapper;
import com.productiontest.util.UUIDGenerator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.productiontest.mapper.ThirdPartyDataMapper;
import com.productiontest.domain.ThirdPartyData;
import com.productiontest.service.IThirdPartyDataService;

/**
 * 第三方授权Service业务层处理
 * 
 * @author cf
 * @date 2023-06-15
 */
@Service
public class ThirdPartyDataServiceImpl implements IThirdPartyDataService 
{
    @Autowired
    private ThirdPartyDataMapper thirdPartyDataMapper;
    @Autowired
    private UpdateOrderLogMapper updateOrderLogMapper;


    SimpleDateFormat sd = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
    /**
     * 查询第三方授权
     * 
     * @param id 第三方授权主键
     * @return 第三方授权
     */
    @Override
    public ThirdPartyData selectThirdPartyDataById(String id)
    {
        return thirdPartyDataMapper.selectThirdPartyDataById(id);
    }

    /**
     * 查询第三方授权列表
     * 
     * @param thirdPartyData 第三方授权
     * @return 第三方授权
     */
    @Override
    public List<ThirdPartyData> selectThirdPartyDataList(ThirdPartyData thirdPartyData)
    {
        return thirdPartyDataMapper.selectThirdPartyDataList(thirdPartyData);
    }

    /**
     * 新增第三方授权
     * 
     * @param thirdPartyData 第三方授权
     * @return 结果
     */
    @Override
    public int insertThirdPartyData(ThirdPartyData thirdPartyData)
    {
        thirdPartyData.setCreateTime(DateUtils.getNowDate());
        thirdPartyData.setId(UUIDGenerator.getUUID());
        return thirdPartyDataMapper.insertThirdPartyData(thirdPartyData);
    }

    /**
     * 修改第三方授权
     * 
     * @param thirdPartyData 第三方授权
     * @return 结果
     */
    @Override
    public int updateThirdPartyData(ThirdPartyData thirdPartyData)
    {
        return thirdPartyDataMapper.updateThirdPartyData(thirdPartyData);
    }

    /**
     * 批量删除第三方授权
     * 
     * @param ids 需要删除的第三方授权主键
     * @return 结果
     */
    @Override
    public int deleteThirdPartyDataByIds(String[] ids)
    {
        String str = thirdPartyDataMapper.selectThirdPartyByListIds(ids);
        ThirdPartyData tp= thirdPartyDataMapper.selectThirdPartyDataById(ids[0]);
        UpdateOrderLog updateOrderLog = new UpdateOrderLog();
        updateOrderLog.setId(UUIDGenerator.getUUID());
        updateOrderLog.setUpdateBy(SecurityUtils.getUsername());
        updateOrderLog.setUpdateTime(sd.format(new Date()));
        updateOrderLog.setCreateTime(sd.format(new Date()));
        updateOrderLog.setType("ORDER");
        updateOrderLog.setContent("删除第三方授权-" + str);
        updateOrderLog.setOddId(tp.getOrderId());
        updateOrderLog.setDeptId(SecurityUtils.getDeptId());
        updateOrderLogMapper.insertUpdateOrderLog(updateOrderLog);
        return thirdPartyDataMapper.deleteThirdPartyDataByIds(ids);
    }

    /**
     * 删除第三方授权信息
     * 
     * @param id 第三方授权主键
     * @return 结果
     */
    @Override
    public int deleteThirdPartyDataById(String id)
    {
        return thirdPartyDataMapper.deleteThirdPartyDataById(id);
    }
}
