package com.productiontest.quartz.task;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.alibaba.fastjson.serializer.ValueFilter;
import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONArray;
import com.alibaba.fastjson2.JSONObject;
import com.alibaba.fastjson2.JSONWriter;
import com.productiontest.common.config.RuoYiConfig;
import com.productiontest.common.utils.SecurityUtils;
import com.productiontest.domain.*;
import com.productiontest.mapper.*;
import com.productiontest.service.ILabelTemplateService;
import com.productiontest.service.IProductionOrderService;
import com.productiontest.util.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.File;
import java.util.*;

@Component("synchronizeTask")
public class SynchronizeTask {

    private final Logger logger = LoggerFactory.getLogger(SynchronizeTask.class);

    @Resource
    private ILabelTemplateService labelTemplateService;
    @Resource
    private ProductionTestUserMapper productionTestUserMapper;
    @Resource
    private IProductionOrderService iProductionOrderService;
    @Resource
    private AgingTaskMapper agingTaskMapper;
    @Resource
    private InventoryTestRecordMapper inventoryTestRecordMapper;
    @Resource
    private LabelTemplateMapper labelTemplateMapper;
    @Resource
    private LicenseDataMapper licenseDataMapper;
    @Resource
    private ProductionInventoryMapper productionInventoryMapper;
    @Resource
    private ProductionOrderMapper productionOrderMapper;

    @Resource
    private ProductionTestUserCardMapper productionTestUserCardMapper;
    @Resource
    private ProductionWorkOrderMapper productionWorkOrderMapper;
    @Resource
    private ProductionWorkOrderTestdetailMapper productionWorkOrderTestdetailMapper;
    @Resource
    private ShippingRecordMapper shippingRecordMapper;
    @Resource
    private ThirdPartyDataMapper thirdPartyDataMapper;
    @Resource
    private UpdateOrderLogMapper updateOrderLogMapper;
    @Resource
    private AgingTaskDetailMapper agingTaskDetailMapper;


    public void synchronizeTask() {
        if (new ToolUtil().getNetwork()) {
            try {
                //***********同步上传模板--oss--*****************
                //查询老化任务httpUrl为空的数据
                List<AgingTask> taskList = agingTaskMapper.selectNullHttpUrlList();
                if (taskList.size() > 0) {
                    taskList.stream().forEach(x -> {
                        if (ObjectUtil.isNotNull(x.getDeviceFile())) {
                            JSONObject js = JSONObject.parseObject(x.getDeviceFile());
                            Map<String, String> map = new QcloudUtil().uploadLocalFile(RuoYiConfig.getUploadPath() + js.getString("name"));
                            if (map.get("code").equals("200")) {
                                AgingTask task = new AgingTask();
                                task.setId(x.getId());
                                js.put("httpUrl", map.get("url"));
                                task.setDeviceFile(js.toString());
                                agingTaskMapper.updateAgingTask(task);
                            }
                        }
                    });
                }

                //查询出所有httpUrl为空的数据
                List<LabelTemplate> list = labelTemplateService.getLabelTemplateList();
                if (list.size() > 0) {
                    //遍历进行上传到oss服务器
                    list.stream().forEach(x -> {
                        if (ObjectUtil.isNotNull(x.getUrl())) {
                            Map<String, String> map = new QcloudUtil().uploadLocalFile(x.getUrl());
                            if (map.get("code").equals("200")) {
                                LabelTemplate labelTemplate = new LabelTemplate();
                                labelTemplate.setId(x.getId());
                                labelTemplate.setHttpFile(map.get("url"));
                                labelTemplateService.updateLabelTemplate(labelTemplate);
                            }
                        }
                    });
                }
                //***********同步4G卡号列表--oss--*****************
                List<ProductionTestUser> productionTestUserList = productionTestUserMapper.getTestUserFileList();
                if (productionTestUserList.size() > 0) {
                    productionTestUserList.stream().forEach(x -> {
                        if (ObjectUtil.isNotNull(x.getFilePath())) {
                            JSONObject js = JSONObject.parseObject(x.getFilePath());
                            Map<String, String> map = new QcloudUtil().uploadLocalFile(RuoYiConfig.getUploadPath() + js.getString("name"));
                            if (map.get("code").equals("200")) {
                                ProductionTestUser pt = new ProductionTestUser();
                                pt.setId(x.getId());
                                js.put("httpUrl", map.get("url"));
                                pt.setFilePath(js.toString());
                                productionTestUserMapper.updateProductionTestUser(pt);
                            }

                        }
                    });
                }

                //***********同步订单上传文件到--oss--*****************
                //查询出所有license_file、rom_file等其他文件上传字段 json中http为空集合
                List<ProductionOrder> listLicenseFile = iProductionOrderService.getListFile("license_file");
//                List<ProductionOrder> listRomFile = iProductionOrderService.getListFile("rom_file");
                List<ProductionOrder> listAccessoryFile = iProductionOrderService.getListFile("accessory");
                List<ProductionOrder> listThirdFile = iProductionOrderService.getListFile("third_party_file");
//                List<ProductionOrder> listDeviceFile = iProductionOrderService.getListFile("device_config_file");
                if (listLicenseFile.size() > 0) {
                    listLicenseFile.stream().forEach(x -> {
                        JSONArray parseArray = JSONArray.parseArray(x.getLicenseFile());
                        List<ProductionTestUser> userList = parseArray.toJavaList(ProductionTestUser.class);
                        userList.stream().forEach(a -> {
                            Map<String, String> map = new QcloudUtil().uploadLocalFile(RuoYiConfig.getUploadPath() + a.getName());
                            if (map.get("code").equals("200")) {
                                ProductionOrder productionOrder = new ProductionOrder();
                                productionOrder.setId(x.getId());
//                            JSONObject js = JSONObject.parseObject(x.getLicenseFile());
//                            js.put("httpUrl", map.get("url"));
//                            productionOrder.setLicenseFile(js.toString());
                                a.setHttpUrl(map.get("url"));
                                productionOrder.setLicenseFile(JSON.toJSONString(userList));
                                productionOrderMapper.updateProductionOrder(productionOrder);
                            }
                        });


                    });
                }
//                if (listRomFile.size() > 0) {
//                    listRomFile.stream().forEach(x -> {
//                        if (ObjectUtil.isNotNull(x.getRomFile())) {
//                            JSONObject js = JSONObject.parseObject(x.getRomFile());
//                            Map<String, String> map = new QcloudUtil().uploadLocalFile(RuoYiConfig.getUploadPath() + js.getString("name"));
//                            if (map.get("code").equals("200")) {
//                                ProductionOrder productionOrder = new ProductionOrder();
//                                productionOrder.setId(x.getId());
//
//                                js.put("httpUrl", map.get("url"));
//                                productionOrder.setLicenseFile(js.toString());
//                                iProductionOrderService.updateProductionOrder(productionOrder);
//                            }
//                        }
//
//                    });
//
//                }
                if (listAccessoryFile.size() > 0) {
                    listAccessoryFile.stream().forEach(x -> {
                        if (ObjectUtil.isNotNull(x.getAccessory())) {
                            JSONObject js = JSONObject.parseObject(x.getAccessory());
                            Map<String, String> map = new QcloudUtil().uploadLocalFile(RuoYiConfig.getUploadPath() + js.getString("name"));
                            if (map.get("code").equals("200")) {
                                ProductionOrder productionOrder = new ProductionOrder();
                                productionOrder.setId(x.getId());
                                js.put("httpUrl", map.get("url"));
                                productionOrder.setLicenseFile(js.toString());
                                iProductionOrderService.updateProductionOrder(productionOrder);
                            }
                        }
                    });
                }
                if (listThirdFile.size() > 0) {
                    listThirdFile.stream().forEach(x -> {
                        if (ObjectUtil.isNotNull(x.getThirdPartyFile())) {
                            JSONObject js = JSONObject.parseObject(x.getThirdPartyFile());
                            Map<String, String> map = new QcloudUtil().uploadLocalFile(RuoYiConfig.getUploadPath() + js.getString("name"));
                            if (map.get("code").equals("200")) {
                                ProductionOrder productionOrder = new ProductionOrder();
                                productionOrder.setId(x.getId());
                                js.put("httpUrl", map.get("url"));
                                productionOrder.setLicenseFile(js.toString());
                                iProductionOrderService.updateProductionOrder(productionOrder);
                            }
                        }
                    });
                }
//                if (listDeviceFile.size() > 0) {
//                    listDeviceFile.stream().forEach(x -> {
//                        if (ObjectUtil.isNotNull(x.getDeviceConfigFile())) {
//                            JSONObject js = JSONObject.parseObject(x.getDeviceConfigFile());
//                            Map<String, String> map = new QcloudUtil().uploadLocalFile(RuoYiConfig.getUploadPath() + js.getString("name"));
//                            if (map.get("code").equals("200")) {
//                                ProductionOrder productionOrder = new ProductionOrder();
//                                productionOrder.setId(x.getId());
//                                js.put("httpUrl", map.get("url"));
//                                productionOrder.setLicenseFile(js.toString());
//                                iProductionOrderService.updateProductionOrder(productionOrder);
//                            }
//                        }
//                    });
//                }


            } catch (Exception e) {
                e.printStackTrace();
                logger.error("上传OSS错误:{}", e.toString());
            }
        } else {
            logger.info("当前无网络,无需同步");
        }

    }

    /**
     * 同步数据操作
     */
    public void synchronizeData() {
        //判断是否有网络
        if (new ToolUtil().getNetwork()) {
            //查询老化任务数据列表
            List<AgingTask> agingList = agingTaskMapper.getAgingTaskList("wait", RuoYiConfig.getDeptId());
            //查询老化任务详情列表
            List<AgingTaskDetail> agingTaskDetailList = agingTaskDetailMapper.getAgingTaskDetailWaitList("wait", RuoYiConfig.getDeptId());
            //查询生产库存-测试记录
            List<InventoryTestRecord> inventoryTestRecordList = inventoryTestRecordMapper.getInventoryTestRecordList("wait", RuoYiConfig.getDeptId());
            //查询标签模板-列表
            List<LabelTemplate> labelTemplateList = labelTemplateMapper.getLabelTemplateWaitList("wait", RuoYiConfig.getDeptId());
            //查询license数据-列表
            List<LicenseData> licenseDataList = licenseDataMapper.getLicenseDataWaitList("wait", RuoYiConfig.getDeptId());
            //查询生产库存
            List<ProductionInventory> inventoryList = productionInventoryMapper.getInventoryWaitList("wait", RuoYiConfig.getDeptId());
            //查询生产订单
            List<ProductionOrder> orderList = productionOrderMapper.getOrderWaitList("wait", RuoYiConfig.getDeptId());
            //查询产测人员
            List<ProductionTestUser> testUserList = productionTestUserMapper.getTestUserWaitList("wait", RuoYiConfig.getDeptId());
            //查询4G卡号列表
            List<ProductionTestUserCard> cardList = productionTestUserCardMapper.getTestUserCardWaitList("wait", RuoYiConfig.getDeptId());
            //查询生产工单
            List<ProductionWorkOrder> workOrderList = productionWorkOrderMapper.getWorkOrderWaitList("wait", RuoYiConfig.getDeptId());
            //查询生产工单-详情
            List<ProductionWorkOrderTestdetail> workOrderDetailList = productionWorkOrderTestdetailMapper.getTestDetailWaitList("wait", RuoYiConfig.getDeptId());    //生产工单-详情
            //查询出货记录
            List<ShippingRecord> shippingRecordList = shippingRecordMapper.getShippingRecordWaitList("wait", RuoYiConfig.getDeptId());
            //查询第三方授权
            List<ThirdPartyData> thirdPartyDataList = thirdPartyDataMapper.getThirdPartyWaitList("wait", RuoYiConfig.getDeptId());
            //查询修改日志
            List<UpdateOrderLog> updateOrderLogList = updateOrderLogMapper.getUpdateOrderLogWaitList("wait", RuoYiConfig.getDeptId());

            //假设这是入参
            HashMap<String, Object> paramMap = new HashMap<>();
            paramMap.put("agingList", JSONObject.toJSONString(agingList, JSONWriter.Feature.WriteNulls));
            paramMap.put("agingTaskDetailList", JSONObject.toJSONString(agingTaskDetailList, JSONWriter.Feature.WriteNulls));
            paramMap.put("inventoryTestRecordList", JSONObject.toJSONString(inventoryTestRecordList, JSONWriter.Feature.WriteNulls));
            paramMap.put("labelTemplateList", JSONObject.toJSONString(labelTemplateList, JSONWriter.Feature.WriteNulls));
            paramMap.put("licenseDataList", JSONObject.toJSONString(licenseDataList, JSONWriter.Feature.WriteNulls));
            paramMap.put("inventoryList", JSONObject.toJSONString(inventoryList, JSONWriter.Feature.WriteNulls));
            paramMap.put("orderList", JSONObject.toJSONString(orderList, JSONWriter.Feature.WriteNulls));
            paramMap.put("testUserList", JSONObject.toJSONString(testUserList, JSONWriter.Feature.WriteNulls));
            paramMap.put("cardList", JSONObject.toJSONString(cardList, JSONWriter.Feature.WriteNulls));
            paramMap.put("workOrderList", JSONObject.toJSONString(workOrderList, JSONWriter.Feature.WriteNulls));
            paramMap.put("workOrderDetailList", JSONObject.toJSONString(workOrderDetailList, JSONWriter.Feature.WriteNulls));
            paramMap.put("shippingRecordList", JSONObject.toJSONString(shippingRecordList, JSONWriter.Feature.WriteNulls));
            paramMap.put("thirdPartyDataList", JSONObject.toJSONString(thirdPartyDataList, JSONWriter.Feature.WriteNulls));
            paramMap.put("updateOrderLogList", JSONObject.toJSONString(updateOrderLogList, JSONWriter.Feature.WriteNulls));

            paramMap.put("deptId", RuoYiConfig.getDeptId());
            //转为Json格式
            JSONObject jsonObject = JSONObject.parseObject(JSONObject.toJSONString(paramMap));
            //调用工具类
            String jsonStr = ConnectUtil.connectPost(RuoYiConfig.getAddressIp() + "/synchronizationData/v1/pushData", jsonObject);
            //接收返回数据
            Map map = JSONObject.parseObject(jsonStr);

            // 返回公有云数据
            HashMap<String, Object> returnMap = new HashMap<>();

            /** 老化测试任务 返回结果进行更新操作 ***********/
            returnMap.put("updateAgingList", insertAgingTask(agingList, map).get("list"));

            /** 老任务详情 返回结果进行更新操作 ***********/
            returnMap.put("updateAgingTaskDetailList", insertAgingTaskDetail(agingTaskDetailList, map).get("list"));

            /**生产库存-测试记录 返回结果进行更新操作 ****
             * *******/
            returnMap.put("updateInventoryTestRecordList", insertInventoryTestRecord(inventoryTestRecordList, map).get("list"));

            /**标签模板 返回结果进行更新操作 ***********/
            returnMap.put("updateLabelTemplateList", insertLabelTemplate(labelTemplateList, map).get("list"));

            /** License 返回结果进行更新操作 ***********/
            returnMap.put("updateLicenseList", insertLicense(licenseDataList, map).get("list"));

            /** 生产库存 返回结果进行更新操作 ***********/
            returnMap.put("updateProductionInventoryList", insertProductionInventory(inventoryList, map).get("list"));

            /** 生产订单 返回结果进行更新操作 ***********/
            returnMap.put("updateProductionOrderList", insertProductionOrder(orderList, map).get("list"));

            /** 产测人员 返回结果进行更新操作 ***********/
            returnMap.put("updateProductionTestUserList", insertProductionTestUser(testUserList, map).get("list"));

            /** 4G卡号列表 返回结果进行更新操作 ***********/
            returnMap.put("updateCardList", insertCard(cardList, map).get("list"));

            /** 生产工单 返回结果进行更新操作 ***********/
            returnMap.put("updateWorkOrderList", insertWorkOrder(workOrderList, map).get("list"));

            /** 生产工单-详情 返回结果进行更新操作 ***********/
            returnMap.put("updateWorkOrderDetailList", insertWorkOrderDetail(workOrderDetailList, map).get("list"));

            /** 出货记录-详情 返回结果进行更新操作 ***********/
            returnMap.put("updateShippingRecordList", insertShippingRecord(shippingRecordList, map).get("list"));

            /** 第三方授权 返回结果进行更新操作 ***********/
            returnMap.put("updateThirdPartyList", insertThirdParty(thirdPartyDataList, map).get("list"));

            /** 第三方授权 返回结果进行更新操作 ***********/
            returnMap.put("updateOrderLogList", insertUpdateLog(updateOrderLogList, map).get("list"));

            //同步完远程数据后再次发送请求更新远端数据
            JSONObject returnJson = JSONObject.parseObject(JSONObject.toJSONString(returnMap));
            //调用工具类
            String reJsonStr = ConnectUtil.connectPost(RuoYiConfig.getAddressIp() + "/synchronizationData/v1/updateData", returnJson);
            //接收返回数据
            Map remap = JSONObject.parseObject(reJsonStr);

        } else {
            logger.error("当前无网络,无需同步");
        }

    }

    //老化测试任务
    public Map<String, Object> insertAgingTask(List<AgingTask> agingList, Map map) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray agingJsonArray = JSONArray.parseArray(String.valueOf(map.get("returnAgingList")));
        List<AgingTask> returnAgingList = agingJsonArray.toJavaList(AgingTask.class);
        if (returnAgingList.size() > 0) {
            returnAgingList.stream().forEach(x -> {
                AgingTask agingTask = new AgingTask();
                agingTask.setPushStatus("push");
                agingTask.setId(x.getId());
                agingTaskMapper.updateAgingTask(agingTask);
            });
        }
        //获取到公有云推送过来的数据进行保存
        JSONArray jsonArray = JSONArray.parseArray(String.valueOf(map.get("publicAgingTaskList")));
        if (ObjectUtil.isNotNull(jsonArray)) {
            List<AgingTask> list = jsonArray.toJavaList(AgingTask.class);
            if (list.size() > 0) {
                list.stream().forEach(x -> {
                    JSONObject js = JSONObject.parseObject(x.getDeviceFile());
                    CommonFileUtils.downloadFileFromUrl(js.getString("url"), js.getString("name"));
                    js.put("url", RuoYiConfig.getNginxFile() + js.getString("name"));
                    x.setDeviceFile(js.toString());
                });
                agingTaskMapper.insertOrUpdateAgingTaskList(list);
            }
            resultMap.put("list", list);
        }
        return resultMap;
    }

    //老化任务详情
    public Map<String, Object> insertAgingTaskDetail(List<AgingTaskDetail> agingTaskDetailList, Map map) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray agingJsonArray = JSONArray.parseArray(String.valueOf(map.get("returnDetailList")));
        List<AgingTaskDetail> returnDetailList = agingJsonArray.toJavaList(AgingTaskDetail.class);
        if (returnDetailList.size() > 0) {
            returnDetailList.stream().forEach(x -> {
                AgingTaskDetail agingTaskDetail = new AgingTaskDetail();
                agingTaskDetail.setPushStatus("push");
                agingTaskDetail.setId(x.getId());
                agingTaskDetailMapper.updateAgingTaskDetail(agingTaskDetail);
            });
        }
        //获取到公有云推送过来的数据进行保存
        JSONArray jsonArray = JSONArray.parseArray(String.valueOf(map.get("publicAgingTaskDetailList")));
        if (ObjectUtil.isNotNull(jsonArray)) {
            List<AgingTaskDetail> list = jsonArray.toJavaList(AgingTaskDetail.class);
            if (list.size() > 0) {
                agingTaskDetailMapper.insertOrUpdateAgingTaskDetailList(list);
            }
            resultMap.put("list", list);
        }
        return resultMap;
    }

    //生产库存-测试记录
    public Map<String, Object> insertInventoryTestRecord(List<InventoryTestRecord> InventoryList, Map map) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray recordJsonArray = JSONArray.parseArray(String.valueOf(map.get("returnRecordList")));
        List<InventoryTestRecord> returnRecordList = recordJsonArray.toJavaList(InventoryTestRecord.class);
        if (returnRecordList.size() > 0) {
            returnRecordList.stream().forEach(x -> {
                InventoryTestRecord inventoryTestRecord = new InventoryTestRecord();
                inventoryTestRecord.setPushStatus("push");
                inventoryTestRecord.setId(x.getId());
                inventoryTestRecordMapper.updateInventoryTestRecord(inventoryTestRecord);
            });
        }
        //获取到公有云推送过来的数据进行保存
        JSONArray testRecordArray = JSONArray.parseArray(String.valueOf(map.get("publicTestRecordList")));
        if (ObjectUtil.isNotNull(testRecordArray)) {
            List<InventoryTestRecord> list = testRecordArray.toJavaList(InventoryTestRecord.class);
            if (list.size() > 0) {
                inventoryTestRecordMapper.insertOrUpdateInventoryTestRecordList(list);

            }
            resultMap.put("list", list);
        }
        return resultMap;

    }

    //标签模板
    public Map<String, Object> insertLabelTemplate(List<LabelTemplate> labelTemplateList, Map map) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray labelTemplateJsonArray = JSONArray.parseArray(String.valueOf(map.get("returnTemplateList")));
        List<LabelTemplate> returnTemplateList = labelTemplateJsonArray.toJavaList(LabelTemplate.class);
        if (returnTemplateList.size() > 0) {
            returnTemplateList.stream().forEach(x -> {
                LabelTemplate labelTemplate = new LabelTemplate();
                labelTemplate.setPushStatus("push");
                labelTemplate.setId(x.getId());
                labelTemplateMapper.updateLabelTemplate(labelTemplate);
            });
        }

        //获取到公有云推送过来的数据进行保存
        JSONArray labelTemplateArray = JSONArray.parseArray(String.valueOf(map.get("publicLabelTemplateList")));
        if (ObjectUtil.isNotNull(labelTemplateArray)) {
            List<LabelTemplate> list = labelTemplateArray.toJavaList(LabelTemplate.class);
            if (list.size() > 0) {
                list.stream().forEach(x -> {
                    CommonFileUtils.downloadFileFromUrl(x.getHttpFile(), x.getHttpFile().substring(x.getHttpFile().lastIndexOf("/") + 1));
                    x.setUrl(RuoYiConfig.getNginxFile() + x.getHttpFile().substring(x.getHttpFile().lastIndexOf("/") + 1));
                });
                labelTemplateMapper.insertOrUpdateLabelTemplateList(list);
            }
            resultMap.put("list", list);
        }
        return resultMap;
    }

    //license
    public Map<String, Object> insertLicense(List<LicenseData> licenseDataList, Map map) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray licenseJsonArray = JSONArray.parseArray(String.valueOf(map.get("returnLicenseList")));
        List<LicenseData> returnLicenseList = licenseJsonArray.toJavaList(LicenseData.class);
        if (returnLicenseList.size() > 0) {
            returnLicenseList.stream().forEach(x -> {
                LicenseData licenseData = new LicenseData();
                licenseData.setPushStatus("push");
                licenseData.setId(x.getId());
                licenseDataMapper.updateLicenseData(licenseData);
            });
        }
        //获取到公有云推送过来的数据进行保存
        JSONArray LicenseDataArray = JSONArray.parseArray(String.valueOf(map.get("publicLicenseDataList")));
        if (ObjectUtil.isNotNull(LicenseDataArray)) {
            List<LicenseData> list = LicenseDataArray.toJavaList(LicenseData.class);
            if (list.size() > 0) {
                licenseDataMapper.insertOrUpdateLicenseDataList(list);
            }
            resultMap.put("list", list);

        }
        return resultMap;
    }

    //生产库存
    public Map<String, Object> insertProductionInventory(List<ProductionInventory> inventoryList, Map map) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray inventoryJsonArray = JSONArray.parseArray(String.valueOf(map.get("returnInventoryList")));
        List<ProductionInventory> returnInventoryList = inventoryJsonArray.toJavaList(ProductionInventory.class);
        if (returnInventoryList.size() > 0) {
            returnInventoryList.stream().forEach(x -> {
                ProductionInventory productionInventory = new ProductionInventory();
                productionInventory.setPushStatus("push");
                productionInventory.setId(x.getId());
                productionInventoryMapper.updateProductionInventory(productionInventory);
            });
        }
        //获取到公有云推送过来的数据进行保存
        JSONArray jsonArray = JSONArray.parseArray(String.valueOf(map.get("publicInventoryList")));
        if (ObjectUtil.isNotNull(jsonArray)) {
            List<ProductionInventory> list = jsonArray.toJavaList(ProductionInventory.class);
            if (list.size() > 0) {
                productionInventoryMapper.insertOrUpdateProductionInventoryList(list);
            }
            resultMap.put("list", list);

        }
        return resultMap;
    }

    //生产订单
    public Map<String, Object> insertProductionOrder(List<ProductionOrder> orderList, Map map) {
        Map<String, Object> resultMap = new HashMap<>();
        logger.error("map============" + map);
        JSONArray orderJsonArray = JSONArray.parseArray(String.valueOf(map.get("returnOrderList")));
        List<ProductionOrder> publicOrderList = orderJsonArray.toJavaList(ProductionOrder.class);
        if (publicOrderList.size() > 0) {
            publicOrderList.stream().forEach(x -> {
                ProductionOrder productionOrder = new ProductionOrder();
                productionOrder.setPushStatus("push");
                productionOrder.setId(x.getId());
                productionOrderMapper.updateProductionOrder(productionOrder);
            });
        }
        //获取到公有云推送过来的数据进行保存
        JSONArray jsonArray = JSONArray.parseArray(String.valueOf(map.get("publicOrderList")));
        if (ObjectUtil.isNotNull(jsonArray)) {
            List<ProductionOrder> list = jsonArray.toJavaList(ProductionOrder.class);
            if (list.size() > 0) {
//                list.stream().forEach(x -> {
//                    if (ObjectUtil.isNotNull(x.getDeviceConfigFile())) {
//                        JSONObject js = JSONObject.parseObject(x.getDeviceConfigFile());
//                        CommonFileUtils.downloadFileFromUrl(js.getString("url"), js.getString("name"));
//
//                        js.put("url", RuoYiConfig.getNginxFile() + js.getString("name"));
//                        x.setDeviceConfigFile(js.toString());
//                    }
//                    if (ObjectUtil.isNotNull(x.getRomFile())) {
//                        JSONObject js = JSONObject.parseObject(x.getRomFile());
//                        if(ObjectUtil.isNotNull(js)) {
//                            CommonFileUtils.downloadFileFromUrl(js.getString("url"), js.getString("name"));
//                            js.put("url", RuoYiConfig.getNginxFile() + js.getString("name"));
//                            x.setRomFile(js.toString());
//                        }
//                    }
//                });
                productionOrderMapper.insertOrUpdateProductionOrderList(list);
            }
            resultMap.put("list", list);

        }
        return resultMap;
    }

    //生产订单
    public Map<String, Object> insertProductionTestUser(List<ProductionTestUser> testUserList, Map map) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray testUserJsonArray = JSONArray.parseArray(String.valueOf(map.get("returnTestUserList")));
        List<ProductionTestUser> returnTestUserList = testUserJsonArray.toJavaList(ProductionTestUser.class);
        if (returnTestUserList.size() > 0) {
            returnTestUserList.stream().forEach(x -> {
                ProductionTestUser productionTestUser = new ProductionTestUser();
                productionTestUser.setPushStatus("push");
                productionTestUser.setId(x.getId());
                productionTestUserMapper.updateProductionTestUser(productionTestUser);
            });
        }
        //获取到公有云推送过来的数据进行保存
        JSONArray jsonArray = JSONArray.parseArray(String.valueOf(map.get("publicTestUserList")));
        if (ObjectUtil.isNotNull(jsonArray)) {
            List<ProductionTestUser> list = jsonArray.toJavaList(ProductionTestUser.class);
            if (list.size() > 0) {
                productionTestUserMapper.insertOrUpdateProductionTestUserList(list);
            }
            resultMap.put("list", list);

        }
        return resultMap;
    }

    //4G卡号
    public Map<String, Object> insertCard(List<ProductionTestUserCard> cardList, Map map) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray cardJsonArray = JSONArray.parseArray(String.valueOf(map.get("returnCardList")));
        List<ProductionTestUserCard> returnCardList = cardJsonArray.toJavaList(ProductionTestUserCard.class);
        if (returnCardList.size() > 0) {
            returnCardList.stream().forEach(x -> {
                ProductionTestUserCard testUserCard = new ProductionTestUserCard();
                testUserCard.setPushStatus("push");
                testUserCard.setId(x.getId());
                productionTestUserCardMapper.updateProductionTestUserCard(testUserCard);
            });
        }
        //获取到公有云推送过来的数据进行保存
        JSONArray jsonArray = JSONArray.parseArray(String.valueOf(map.get("publicCardList")));
        if (ObjectUtil.isNotNull(jsonArray)) {
            List<ProductionTestUserCard> list = jsonArray.toJavaList(ProductionTestUserCard.class);
            if (list.size() > 0) {
                productionTestUserCardMapper.insertOrUpdateProductionTestUserCardList(list);
            }
            resultMap.put("list", list);

        }
        return resultMap;
    }

    //生产工单
    public Map<String, Object> insertWorkOrder(List<ProductionWorkOrder> workOrderList, Map map) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray workOrderJsonArray = JSONArray.parseArray(String.valueOf(map.get("returnWorkOrderList")));
        List<ProductionWorkOrder> returnWorkOrderList = workOrderJsonArray.toJavaList(ProductionWorkOrder.class);
        if (returnWorkOrderList.size() > 0) {
            returnWorkOrderList.stream().forEach(x -> {
                ProductionWorkOrder workOrder = new ProductionWorkOrder();
                workOrder.setPushStatus("push");
                workOrder.setId(x.getId());
                productionWorkOrderMapper.updateProductionWorkOrder(workOrder);
            });
        }
        //获取到公有云推送过来的数据进行保存
        JSONArray jsonArray = JSONArray.parseArray(String.valueOf(map.get("publicWorkOrderList")));
        if (ObjectUtil.isNotNull(jsonArray)) {
            List<ProductionWorkOrder> list = jsonArray.toJavaList(ProductionWorkOrder.class);
            if (list.size() > 0) {
                list.stream().forEach(x -> {
                    if (ObjectUtil.isNotNull(x.getDeviceConfigFile())) {
                        JSONObject js = JSONObject.parseObject(x.getDeviceConfigFile());
                        CommonFileUtils.downloadFileFromUrl(js.getString("url"), js.getString("name"));
                        js.put("url", RuoYiConfig.getNginxFile() + js.getString("name"));
                        x.setDeviceConfigFile(js.toString());
                    }
                    if (ObjectUtil.isNotNull(x.getRomFile())) {
                        JSONObject js = JSONObject.parseObject(x.getRomFile());
                        if (ObjectUtil.isNotNull(js)) {
                            CommonFileUtils.downloadFileFromUrl(js.getString("url"), js.getString("name"));
                            js.put("url", RuoYiConfig.getNginxFile() + js.getString("name"));
                            x.setRomFile(js.toString());
                        }
                    }
                });
                productionWorkOrderMapper.insertOrUpdateProductionWorkOrderList(list);
            }
            resultMap.put("list", list);

        }
        return resultMap;
    }

    //生产工单详情
    public Map<String, Object> insertWorkOrderDetail(List<ProductionWorkOrderTestdetail> testDetailList, Map map) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray workOrderDetailJsonArray = JSONArray.parseArray(String.valueOf(map.get("returnWorkOrderDetailList")));
        List<ProductionWorkOrderTestdetail> returnWorkOrderDetailList = workOrderDetailJsonArray.toJavaList(ProductionWorkOrderTestdetail.class);
        if (returnWorkOrderDetailList.size() > 0) {
            returnWorkOrderDetailList.stream().forEach(x -> {
                ProductionWorkOrderTestdetail workOrderTestDetail = new ProductionWorkOrderTestdetail();
                workOrderTestDetail.setPushStatus("push");
                workOrderTestDetail.setId(x.getId());
                productionWorkOrderTestdetailMapper.updateProductionWorkOrderTestdetail(workOrderTestDetail);
            });
        }
        //获取到公有云推送过来的数据进行保存
        JSONArray jsonArray = JSONArray.parseArray(String.valueOf(map.get("publicWorkOrderDetailList")));
        if (ObjectUtil.isNotNull(jsonArray)) {
            List<ProductionWorkOrderTestdetail> list = jsonArray.toJavaList(ProductionWorkOrderTestdetail.class);
            if (list.size() > 0) {
                productionWorkOrderTestdetailMapper.insertOrUpdateTestDetailList(list);
            }
            resultMap.put("list", list);

        }
        return resultMap;
    }

    //出货记录
    public Map<String, Object> insertShippingRecord(List<ShippingRecord> shippingRecordList, Map map) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray shippingRecordJsonArray = JSONArray.parseArray(String.valueOf(map.get("returnShippingRecordList")));
        List<ShippingRecord> returnShippingRecordList = shippingRecordJsonArray.toJavaList(ShippingRecord.class);
        if (returnShippingRecordList.size() > 0) {
            returnShippingRecordList.stream().forEach(x -> {
                ShippingRecord shippingRecord = new ShippingRecord();
                shippingRecord.setPushStatus("push");
                shippingRecord.setId(x.getId());
                shippingRecordMapper.updateShippingRecord(shippingRecord);
            });
        }
        //获取到公有云推送过来的数据进行保存
        JSONArray jsonArray = JSONArray.parseArray(String.valueOf(map.get("publicShippingRecordList")));
        if (ObjectUtil.isNotNull(jsonArray)) {
            List<ShippingRecord> list = jsonArray.toJavaList(ShippingRecord.class);
            if (list.size() > 0) {
                shippingRecordMapper.insertOrUpdateShippingRecordList(list);
            }
            resultMap.put("list", list);

        }
        return resultMap;
    }

    //第三方授权
    public Map<String, Object> insertThirdParty(List<ThirdPartyData> thirdPartyDataList, Map map) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray thirdPartyDataJsonArray = JSONArray.parseArray(String.valueOf(map.get("returnThirdPartyDataList")));
        List<ThirdPartyData> returnThirdPartyDataList = thirdPartyDataJsonArray.toJavaList(ThirdPartyData.class);
        if (returnThirdPartyDataList.size() > 0) {
            returnThirdPartyDataList.stream().forEach(x -> {
                ThirdPartyData thirdPartyData = new ThirdPartyData();
                thirdPartyData.setPushStatus("push");
                thirdPartyData.setId(x.getId());
                thirdPartyDataMapper.updateThirdPartyData(thirdPartyData);
            });
        }
        //获取到公有云推送过来的数据进行保存
        JSONArray jsonArray = JSONArray.parseArray(String.valueOf(map.get("publicThirdPartyList")));
        if (ObjectUtil.isNotNull(jsonArray)) {
            List<ThirdPartyData> list = jsonArray.toJavaList(ThirdPartyData.class);
            if (list.size() > 0) {
                thirdPartyDataMapper.insertOrUpdateThirdPartyList(list);
            }
            resultMap.put("list", list);

        }
        return resultMap;
    }

    //修改日志
    public Map<String, Object> insertUpdateLog(List<UpdateOrderLog> updateOrderLogList, Map map) {
        Map<String, Object> resultMap = new HashMap<>();
        JSONArray logJsonArray = JSONArray.parseArray(String.valueOf(map.get("returnUpdateOrderLogList")));
        List<UpdateOrderLog> returnUpdateOrderLogList = logJsonArray.toJavaList(UpdateOrderLog.class);
        if (returnUpdateOrderLogList.size() > 0) {
            returnUpdateOrderLogList.stream().forEach(x -> {
                UpdateOrderLog updateOrderLog = new UpdateOrderLog();
                updateOrderLog.setPushStatus("push");
                updateOrderLog.setId(x.getId());
                updateOrderLogMapper.updateUpdateOrderLog(updateOrderLog);
            });
        }
        //获取到公有云推送过来的数据进行保存
        JSONArray jsonArray = JSONArray.parseArray(String.valueOf(map.get("publicUpdateLogList")));
        if (ObjectUtil.isNotNull(jsonArray)) {
            List<UpdateOrderLog> list = jsonArray.toJavaList(UpdateOrderLog.class);
            if (list.size() > 0) {
                updateOrderLogMapper.insertOrUpdateUpdateOrderLogList(list);
            }
            resultMap.put("list", list);

        }
        return resultMap;
    }
}
